/**
 * Main Smart WooCommerce Wishlist JS
 *
 * @author: MoreConvert
 * @package: Smart Wishlist For More Convert
 *
 * @version 1.3.3
 */

(function ($) {
	$.noConflict();

	$(document).ready(function () {

		/* === MAIN INIT === */
		var product_in_list = [];

		$(document).on('wlfmc_init', function () {

			init_fix_on_image_single_position();

			var t = $(this),
				cart_redirect_after_add = (typeof (wc_add_to_cart_params) !== 'undefined' && wc_add_to_cart_params !== null) ? wc_add_to_cart_params.cart_redirect_after_add : '';

			t.on('click', '.wlfmc_add_to_wishlist', function (ev) {

				var t = $(this),
					product_id = t.attr('data-product-id'),
					parent_product_id = t.attr('data-parent-product-id'),

					el_wrap = t.closest('.add-to-wishlist-' + product_id),
					filtered_data = null,
					data = {
						action: wlfmc_l10n.actions.add_to_wishlist_action,
						context: 'frontend',
						add_to_wishlist: product_id,
						product_type: t.data('product-type'),
						wishlist_id: t.attr('data-wishlist-id'),
						fragments: retrieve_fragments(product_id)
					};

				// allow third party code to filter data
				if (filtered_data === $(document).triggerHandler('wlfmc_add_to_wishlist_data', [t, data])) {
					data = filtered_data;
				}

				ev.preventDefault();

				jQuery(document.body).trigger('wlfmc_adding_to_wishlist');


				if (!is_cookie_enabled()) {
					window.alert(wlfmc_l10n.labels.cookie_disabled);
					return;
				}

				$.ajax({
					type: 'POST',
					url: wlfmc_l10n.ajax_url,
					data: data,
					dataType: 'json',
					beforeSend: function (xhr) {
						if (wlfmc_l10n.ajax_mode === 'rest_api')
							xhr.setRequestHeader('X-WP-Nonce', wlfmc_l10n.nonce);
						block(t);

					},
					complete: function () {
						unblock(t);
					},
					success: function (response) {

						var response_result = response.result,
							response_message = response.message,
							show_toast = true;

						if (response_result === 'true' || response_result === 'exists') {
							if (typeof response.fragments !== 'undefined') {
								replace_fragments(response.fragments);
							}

							var popup_id = el_wrap.attr('data-popup-id');

							if (popup_id) {

								show_toast = false;
								var popup = $('#' + popup_id).popup({
									closeelement: '#' + popup_id + '_close',
									absolute: false,
									color: '#fff',
									horizontal: $('#' + popup_id).data('horizontal'),
									vertical: $('#' + popup_id).data('vertical'),
									transition: 'all 0.3s',
								});
								console.log({
									closeelement: '#' + popup_id + '_close',
									absolute: false,
									color: '#fff',
									horizontal: $('#' + popup_id).data('horizontal'),
									vertical: $('#' + popup_id).data('vertical'),
									transition: 'all 0.3s',
								});
								popup.popup('show');

							}
							el_wrap.addClass('exists');

							if (response.item_id) {
								el_wrap.find('.wlfmc_delete_item').attr('data-item-id', response.item_id);
								el_wrap.find('.wlfmc_delete_item').attr('data-wishlist-id', response.wishlist_id);
								if ('variable' === t.data('product-type') && typeof product_in_list !== 'undefined' && product_in_list !== null) {
									product_in_list.push({
										wishlist_id: response.wishlist_id,
										item_id: response.item_id,
										product_id: parseInt(product_id)
									});
								}
							}


							if (show_toast && '' !== $.trim(wlfmc_l10n.product_added_text) && response_result === 'true')
								toastr.success(wlfmc_l10n.product_added_text);

							if (response_result === 'true') {
								load_analytics(parseInt(product_id), response.wishlist_id);
							}
						}
						if (show_toast && '' !== $.trim(response.message) && response_result !== 'true')
							toastr.success(response_message);


						init_handling_after_ajax();

						$('body').trigger('wlfmc_added_to_wishlist', [t, el_wrap]);

					}

				});

				return false;
			});

			t.on('click', '.wlfmc-btn-login-need', function (ev) {
				ev.preventDefault();
				toastr.error(wlfmc_l10n.labels.login_need);
				return false;
			});

			t.on('click', '.wlfmc-wishlist-table .remove_from_wishlist', function (ev) {
				var t = $(this);

				ev.preventDefault();

				var table = t.parents('.wlfmc-wishlist-items-wrapper'),
					row = t.parents('[data-row-id]'),
					data_row_id = row.data('row-id'),
					wishlist_id = table.data('id'),
					wishlist_token = table.data('token'),
					data = {
						action: wlfmc_l10n.actions.remove_from_wishlist_action,
						context: 'frontend',
						remove_from_wishlist: data_row_id,
						wishlist_id: wishlist_id,
						wishlist_token: wishlist_token,
						fragments: retrieve_fragments(data_row_id)
					};

				$.ajax({
					beforeSend: function (xhr) {
						if (wlfmc_l10n.ajax_mode === 'rest_api')
							xhr.setRequestHeader('X-WP-Nonce', wlfmc_l10n.nonce);
						block(table);
					},
					complete: function () {
						unblock(table);
					},
					data: data,
					method: 'post',
					success: function (data) {
						if (typeof data.fragments !== 'undefined') {
							replace_fragments(data.fragments);
						}
						if ('true' == data.result) {
							$('.wlfmc-add-to-wishlist.add-to-wishlist-' + data_row_id).removeClass('exists');
						}
						init_handling_after_ajax();

						$('body').trigger('wlfmc_removed_from_wishlist', [t, row]);
					},
					url: wlfmc_l10n.ajax_url
				});

				return false;
			});

			t.on('click', '.wlfmc-products-counter-wishlist .remove_from_wishlist', function (ev) {
				var t = $(this);

				ev.preventDefault();

				var table = t.parents('.wlfmc-wishlist-items-wrapper'),
					row = t.parents('[data-row-id]'),
					data_row_id = row.data('row-id'),
					wishlist_id = table.data('id'),
					wishlist_token = table.data('token'),
					data = {
						action: wlfmc_l10n.actions.remove_from_wishlist_action,
						context: 'frontend',
						remove_from_wishlist: data_row_id,
						wishlist_id: wishlist_id,
						wishlist_token: wishlist_token,
						fragments: retrieve_fragments(data_row_id)
					};

				$.ajax({
					beforeSend: function (xhr) {
						if (wlfmc_l10n.ajax_mode === 'rest_api')
							xhr.setRequestHeader('X-WP-Nonce', wlfmc_l10n.nonce);
						block(table);
					},
					complete: function () {
						unblock(table);
					},
					data: data,
					method: 'post',
					success: function (data) {

						if ('true' == data.result) {
							if (typeof product_in_list !== 'undefined' && product_in_list !== null) {

								for (var i = 0; i <= product_in_list.length - 1; i++) {
									if (product_in_list[i].wishlist_id == wishlist_id && product_in_list[i].product_id == data_row_id) {
										product_in_list.splice(i, 1);
									}
								}
							}

							row.remove();
							$('.wlfmc-wishlist-form').find('[data-row-id="' + data_row_id + '"]').remove();
							$('.wlfmc-products-counter-wrapper  .products-counter-number').text(data.count);
							$('.wlfmc-products-counter-wishlist .total-products .count').text(data.count);

							$('.wlfmc-add-to-wishlist.add-to-wishlist-' + data_row_id).removeClass('exists');

							if ((data.count < 1 || !table.find('[data-row-id]').length) && typeof data.fragments !== 'undefined') {
								replace_fragments(data.fragments);
							}

						}
						init_handling_after_ajax();

						$('body').trigger('wlfmc_removed_from_wishlist', [t, row]);
					},
					url: wlfmc_l10n.ajax_url
				});

				return false;
			});

			t.on('adding_to_cart', 'body', function (ev, button, data) {
				if (typeof button !== 'undefined' && typeof data !== 'undefined' && button.closest('.wlfmc-wishlist-table').length) {
					data.remove_from_wishlist_after_add_to_cart = button.closest('[data-row-id]').data('row-id');
					data.wishlist_id = button.closest('.wlfmc-wishlist-table').data('id');
					typeof wc_add_to_cart_params !== 'undefined' && (wc_add_to_cart_params.cart_redirect_after_add = wlfmc_l10n.redirect_to_cart);
				}
			});

			t.on('added_to_cart', 'body', function (ev, fragments, carthash, button) {
				if (typeof button !== 'undefined' && button.closest('.wlfmc-wishlist-table').length) {
					typeof wc_add_to_cart_params !== 'undefined' && (wc_add_to_cart_params.cart_redirect_after_add = cart_redirect_after_add);

					var tr = button.closest('[data-row-id]'),
						table = tr.closest('.wlfmc-wishlist-fragment'),
						options = table.data('fragment-options');

					button.removeClass('added');
					tr.find('.added_to_cart').remove();

					if (wlfmc_l10n.remove_from_wishlist_after_add_to_cart && options.is_user_owner) {
						tr.remove();
					}
				}
			});

			t.on('added_to_cart', 'body', function () {
				var messages = $('.woocommerce-message');

				if (messages.length === 0) {
					$('#wlfmc-wishlist-form').prepend(wlfmc_l10n.labels.added_to_cart_message);
				} else {
					messages.fadeOut(300, function () {
						$(this).replaceWith(wlfmc_l10n.labels.added_to_cart_message).fadeIn();
					});
				}
			});

			t.on('cart_page_refreshed', 'body', init_handling_after_ajax);

			t.on('click', '.wlfmc_delete_item', function () {
				var t = $(this),
					product_id = t.attr('data-product-id'),
					wishlist_id = t.attr('data-wishlist-id'),
					item_id = t.attr('data-item-id'),
					el_wrap = $('.add-to-wishlist-' + product_id),
					data = {
						action: wlfmc_l10n.actions.delete_item_action,
						context: 'frontend',
						wishlist_id: wishlist_id,
						item_id: item_id,
						fragments: retrieve_fragments(product_id)
					};

				$.ajax({
					url: wlfmc_l10n.ajax_url,
					data: data,
					dataType: 'json',
					beforeSend: function (xhr) {
						if (wlfmc_l10n.ajax_mode === 'rest_api')
							xhr.setRequestHeader('X-WP-Nonce', wlfmc_l10n.nonce);
						block(t);
					},
					complete: function () {
						unblock(t);
					},
					method: 'post',
					success: function (response) {
						var fragments = response.fragments,
							response_message = response.message;

						if ('true' === response.result) {
							el_wrap.removeClass('exists');
							if ('variable' === t.data('product-type') && typeof product_in_list !== 'undefined' && product_in_list !== null) {

								product_in_list = $.grep(product_in_list, function (e) {
									return e.item_id !== parseInt(item_id)
								});

							}
						}
						if (!t.closest('.wlfmc-remove-button').length && '' !== $.trim(response_message)) {
							toastr.error(response_message);
						}
						if ('true' === response.result && '' !== $.trim(wlfmc_l10n.product_removed_text)) {
							toastr.error(wlfmc_l10n.product_removed_text);
						}

						if (typeof fragments !== 'undefined') {
							replace_fragments(fragments);
						}

						init_handling_after_ajax();

						$('body').trigger('wlfmc_removed_from_wishlist', [t, el_wrap]);
					}
				});

				return false;
			});

			t.on('change', '#bulk_add_to_cart', function () {
				var t = $(this),
					checkboxes = t.closest('.wlfmc-wishlist-table').find('[data-row-id]').find('input[type="checkbox"]:not(:disabled)');


				if (t.is(':checked')) {
					checkboxes.prop('checked', 'checked').change();
				} else {
					checkboxes.prop('checked', false).change();
				}
			});

			t.on('submit', '.wlfmc-popup-form', function () {
				return false;
			});


			t.on('found_variation', function (ev, variation) {

				var t = $(ev.target),
					product_id = t.data('product_id'),
					variation_id = variation.variation_id,
					targets = $('.wlfmc-add-to-wishlist [data-parent-product-id="' + product_id + '"]'),
					enable_outofstock = targets.closest('.wlfmc-add-to-wishlist').data('enable-outofstock');

				product_in_list = typeof product_in_list === 'undefined' || product_in_list === null ? targets.closest('.wlfmc-add-to-wishlist').attr('exists-in-wishlist') : product_in_list;

				if (!product_id || !variation_id || !targets.length) {
					return;
				}
				if (!enable_outofstock && !variation.is_in_stock) {
					targets.closest('.wlfmc-add-to-wishlist').addClass('hide');
				} else {
					targets.closest('.wlfmc-add-to-wishlist').removeClass('hide');
				}
				var popup = $('#' + targets.closest('.wlfmc-add-to-wishlist').attr('data-popup-id'));

				if (popup.length) {
					var product_title = popup.data('product-title');
					var desc = wlfmc_l10n.popup_content
					var title = wlfmc_l10n.popup_title;
					var image_size = popup.data('image-size');
					var img = popup.find('.wlfmc-popup-header img').data('src');
					var original_price = popup.find('.wlfmc-parent-product-price').html();
					var product_price = '' !== variation.price_html ? variation.price_html : original_price;


					desc = desc.replace('{product_price}', product_price);
					desc = desc.replace('{product_name}', product_title);

					title = title.replace('{product_price}', product_price);
					title = title.replace('{product_name}', product_title);

					if (variation.image_id && 'true' == popup.data('use-featured')) {
						img = 'large' === image_size ? variation.image.full_src : ('thumbnail' === image_size ? variation.image.thumb_src : variation.image.src);
					}

					popup.find('.wlfmc-popup-title').html(title);
					popup.find('.wlfmc-popup-desc').html(desc);
					popup.find('.wlfmc-popup-header img').attr('src', img);

				}


				targets.each(function () {
					var t = $(this),
						container = t.closest('.wlfmc-add-to-wishlist');

					t.attr('data-parent-product-id', product_id);
					t.attr('data-product-id', variation_id);

					if (container.length) {

						container
							.removeClass(function (i, classes) {
								return classes.match(/add-to-wishlist-\S+/g).join(' ');
							})
							.addClass('add-to-wishlist-' + variation_id).removeClass('exists');
					}
					container.find('.wlfmc-addtowishlist a').attr('href', container.attr('data-add-url').replace("#product_id", variation_id));
					container.find('.wlfmc-removefromwishlist a').attr('href', container.attr('data-remove-url').replace("#product_id", variation_id));
					$.each(product_in_list, function (i, v) {
						if (typeof v !== 'undefined' && v.product_id && v.product_id == variation_id) {
							container.addClass('exists');
							container.find('.wlfmc_delete_item').attr('data-wishlist-id', v.wishlist_id);
							container.find('.wlfmc_delete_item').attr('data-item-id', v.item_id);
						}

					});
				});


			});

			t.on('reset_data', function (ev) {
				var t = $(ev.target),
					product_id = t.data('product_id'),
					targets = $('.wlfmc-add-to-wishlist [data-parent-product-id="' + product_id + '"]');

				product_in_list = typeof product_in_list === 'undefined' || product_in_list === null ? targets.closest('.wlfmc-add-to-wishlist').data('exists-in-wishlist') : product_in_list;

				if (!product_id || !targets.length) {
					return;
				}

				targets.closest('.wlfmc-add-to-wishlist').removeClass('hide');

				var popup = $('#' + targets.closest('.wlfmc-add-to-wishlist').attr('data-popup-id'));

				if (popup.length) {
					var original_price = popup.find('.wlfmc-parent-product-price').html();
					var product_title = popup.data('product-title');
					var desc = wlfmc_l10n.popup_content;
					var title = wlfmc_l10n.popup_title;


					var img = popup.find('.wlfmc-popup-header img').data('src');


					desc = desc.replace('{product_price}', original_price);
					desc = desc.replace('{product_name}', product_title);

					title = title.replace('{product_price}', original_price);
					title = title.replace('{product_name}', product_title);

					popup.find('.wlfmc-popup-title').html(title);
					popup.find('.wlfmc-popup-desc').html(desc);
					popup.find('.wlfmc-popup-header img').attr('src', img);

				}
				targets.each(function () {
					var t = $(this),
						container = t.closest('.wlfmc-add-to-wishlist');

					t.attr('data-parent-product-id', product_id);
					t.attr('data-product-id', product_id);

					if (container.length) {

						container
							.removeClass(function (i, classes) {
								return classes.match(/add-to-wishlist-\S+/g).join(' ');
							})
							.addClass('add-to-wishlist-' + product_id).removeClass('exists');
					}
					container.find('.wlfmc-addtowishlist a').attr('href', container.attr('data-add-url').replace("#product_id", product_id));
					container.find('.wlfmc-removefromwishlist a').attr('href', container.attr('data-remove-url').replace("#product_id", product_id));
					$.each(product_in_list, function (i, v) {
						if (typeof v !== 'undefined' && v.product_id && v.product_id == product_id) {
							container.addClass('exists');
							container.find('.wlfmc_delete_item').attr('data-wishlist-id', v.wishlist_id);
							container.find('.wlfmc_delete_item').attr('data-item-id', v.item_id);
						}

					});
				});


			});

			t.on('wlfmc_reload_fragments', load_fragments);

			t.on('wlfmc_fragments_loaded', function (ev, original, update, firstLoad) {
				if (!firstLoad) {
					return;
				}

				$('.variations_form').find('.variations select').last().change();
			});

			t.on('click', '.wlfmc-products-counter.has-dropdown', function (ev) {
				ev.preventDefault();

				var a = $(this).closest('.wlfmc-products-counter-wrapper').find('.wlfmc-products-counter-dropdown'),
					ao = a.offset(), al = ao.left, at = ao.top, aw = a.outerWidth(), ah = a.outerHeight(),
					la = parseFloat(a.css('left')), ta = parseFloat(a.css('top')), aol = al - la, aot = at - ta,
					_la = la, _ta = ta, ww = $(window).width(), dh = $(document).height(), os = 50,
					r = ww - aol - aw - os, l = os - aol, b = dh - aot - ah - os;
				if (ww <= aw) {
					_la = -1 * aol;
				} else if (0 > ww - (aw + os * 2)) {
					_la = (ww - aw) / 2 - aol;
				} else if (0 < l) {
					_la = l;
				} else if (0 > r) {
					_la = r;
				}
				if (dh < ah) {
					a.height(dh - a.outerHeight() + a.height());
					ah = a.outerHeight();
				}
				if (dh <= ah) {
					_ta = -1 * aot;
				} else if (0 > dh - (ah + os * 2)) {
					_ta = (dh - ah) / 2 - aot;
				} else if (0 > b) {
					_ta = b;
				}
				a.css({left: _la, top: _ta,});
				a.toggleClass('products-show');
				return false;
			})
			t.on("click", function (ev) {
				var $trigger = $(".wlfmc-products-counter.has-dropdown");
				if ($trigger !== ev.target && !$trigger.has(ev.target).length) {
					$(".wlfmc-products-counter-dropdown").removeClass("products-show");
				}
			});

			init_load_variation();

			init_wishlist_popup();

			init_quantity();

			init_checkbox_handling();

			init_copy_wishlist_link();

			init_tooltip();

		}).trigger('wlfmc_init');

		// fix with jet woo builder plugin
		$(document)
			.on('jet-filter-content-rendered', reInit_wlfmc)
			.on('jet-woo-builder-content-rendered', reInit_wlfmc)
			.on('jet-engine/listing-grid/after-load-more', reInit_wlfmc)
			.on('jet-engine/listing-grid/after-lazy-load', reInit_wlfmc)
			.on('jet-cw-loaded', reInit_wlfmc);


		function reInit_wlfmc() {
			$(document).trigger('wlfmc_init');
		}

		function init_load_variation() {
			$('.wlfmc-add-to-wishlist').each(function () {
				var data = $(this).data('exists-in-wishlist');

				if ($.isArray(data) && data.length > 0) {
					$.each(data, function (i, v) {
						product_in_list.push(v);
					})

				}
			});

		}

		function load_popup_data(popup_id, variation_id) {

		}

		/* === Tooltip === */

		function init_tooltip() {
			var wlfmc_tooltip = function () {
				var instance;
				var _self = this;

				this.idSelector = 'wlfmc-tooltip';
				this.text = '';
				this.top = 0;
				this.left = 0;
				this.direction = typeof this.direction !== 'undefined' ? this.direction : 'bottom';
				this.t_type = typeof this.t_type !== 'undefined' ? this.t_type : 'default';
				this.target;

				//Create actual element and tie element to object for reference
				this.node = document.createElement("div");
				this.node.setAttribute("id", this.idSelector);
				this.node.className = this.node.className + "tooltip__hidden";
				this.node.innerHTML = this.text;
				document.body.appendChild(this.node);

				this.show = function () { //Rerender tooltip
					var location_order = ['top', 'right', 'bottom', 'left', 'top'];

					_self.node.innerHTML = _self.text;
					var direction = _self.direction;
					var t_type = _self.t_type;
					if (direction) {
						$(this.node).addClass('tooltip__expanded ' + 'tooltip__expanded-' + direction);
					} else {
						$(this.node).addClass('tooltip__expanded');
					}
					$(this.node).addClass('wlfmc-tooltip-' + t_type);

					$(this.node).removeClass('tooltip__hidden');


					if (offscreen($(wlfmcTooltip.node))) {
						wlfmcTooltip.hide();
						wlfmcTooltip.direction = location_order[location_order.indexOf(wlfmcTooltip.direction) + 1]
						moveTip(wlfmcTooltip.node, wlfmcTooltip.target);
					}
					;

				}

				this.hide = function () { //Hide tooltip
					$(_self.node).css('top', '0');
					$(_self.node).css('left', '0');
					$(_self.node).attr('class', '');
					$(_self.node).addClass('tooltip__hidden');
				}

			}
			//Move tip to proper location before display
			var offscreen = function (el) {
				return (
					(el.offsetLeft + el.offsetWidth) < 0
					|| (el.offsetTop + el.offsetHeight) < 0
					|| (el.offsetLeft + el.offsetWidth > window.innerWidth || el.offsetTop + el.offsetHeight > window.innerHeight)
				);
			};
			var moveTip = function (ell, target) {

				var $target = $(target);
				var $ell = $(ell);
				var body = $("body").offset();
				$("body").css({'position': 'relative'});

				// fix $ell size after change new tooltip text
				wlfmcTooltip.show();
				wlfmcTooltip.hide();

				var buu = 7; //Default padding size in px
				//var center_height = -($ell.outerHeight()/2) + $target.outerHeight()/2;
				var center_height = -($ell.outerHeight() / 2) / 2;
				var center_width = -($ell.outerWidth() / 2) + $target.outerWidth() / 2;

				var locations = {
					'top': [-$ell.outerHeight() - buu, center_width],
					'right': [center_height, $target.outerWidth() + buu],
					'bottom': [$target.outerHeight() + buu, center_width],
					'left': [center_height, -$ell.outerWidth() - buu]
				}
				location_order = ['top', 'right', 'bottom', 'left', 'top'];
				var location_keys = Object.keys(locations);


				//$ell.css('top', $target.offset().top + locations[wlfmcTooltip.direction][0]);
				//$ell.css('left', $target.offset().left + ( buu /2 ) + locations[wlfmcTooltip.direction][1]);

				if (wlfmcTooltip.direction === 'top' || wlfmcTooltip.direction === 'bottom') {
					$ell.css('top', $target.offset().top - (body.top) + locations[wlfmcTooltip.direction][0]);
					$ell.css('left', $target.offset().left - (body.left) + (buu / 2) + locations[wlfmcTooltip.direction][1]);

				} else {
					$ell.css('top', $target.offset().top - (body.top) + (buu / 2) + locations[wlfmcTooltip.direction][0]);
					$ell.css('left', $target.offset().left - (body.left) + locations[wlfmcTooltip.direction][1]);

				}
				if (offscreen($ell)) {
					wlfmcTooltip.direction = location_order[location_order.indexOf(wlfmcTooltip.direction) + 1];
					wlfmcTooltip.show();
				} else {
					wlfmcTooltip.show();
				}

			}


			//Create global wlfmc_tooltip
			wlfmcTooltip = new wlfmc_tooltip();


			//Mouseover to show
			$(".wlfmc-tooltip").mouseover(function (ee) {
				var _self = this
				wlfmcTooltip.target = _self; //Default to self
				var name_classes = _self.className.split(' ');
				name_classes.forEach(function (cc) {
					if (cc.indexOf('wlfmc-tooltip-') != -1) { //Find a directional tag
						wlfmcTooltip.direction = cc.split('-')[cc.split('-').length - 1];
					}
				});

				if ($(this).attr('data-tooltip-type')) {

					wlfmcTooltip.t_type = $(this).attr('data-tooltip-type');

				}
				if ($(this).attr('data-tooltip-text')) {

					wlfmcTooltip.text = $(this).attr('data-tooltip-text');
					//if ($(_self).attr('data-tooltip-target')) wlfmcTooltip.target = $(_self).attr('data-tooltip-target')
					moveTip(wlfmcTooltip.node, wlfmcTooltip.target);

				}

			});

			$('.wlfmc-tooltip').mouseout(function (ee) { //Re-hide tooltip
				wlfmcTooltip.hide();
			});
		}


		function init_fix_on_image_single_position() {
			if ($('.woocommerce-product-gallery__wrapper .wlfmc-top-of-image').length > 0) {
				$('.woocommerce-product-gallery__wrapper .wlfmc-top-of-image').each(function () {
					$(this).insertBefore($(this).parent())
				})
			}

		}

		/* === INIT FUNCTIONS === */

		/**
		 * Init popup for all links with the plugin that open a popup
		 *
		 * @return void
		 */
		function init_wishlist_popup() {

			// add & remove class to body when popup is opened
			var callback = function (node, op) {
					if (typeof node.classList !== 'undefined' && node.classList.contains('wlfmc-overlay')) {
						var method = 'remove' === op ? 'removeClass' : 'addClass';

						$('body')[method]('wlfmc-with-popup');
					}
				},
				callbackAdd = function (node) {
					callback(node, 'add');
				},
				callbackRemove = function (node) {
					callback(node, 'remove');
				},
				observer = new MutationObserver(function (mutationsList) {
					for (var i in mutationsList) {
						var mutation = mutationsList[i];
						if (mutation.type === 'childList') {
							typeof mutation.addedNodes !== 'undefined' && mutation.addedNodes.forEach(callbackAdd);

							typeof mutation.removedNodes !== 'undefined' && mutation.removedNodes.forEach(callbackRemove);
						}
					}
				});

			observer.observe(document.body, {
				childList: true
			});
		}


		/**
		 * Init checkbox handling
		 *
		 * @return void
		 */
		function init_checkbox_handling() {
			var checkboxes = $('.wlfmc-wishlist-table').find('.product-checkbox input[type="checkbox"]');

			checkboxes.off('change').on('change', function (e) {

				e.preventDefault();
				var t = $(this),
					p = t.parent();

				if (!t.is(':checked')) {
					$('input[name="' + t.attr('name') + '"]').prop('checked', false);
					$('#bulk_add_to_cart').prop('checked', false);

				}
				p.removeClass('checked')
					.removeClass('unchecked')
					.addClass(t.is(':checked') ? 'checked' : 'unchecked');

				return false;
			}).trigger('change');
		}


		/**
		 * Init js handling on wishlist table items after ajax update
		 *
		 * @return void
		 */
		function init_handling_after_ajax() {

			init_checkbox_handling();
			init_quantity();
			init_copy_wishlist_link();
			init_tooltip();
			$(document).trigger('wlfmc_init_after_ajax');
		}


		/**
		 * Handle quantity input change for each wishlist item
		 *
		 * @return void
		 */
		function init_quantity() {
			var jqxhr,
				timeout;

			$('.wlfmc-wishlist-table').on('change', '.quantity :input', function () {
				var t = $(this),
					row = t.closest('[data-row-id]'),
					product_id = row.data('row-id'),
					table = t.closest('.wlfmc-wishlist-table'),
					token = table.data('token');

				clearTimeout(timeout);

				// set add to cart link to add specific qty to cart
				row.find('.add_to_cart_button').attr('data-quantity', t.val());

				timeout = setTimeout(function () {
					if (jqxhr) {
						jqxhr.abort();
					}

					jqxhr = $.ajax({
						beforeSend: function (xhr) {
							if (wlfmc_l10n.ajax_mode === 'rest_api')
								xhr.setRequestHeader('X-WP-Nonce', wlfmc_l10n.nonce);
							block(table);
						},
						complete: function () {
							unblock(table);
						},
						data: {
							action: wlfmc_l10n.actions.update_item_quantity,
							context: 'frontend',
							product_id: product_id,
							wishlist_token: token,
							quantity: t.val()
						},
						method: 'POST',
						url: wlfmc_l10n.ajax_url
					});
				}, 1000);
			});
		}

		/**
		 * Init handling for copy button
		 *
		 * @return void
		 */
		function init_copy_wishlist_link() {
			$('.copy-link-trigger').on('click', function (e) {
				e.preventDefault();
				var obj_to_copy = $(this);

				var hidden = $('<input/>', {
					val: obj_to_copy.attr('href'),
					type: 'text'
				});

				$('body').append(hidden);

				if (isOS()) {
					hidden[0].setSelectionRange(0, 9999);
				} else {
					hidden.select();
				}
				document.execCommand('copy');

				hidden.remove();
				return false;
			});
		}


		/* === EVENT HANDLING === */


		/**
		 * Remove a product from the wishlist.
		 *
		 * @param el
		 * @return void
		 */
		function remove_item_from_wishlist(el) {

		}

		function load_analytics(product_id, wishlist_id) {
			$.ajax({
				beforeSend: function (xhr) {
					if (wlfmc_l10n.ajax_mode === 'rest_api')
						xhr.setRequestHeader('X-WP-Nonce', wlfmc_l10n.nonce);
				},
				complete: function () {
					// anything
				},
				data: {
					action: wlfmc_l10n.actions.load_analytics,
					context: 'frontend',
					product_id: product_id,
					wishlist_id: wishlist_id,
				},
				method: 'POST',
				url: wlfmc_l10n.ajax_url
			});
		}

		/* === UTILS === */


		/**
		 * Block item if possible
		 *
		 * @param item jQuery object
		 * @return void
		 */
		function block(item) {
			if (typeof $.fn.block !== 'undefined' && wlfmc_l10n.enable_ajax_loading) {
				item.fadeTo('400', '0.6').block({
					message: null,
					overlayCSS: {
						background: 'transparent url(' + wlfmc_l10n.ajax_loader_url + ') no-repeat center !important',
						backgroundSize: '40px 40px',
						opacity: 1
					}
				});
			}
		}

		/**
		 * Unblock item if possible
		 *
		 * @param item jQuery object
		 * @return void
		 */
		function unblock(item) {
			if (typeof $.fn.unblock !== 'undefined') {
				item.stop(true).css('opacity', '1').unblock();
				$('.tooltip__expanded').removeClass().addClass('tooltip__hidden');
			}
		}

		/**
		 * Check if cookies are enabled
		 *
		 * @return bool
		 */
		function is_cookie_enabled() {
			if (navigator.cookieEnabled) {
				return true;
			}

			// set and read cookie
			document.cookie = 'cookietest=1';
			var ret = document.cookie.indexOf('cookietest=') !== -1;

			// delete cookie
			document.cookie = 'cookietest=1; expires=Thu, 01-Jan-1970 00:00:01 GMT';

			return ret;
		}

		/**
		 * Retrieve fragments that need to be refreshed in the page
		 *
		 * @param search string Ref to search among all fragments in the page
		 * @return object Object containing a property for each fragments that matches search
		 */
		function retrieve_fragments(search) {
			var options = {},
				fragments = null;

			if (search) {
				if (typeof search === 'object') {
					search = $.extend({
						fragments: null,
						s: '',
						container: $(document),
						firstLoad: false
					}, search);

					if (!search.fragments) {
						fragments = search.container.find('.wlfmc-wishlist-fragment');
					} else {
						fragments = search.fragments;
					}

					if (search.s) {
						fragments = fragments.not('[data-fragment-ref]').add(fragments.filter('[data-fragment-ref="' + search.s + '"]'));
					}

					if (search.firstLoad) {
						fragments = fragments.filter('.on-first-load');
					}
				} else {
					fragments = $('.wlfmc-wishlist-fragment');

					if (typeof search === 'string' || typeof search === 'number') {
						fragments = fragments.not('[data-fragment-ref]').add(fragments.filter('[data-fragment-ref="' + search + '"]'));
					}
				}
			} else {
				fragments = $('.wlfmc-wishlist-fragment');
			}

			if (fragments.length) {
				fragments.each(function () {
					var t = $(this),
						id = t.attr('class').split(' ').filter((val) => {
							return val.length && val !== 'exists';
						}).join(wlfmc_l10n.fragments_index_glue);

					options[id] = t.data('fragment-options');
				});
			} else {
				return null;
			}

			return options;
		}

		/**
		 * Load fragments on page loading
		 *
		 * @param search string Ref to search among all fragments in the page
		 */
		function load_fragments(search) {
			search = $.extend({
				firstLoad: true
			}, search);

			var fragments = retrieve_fragments(search);

			if (!fragments) {
				return;
			}

			$.ajax({
				data: {
					action: wlfmc_l10n.actions.load_fragments,
					context: 'frontend',
					fragments: fragments
				},
				method: 'post',
				beforeSend: function (xhr) {
					if (wlfmc_l10n.ajax_mode === 'rest_api')
						xhr.setRequestHeader('X-WP-Nonce', wlfmc_l10n.nonce);
				},
				success: function (data) {
					if (typeof data.fragments !== 'undefined') {
						replace_fragments(data.fragments);

						init_handling_after_ajax();

						$(document).trigger('wlfmc_fragments_loaded', [fragments, data.fragments, search.firstLoad]);

					}
				},
				url: wlfmc_l10n.ajax_url
			});
		}

		/**
		 * Replace fragments with template received
		 *
		 * @param fragments array Array of fragments to replace
		 */
		function replace_fragments(fragments) {
			$.each(fragments, function (i, v) {
				var itemSelector = '.' + i.split(wlfmc_l10n.fragments_index_glue).filter((val) => {
						return val.length && val !== 'exists' && val !== 'with-count';
					}).join('.'),
					toReplace = $(itemSelector);

				// find replace template
				var replaceWith = $(v).filter(itemSelector);

				if (!replaceWith.length) {
					replaceWith = $(v).find(itemSelector);
				}

				if (toReplace.length && replaceWith.length) {
					toReplace.replaceWith(replaceWith);
				}
			});
		}

		/**
		 * Check if device is an IOS device
		 */
		function isOS() {
			return navigator.userAgent.match(/ipad|iphone/i);
		}

		/**
		 * Check if passed value could be considered true
		 */
		function isTrue(value) {
			return true === value || 'yes' === value || '1' === value || 1 === value;
		}
	});
})(jQuery);
