<?php
/**
 * Smart Wishlist Admin
 *
 * @author MoreConvert
 * @package Smart Wishlist For More Convert
 *
 * @version 1.3.3
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'WLFMC_Admin' ) ) {
	/**
	 * This class handles admin for wishlist plugin
	 */
	class WLFMC_Admin {

		/**
		 * Single instance of the class
		 *
		 * @var WLFMC_Admin
		 */
		protected static $instance;

		/**
		 * Main panel
		 *
		 * @var MCT_Admin $main_panel Main panel.
		 */
		public $main_panel;

		/**
		 * Main options
		 *
		 * @var Array $main_options Main option.
		 */
		public $main_options;

		/**
		 * Installed state
		 *
		 * @var bool
		 * @since 1.0.1
		 */
		public $installed;
		/**
		 * @var array
		 */
		public $steps_options;

		/**
		 * @var array
		 */
		public $tool_options;


		/**
		 * Constructor
		 *
		 * @return void
		 *
		 * @version 1.3.3
		 */
		public function __construct() {

			// install plugin, or update from older versions.
			add_action( 'init', array( $this, 'install' ) );

			$this->installed = WLFMC_Install()->is_installed();

			if ( $this->installed ) {

				$this->main_options = array(
					'options'        => apply_filters(
						'wlfmc_admin_options',
						array(
							'button-display' => array(
								'tabs'   => array(
									'general'       => __( 'General', 'wc-wlfmc-wishlist' ),
									'button'        => __( 'Wishlist Button', 'wc-wlfmc-wishlist' ),
									'page-settings' => __( 'Wishlist Page', 'wc-wlfmc-wishlist' ),
									'counter'       => __( 'Counter', 'wc-wlfmc-wishlist' ),
									'advanced'      => __( 'Advanced', 'wc-wlfmc-wishlist' ),
								),
								'fields' => array(
									'general'       => array(
										'start-article-display-settings' => array(
											'type'  => 'start',
											'title' => __( 'Display Settings', 'wc-wlfmc-wishlist' ),
											'desc'  => __( 'You only need to set them once after installing the plugin.', 'wc-wlfmc-wishlist' )
										),
										'who_can_see_wishlist_options'   => array(
											'label'   => __( 'Enable Wishlist for', 'wc-wlfmc-wishlist' ),
											'type'    => 'select',
											'class'   => 'select2-trigger',
											'help'    => __( 'Do you want the wishlist to be visible only to members or all users of your website', 'wc-wlfmc-wishlist' ),
											'options' => array(
												'all'   => __( 'All users', 'wc-wlfmc-wishlist' ),
												'users' => __( 'Logined users', 'wc-wlfmc-wishlist' ),
											),
											'default' => 'all',
										),
										'force_user_to_login'            => array(
											'label'        => __( 'Require login or register', 'wc-wlfmc-wishlist' ),
											'desc'         => __( 'If you want a comprehensive and accurate analytics section, make the login compulsory.', 'wc-wlfmc-wishlist' ),
											'help'         => __( 'Selecting the user membership to use the wishlist is mandatory or optional', 'wc-wlfmc-wishlist' ),
											'type'         => 'switch',
											'dependencies' => array(
												'id'    => 'who_can_see_wishlist_options',
												'value' => 'all',
											),
											'default'      => '0',
										),
										'click_wishlist_button_behavior' => array(
											'label'   => __( 'After clicking button', 'wc-wlfmc-wishlist' ),
											'type'    => 'select',
											'class'   => 'select2-trigger',
											'help'    => __( 'Choose what happens after your user clicks the Add to wishlist button', 'wc-wlfmc-wishlist' ),
											'options' => array(
												'open-popup'   => __( 'Open the pop up', 'wc-wlfmc-wishlist' ),
												'just-add'     => __( 'Just add it to Wishlist', 'wc-wlfmc-wishlist' ),
												'add-redirect' => __( 'Add and redirect to Wishlist page', 'wc-wlfmc-wishlist' ),
											),
											'default' => 'open-popup',
										),
										'remove_after_second_click'      => array(
											'label'   => __( 'Remove after second click', 'wc-wlfmc-wishlist' ),
											'help'    => __( 'Remove Product From Wishlist On Second Click', 'wc-wlfmc-wishlist' ),
											'type'    => 'switch',
											'default' => '1',

										),
										'enable_for_outofstock_product'  => array(
											'label'   => __( 'Show for out-of-stock', 'wc-wlfmc-wishlist' ),
											'desc'    => __( 'Enable the “ add to wishlist” button for out-of-stock products', 'wc-wlfmc-wishlist' ),
											'type'    => 'switch',
											'default' => '1',
											'help'    => __( 'By activating this option, the Add to wishlist button will be displayed in out of stock products.', 'wc-wlfmc-wishlist' )
										),
										'end-article-display-settings'   => array(
											'type' => 'end',
										),
										'start-article-popup-setting'    => array(
											'type'         => 'start',
											'title'        => __( 'Pop up Settings', 'wc-wlfmc-wishlist' ),
											'dependencies' => array(
												'id'    => 'click_wishlist_button_behavior',
												'value' => 'open-popup',
											),
											'desc'         => __( 'Only in the pop up selection mode will these settings be displayed for you. With these settings, you can customize your pop up.', 'wc-wlfmc-wishlist' )
										),
										'popup_position'                 => array(
											'label'        => __( 'Pop up position', 'wc-wlfmc-wishlist' ),
											'type'         => 'select',
											'class'        => 'select2-trigger',
											'options'      => array(
												'center-center' => __( 'Middle', 'wc-wlfmc-wishlist' ),
												'bottom-left'   => __( 'Down left', 'wc-wlfmc-wishlist' ),
												'bottom-right'  => __( 'Down right', 'wc-wlfmc-wishlist' ),
												'top-right'     => __( 'Top right', 'wc-wlfmc-wishlist' ),
												'top-left'      => __( 'Top left', 'wc-wlfmc-wishlist' ),
											),
											'dependencies' => array(
												'id'    => 'click_wishlist_button_behavior',
												'value' => 'open-popup',
											),
											'default'      => 'center-center',
											'help'         => __( 'Specify the position of the pop up on the website page. There are 5 modes for the pop up position. Middle mode is recommended.', 'wc-wlfmc-wishlist' )
										),
										'popup_size'                     => array(
											'label'        => __( 'Pop up size', 'wc-wlfmc-wishlist' ),
											'desc'         => __( 'If you want to use a photo in the pop up, choose large size for it.', 'wc-wlfmc-wishlist' ),
											'type'         => 'radio',
											'options'      => array(
												'small' => __( 'Small', 'wc-wlfmc-wishlist' ),
												'large' => __( 'Large', 'wc-wlfmc-wishlist' ),
											),
											'dependencies' => array(
												'id'    => 'click_wishlist_button_behavior',
												'value' => 'open-popup',
											),
											'default'      => 'large',
											'help'         => __( 'Specify the size of the pop up. There are two modes, small and large. In large mode you can use the product photo for pop up.', 'wc-wlfmc-wishlist' )
										),
										'use_featured_image'             => array(
											'label'        => __( 'Use featured image for pop up', 'wc-wlfmc-wishlist' ),
											'desc'         => __( 'Enable if use featured image for pop up', 'wc-wlfmc-wishlist' ),
											'type'         => 'switch',
											'dependencies' => array(
												array(
													'id'    => 'popup_size',
													'value' => 'large',
												),
												array(
													'id'    => 'click_wishlist_button_behavior',
													'value' => 'open-popup',
												)
											),
											'default'      => '0',
										),
										'popup_image'                    => array(
											'label'        => __( 'Pop up image', 'wc-wlfmc-wishlist' ),
											'type'         => 'upload-image',
											'dependencies' => array(
												array(
													'id'    => 'popup_size',
													'value' => 'large',
												),
												array(
													'id'    => 'click_wishlist_button_behavior',
													'value' => 'open-popup',
												),
												array(
													'id'    => 'use_featured_image',
													'value' => '0',
												),
											),
										),
										'popup_image_size'               => array(
											'label'        => __( 'Pop up image Size', 'wc-wlfmc-wishlist' ),
											'type'         => 'select',
											'class'        => 'select2-trigger',
											'options'      => array(
												'thumbnail' => __( 'Thumbnail', 'wc-wlfmc-wishlist' ),
												'medium'    => __( 'Medium', 'wc-wlfmc-wishlist' ),
												'large'     => __( 'Large', 'wc-wlfmc-wishlist' ),
												'manual'    => __( 'Manual', 'wc-wlfmc-wishlist' ),
											),
											'dependencies' => array(
												array(
													'id'    => 'popup_size',
													'value' => 'large',
												),
												array(
													'id'    => 'click_wishlist_button_behavior',
													'value' => 'open-popup',
												),
											),
											'default'      => 'medium',
										),
										'popup_image_manual_sizes'       => array(
											'section'      => 'button-display',
											'label'        => __( 'Pop up image sizes', 'wc-wlfmc-wishlist' ),
											'type'         => 'group-fields',
											'fields'       => array(
												'popup_image_width'  => array(
													'label'             => __( 'Image width', 'wc-wlfmc-wishlist' ),
													'type'              => 'number',
													'custom_attributes' => array(
														'style' => 'width:80px'
													)

												),
												'popup_image_height' => array(
													'label'             => __( 'Image height', 'wc-wlfmc-wishlist' ),
													'type'              => 'number',
													'custom_attributes' => array(
														'style' => 'width:80px'
													)

												),

											),
											'dependencies' => array(
												array(
													'id'    => 'popup_size',
													'value' => 'large',
												),
												array(
													'id'    => 'click_wishlist_button_behavior',
													'value' => 'open-popup',
												),
												array(
													'id'    => 'popup_image_size',
													'value' => 'manual',
												),

											)

										),
										'popup_title'                    => array(
											'label'        => __( 'Pop up title', 'wc-wlfmc-wishlist' ),
											'default'      => __( 'Added to Wishlist', 'wc-wlfmc-wishlist' ),
											'type'         => 'text',
											'dependencies' => array(
												'id'    => 'click_wishlist_button_behavior',
												'value' => 'open-popup',
											),
											'desc'         => __( ' You can use the following placeholders: <code>{product_name}</code>,<code>{product_price}</code>', 'wc-wlfmc-wishlist' ),
											'help'         => __( 'Select the title of the pop up. No need to change and you can use the default text.', 'wc-wlfmc-wishlist' ),
										),
										'popup_content'                  => array(
											'label'             => __( 'Pop up content', 'wc-wlfmc-wishlist' ),
											'type'              => 'wp-editor',
											'desc'              => __( ' You can use the following placeholders: <code>{product_name}</code>,<code>{product_price}</code>', 'wc-wlfmc-wishlist' ),
											'default'           => __( 'See your favorite product on Wishlist', 'wc-wlfmc-wishlist' ),
											'dependencies'      => array(
												'id'    => 'click_wishlist_button_behavior',
												'value' => 'open-popup',
											),
											'custom_attributes' => array(
												'style' => 'max-width:100%;'
											),
											'help'              => __( 'Select the content of the pop up. No need to change and you can use the default text.', 'wc-wlfmc-wishlist' )
										),
										'popup_buttons'                  => array(
											'label'        => __( 'Add pop up button', 'wc-wlfmc-wishlist' ),
											'type'         => 'add-button',
											'links'        => array(
												'back'         => __( 'Close pop up and back', 'wc-wlfmc-wishlist' ),
												'signup-login' => __( 'Sign-up or login', 'wc-wlfmc-wishlist' ),
												'wishlist'     => __( 'Wishlist', 'wc-wlfmc-wishlist' ),
												'custom-link'  => __( 'Custom url', 'wc-wlfmc-wishlist' ),
											),
											'default'      => array(
												array(
													'label'             => __( 'View My Wishlist', 'wc-wlfmc-wishlist' ),
													'background'        => '#555555',
													'background-hover'  => '#555555',
													'label-color'       => '#ffffff',
													'label-hover-color' => '#ffffff',
													'border-radius'     => '2px',
													'link'              => 'wishlist',
													'custom-link'       => '',
												),
												array(
													'label'             => __( 'Close', 'wc-wlfmc-wishlist' ),
													'background'        => 'rgba(0,0,0,0)',
													'background-hover'  => 'rgba(0,0,0,0)',
													'label-color'       => '#7e7e7e',
													'label-hover-color' => '#7e7e7e',
													'border-radius'     => '2px',
													'link'              => 'back',
													'custom-link'       => '',
												),
											),
											'limit'        => 3,
											'dependencies' => array(
												'id'    => 'click_wishlist_button_behavior',
												'value' => 'open-popup',
											),
											'help'         => __( 'These settings are related to the pop up button. You can consider more than one button for your pop up.', 'wc-wlfmc-wishlist' )
										),
										'popup_box_style'                => array(
											'section'      => 'button-display',
											'label'        => __( 'Pop up box style', 'wc-wlfmc-wishlist' ),
											'type'         => 'group-fields',
											'fields'       => array(
												'popup_background_color' => array(
													'label'   => __( 'Background color', 'wc-wlfmc-wishlist' ),
													'type'    => 'color',
													'default' => '#f6f6f6',
												),
												'popup_border_color'     => array(
													'label'   => __( 'Border color', 'wc-wlfmc-wishlist' ),
													'type'    => 'color',
													'default' => '#c2c2c2',
												),
												'popup_border_radius'    => array(
													'label'             => __( 'Border radius', 'wc-wlfmc-wishlist' ),
													'type'              => 'text',
													'default'           => '8px',
													'custom_attributes' => array(
														'style' => 'width:80px'
													)
												),
											),
											'dependencies' => array(
												'id'    => 'click_wishlist_button_behavior',
												'value' => 'open-popup',
											),

										),
										'end-article-popup-setting'      => array(
											'type' => 'end',
										),
									),
									'button'        => array(
										// Products single
										'start-article-single'     => array(
											'type'  => 'start',
											'title' => __( 'Single Product page', 'wc-wlfmc-wishlist' ),
											'desc'  => __( 'Design your wishlist button on your product page.', 'wc-wlfmc-wishlist' )
										),
										'wishlist_button_position' => array(
											'label'   => __( 'Button position', 'wc-wlfmc-wishlist' ),
											'type'    => 'select',
											'class'   => 'select2-trigger',
											'options' => array(
												'before_add_to_cart'        => __( 'Before "add to cart" form', 'wc-wlfmc-wishlist' ),
												'after_add_to_cart'         => __( 'After "add to cart" form', 'wc-wlfmc-wishlist' ),
												'before_add_to_cart_button' => __( 'Before "add to cart" button', 'wc-wlfmc-wishlist' ),
												'after_add_to_cart_button'  => __( 'After "add to cart" button', 'wc-wlfmc-wishlist' ),
												'image_top_left'            => __( 'On image - top left', 'wc-wlfmc-wishlist' ),
												'image_top_right'           => __( 'On image - top right', 'wc-wlfmc-wishlist' ),
												'image_bottom_left'         => __( 'On image - bottom left', 'wc-wlfmc-wishlist' ),
												'image_bottom_right'        => __( 'On image - bottom right', 'wc-wlfmc-wishlist' ),
												'summary'                   => __( 'After summary', 'wc-wlfmc-wishlist' ),
												'shortcode'                 => __( 'Use shortcode', 'wc-wlfmc-wishlist' ),
											),
											'help'    => __( 'button position on the product page', 'wc-wlfmc-wishlist' ),
											'default' => 'image_top_left',
										),
										'shortcode_button'         => array(
											'label'        => __( 'Shortcode button', 'wc-wlfmc-wishlist' ),
											'type'         => 'copy-text',
											'default'      => '[wlfmc_add_to_wishlist]',
											'dependencies' => array(
												'id'    => 'wishlist_button_position',
												'value' => 'shortcode',
											),
											'help'         => __( 'Use this shortcode to specify a custom position. Just copy this shortcode wherever you want the button to be displayed.', 'wc-wlfmc-wishlist' )
										),
										'button_type_single'       => array(
											'label'      => __( 'Button type', 'wc-wlfmc-wishlist' ),
											'type'       => 'radio',
											'options'    => array(
												'icon' => __( 'Icon only', 'wc-wlfmc-wishlist' ),
												'text' => __( 'Text only', 'wc-wlfmc-wishlist' ),
												'both' => __( 'Icon and text', 'wc-wlfmc-wishlist' ),
											),
											'default'    => 'icon',
											'help_image' => MC_WLFMC_URL . 'assets/admin/img/help/button_type.gif',
											'help'       => __( 'Select the button appearance. It is better to test different modes and choose the most compatible with the theme.', 'wc-wlfmc-wishlist' )
										),

										'button_theme_single'   => array(
											'label'   => __( 'Default button style', 'wc-wlfmc-wishlist' ),
											'desc'    => __( 'Enable if use theme default styles for icon and text', 'wc-wlfmc-wishlist' ),
											'type'    => 'switch',
											'default' => '0',
											'help'    => __( 'Do you want the button settings to be automatically aligned with your theme?', 'wc-wlfmc-wishlist' )
										),
										'icon_name_single'      => array(
											'label'        => __( 'Button icon', 'wc-wlfmc-wishlist' ),
											'type'         => 'select-icon',
											'class'        => 'select2-trigger',
											'options'      => array(
												'heart'  => array(
													'title' => __( 'Heart', 'wc-wlfmc-wishlist' ),
													'image' => '<span class="d-flex space-between f-center"><img src="' . MC_WLFMC_URL . 'assets/images/heart.svg" width="15" height="15" style="margin:0  5px"/><img src="' . MC_WLFMC_URL . 'assets/images/heart-o.svg" width="15" height="15" /></span>',
												),
												'tag'    => array(
													'title' => __( 'Save', 'wc-wlfmc-wishlist' ),
													'image' => '<span class="d-flex space-between f-center"><img src="' . MC_WLFMC_URL . 'assets/images/tag.svg" width="15" height="15" style="margin:0  5px"/><img src="' . MC_WLFMC_URL . 'assets/images/tag-o.svg" width="15" height="15" /></span>',
												),
												'plus'   => array(
													'title' => __( 'Plus', 'wc-wlfmc-wishlist' ),
													'image' => '<span class="d-flex space-between f-center"><img src="' . MC_WLFMC_URL . 'assets/images/plus.svg" width="15" height="15" style="margin:0  5px"/><img src="' . MC_WLFMC_URL . 'assets/images/plus-o.svg" width="15" height="15" /></span>',
												),
												'gift'   => array(
													'title' => __( 'Gift', 'wc-wlfmc-wishlist' ),
													'image' => '<span class="d-flex space-between f-center"><img src="' . MC_WLFMC_URL . 'assets/images/gift.svg" width="15" height="15" style="margin:0  5px"/><img src="' . MC_WLFMC_URL . 'assets/images/gift-o.svg" width="15" height="15" /></span>',
												),
												'star'   => array(
													'title' => __( 'Star', 'wc-wlfmc-wishlist' ),
													'image' => '<span class="d-flex space-between f-center"><img src="' . MC_WLFMC_URL . 'assets/images/star.svg" width="15" height="15" style="margin:0  5px"/><img src="' . MC_WLFMC_URL . 'assets/images/star-o.svg" width="15" height="15" /></span>',
												),
												'pin'    => array(
													'title' => __( 'Pin', 'wc-wlfmc-wishlist' ),
													'image' => '<span class="d-flex space-between f-center"><img src="' . MC_WLFMC_URL . 'assets/images/pin.svg" width="15" height="15" style="margin:0  5px"/><img src="' . MC_WLFMC_URL . 'assets/images/pin-o.svg" width="15" height="15" /></span>',
												),
												'custom' => __( 'Custom icon', 'wc-wlfmc-wishlist' ),
											),
											'default'      => 'heart',
											'dependencies' => array(
												array(
													'id'    => 'button_type_single',
													'value' => 'icon,both',
												),
												array(
													'id'    => 'button_theme_single',
													'value' => '0',
												),
											),
										),
										'icon_svg_single'       => array(
											'label'             => __( 'Custom icon (svg)', 'wc-wlfmc-wishlist' ),
											'type'              => 'textarea',
											'custom_attributes' => array(
												'cols' => '120',
												'rows' => '3'
											),
											'dependencies'      => array(
												array(
													'id'    => 'button_type_single',
													'value' => 'icon,both',
												),
												array(
													'id'    => 'button_theme_single',
													'value' => '0',
												),
												array(
													'id'    => 'icon_name_single',
													'value' => 'custom',
												)
											),
											'desc'              => __( 'Open your SVG file on a notepad and copy the code on this field.Please input the SVG code with your desired color.', 'wc-wlfmc-wishlist' ),
										),
										'icon_svg_added_single' => array(
											'label'             => __( '"product added" custom icon (svg)', 'wc-wlfmc-wishlist' ),
											'type'              => 'textarea',
											'custom_attributes' => array(
												'cols' => '120',
												'rows' => '3'
											),
											'dependencies'      => array(
												array(
													'id'    => 'button_type_single',
													'value' => 'icon,both',
												),
												array(
													'id'    => 'button_theme_single',
													'value' => '0',
												),
												array(
													'id'    => 'icon_name_single',
													'value' => 'custom',
												)
											),
											'desc'              => __( 'Open your SVG file on a notepad and copy the code on this field.Please input the SVG code with your desired color.', 'wc-wlfmc-wishlist' ),
										),
										'button_icon_single'    => array(
											'section'      => 'button-display',
											'label'        => __( 'Icon style', 'wc-wlfmc-wishlist' ),
											'type'         => 'group-fields',
											'fields'       => array(
												'icon_font_size_single'   => array(
													'label'             => __( 'Font size', 'wc-wlfmc-wishlist' ),
													'type'              => 'text',
													'default'           => '15px',
													'custom_attributes' => array(
														'style' => 'width:80px'
													)
												),
												'icon_color_single'       => array(
													'label'   => __( 'Color', 'wc-wlfmc-wishlist' ),
													'type'    => 'color',
													'default' => 'rgb(230,126,34)',
												),
												'icon_hover_color_single' => array(
													'label'   => __( 'Hover color', 'wc-wlfmc-wishlist' ),
													'type'    => 'color',
													'default' => 'rgb(81,81,81)',
												),
											),
											'dependencies' => array(
												array(
													'id'    => 'button_theme_single',
													'value' => '0',
												),
												array(
													'id'    => 'button_type_single',
													'value' => 'icon,both',
												),
											),
											'desc'         => __( 'write like 10px, 15rem, 13em etc.', 'wc-wlfmc-wishlist' ),
										),
										'button_text_single'    => array(
											'section'      => 'button-display',
											'label'        => __( 'Text style', 'wc-wlfmc-wishlist' ),
											'type'         => 'group-fields',
											'fields'       => array(

												'text_font_size_single'   => array(
													'label'             => __( 'Font size', 'wc-wlfmc-wishlist' ),
													'type'              => 'text',
													'default'           => 'inherit',
													'custom_attributes' => array(
														'style' => 'width:80px'
													)
												),
												'text_color_single'       => array(
													'label'   => __( 'Color', 'wc-wlfmc-wishlist' ),
													'type'    => 'color',
													'default' => 'rgb(230,126,34)',
												),
												'text_hover_color_single' => array(
													'label'   => __( 'Hover color', 'wc-wlfmc-wishlist' ),
													'type'    => 'color',
													'default' => 'rgb(81,81,81)',
												),
											),
											'dependencies' => array(
												array(
													'id'    => 'button_theme_single',
													'value' => '0',
												),
												array(
													'id'    => 'button_type_single',
													'value' => 'text,both',
												),
											),
											'desc'         => __( 'write like 10px, 15rem, 13em etc.', 'wc-wlfmc-wishlist' ),

										),
										'button_colors_single'  => array(
											'section'      => 'button-display',
											'label'        => __( 'Button colors', 'wc-wlfmc-wishlist' ),
											'type'         => 'group-fields',
											'fields'       => array(
												'button_background_color_single'       => array(
													'label'   => __( 'Background color', 'wc-wlfmc-wishlist' ),
													'type'    => 'color',
													'default' => 'transparent',
												),
												'button_background_hover_color_single' => array(
													'label'   => __( 'Background hover color', 'wc-wlfmc-wishlist' ),
													'type'    => 'color',
													'default' => 'transparent',
												),
												'button_border_color_single'           => array(
													'label'   => __( 'Border color', 'wc-wlfmc-wishlist' ),
													'type'    => 'color',
													'default' => 'transparent',
												),
												'button_border_hover_color_single'     => array(
													'label'   => __( 'Border hover color', 'wc-wlfmc-wishlist' ),
													'type'    => 'color',
													'default' => 'transparent',
												),

											),
											'dependencies' => array(
												array(
													'id'    => 'button_theme_single',
													'value' => '0',
												),
											),
										),
										'button_sizes_single'   => array(
											'section'      => 'button-display',
											'label'        => __( 'Button sizes', 'wc-wlfmc-wishlist' ),
											'type'         => 'group-fields',
											'fields'       => array(
												'button_border_width_single'  => array(
													'label'             => __( 'Border width', 'wc-wlfmc-wishlist' ),
													'type'              => 'text',
													'default'           => '1px',
													'custom_attributes' => array(
														'style' => 'width:80px'
													)
												),
												'button_width_single'         => array(
													'label'             => __( 'Width', 'wc-wlfmc-wishlist' ),
													'type'              => 'text',
													'default'           => '45px',
													'custom_attributes' => array(
														'style' => 'width:80px'
													),
													'dependencies'      => array(
														array(
															'id'    => 'button_type_single',
															'value' => 'icon',
														),
													),
												),
												'button_height_single'        => array(
													'label'             => __( 'Height', 'wc-wlfmc-wishlist' ),
													'type'              => 'text',
													'default'           => '45px',
													'custom_attributes' => array(
														'style' => 'width:80px'
													)
												),
												'button_border_radius_single' => array(
													'label'             => __( 'Border radius', 'wc-wlfmc-wishlist' ),
													'type'              => 'text',
													'default'           => '5px',
													'custom_attributes' => array(
														'style' => 'width:80px'
													),
													'help_image'        => MC_WLFMC_URL . 'assets/admin/img/help/border_radius.gif',
													'help'              => __( 'You can define the radius for all 4 corners of the button (look at the gif)', 'wc-wlfmc-wishlist' ),
												),
												'button_margin_single'        => array(
													'label'             => __( 'Margin', 'wc-wlfmc-wishlist' ),
													'type'              => 'text',
													'default'           => '0px',
													'custom_attributes' => array(
														'style' => 'width:80px'
													),
													'help'              => __( 'You Can Define The Margin For All 4 Side Of The Button. To Move The Button Left, Put The Margin Like 0px 0px 0px -15px', 'wc-wlfmc-wishlist' ),
												),

											),
											'dependencies' => array(
												array(
													'id'    => 'button_theme_single',
													'value' => '0',
												),
											),
											'desc'         => __( 'write like 10px, 15rem, 13em etc.', 'wc-wlfmc-wishlist' ),
										),
										'separator_single'      => array(
											'section'      => 'button-display',
											'label'        => __( 'Separate icon and text', 'wc-wlfmc-wishlist' ),
											'type'         => 'group-fields',
											'fields'       => array(
												'separate_icon_and_text_single' => array(
													'label'   => __( 'Activation', 'wc-wlfmc-wishlist' ),
													'type'    => 'switch',
													'default' => '0',
												),
												'separator_color_single'        => array(
													'label'        => __( 'Separator color', 'wc-wlfmc-wishlist' ),
													'type'         => 'color',
													'dependencies' => array(
														array(
															'id'    => 'button_type_single',
															'value' => 'both',
														),
														array(
															'id'    => 'separate_icon_and_text_single',
															'value' => '1',
														),
													),

												),

											),
											'desc'         => __( 'Separate icon and text boxes with a vertical line', 'wc-wlfmc-wishlist' ),
											'dependencies' => array(
												'id'    => 'button_type_single',
												'value' => 'both',
											),
										),
										'button_tooltip_single' => array(
											'section'      => 'button-display',
											'label'        => __( 'Button tooltip styles', 'wc-wlfmc-wishlist' ),
											'type'         => 'group-fields',
											'fields'       => array(
												'enable_tooltip_single'           => array(
													'label'   => __( 'Activation', 'wc-wlfmc-wishlist' ),
													'type'    => 'switch',
													'default' => '0',
												),
												'tooltip_direction_single'        => array(
													'label'        => __( 'direction', 'wc-wlfmc-wishlist' ),
													'type'         => 'select',
													'default'      => 'up',
													'options'      => array(
														'top'    => __( 'Top', 'wc-wlfmc-wishlist' ),
														'bottom' => __( 'Bottom', 'wc-wlfmc-wishlist' ),
														'right'  => __( 'Right', 'wc-wlfmc-wishlist' ),
														'left'   => __( 'Left', 'wc-wlfmc-wishlist' )
													),
													'dependencies' => array(
														array(
															'id'    => 'enable_tooltip_single',
															'value' => '1',
														),
													),
												),
												'tooltip_color_single'            => array(
													'label'        => __( 'color', 'wc-wlfmc-wishlist' ),
													'type'         => 'color',
													'default'      => '#fff',
													'dependencies' => array(
														array(
															'id'    => 'enable_tooltip_single',
															'value' => '1',
														),
													),
												),
												'tooltip_background_color_single' => array(
													'label'        => __( 'Background color', 'wc-wlfmc-wishlist' ),
													'type'         => 'color',
													'default'      => 'rgba(55, 64, 70, 0.9)',
													'dependencies' => array(
														array(
															'id'    => 'enable_tooltip_single',
															'value' => '1',
														),
													),
												),
												'tooltip_border_radius_single'    => array(
													'label'             => __( 'border radius', 'wc-wlfmc-wishlist' ),
													'type'              => 'text',
													'default'           => '6px',
													'custom_attributes' => array(
														'style' => 'width:80px'
													),
													'dependencies'      => array(
														array(
															'id'    => 'enable_tooltip_single',
															'value' => '1',
														),
													),
												),

											),
											'dependencies' => array(
												array(
													'id'    => 'button_type_single',
													'value' => 'icon',
												),
											),
											'help'         => __( 'Tooltip gets text from button text', 'wc-wlfmc-wishlist' ),
											'desc'         => __( 'write like 10px, 15rem, 13em etc for border radius.', 'wc-wlfmc-wishlist' ),
										),

										'end-article-single' => array(
											'type' => 'end',
										),

										'start-article-loop'    => array(
											'type'  => 'start',
											'title' => __( 'Product lists', 'wc-wlfmc-wishlist' ),
											'desc'  => __( 'Design your wishlist button on your shop page and other loops.', 'wc-wlfmc-wishlist' )
										),
										// Products loop
										'show_on_loop'          => array(
											'label'   => __( 'Show "add to Wishlist" in listings', 'wc-wlfmc-wishlist' ),
											'desc'    => __( 'Enable the "add to Wishlist" feature in WooCommerce products\' listing', 'wc-wlfmc-wishlist' ),
											'type'    => 'switch',
											'default' => '1',
											'help'    => __( 'By activating this option, the Add to wishlist button will be displayed in all lists.', 'wc-wlfmc-wishlist' )
										),
										'loop_position'         => array(
											'label'        => __( 'Button position in listings', 'wc-wlfmc-wishlist' ),
											'desc'         => __( 'Choose where to show "Add to Wishlist" button or link in WooCommerce products\' listing.', 'wc-wlfmc-wishlist' ),
											'default'      => 'image_top_right',
											'type'         => 'select',
											'class'        => 'select2-trigger',
											'options'      => array(
												'image_top_left'     => __( 'On image - top left', 'wc-wlfmc-wishlist' ),
												'image_top_right'    => __( 'On image - top right', 'wc-wlfmc-wishlist' ),
												'before_add_to_cart' => __( 'Before "add to cart" button', 'wc-wlfmc-wishlist' ),
												'after_add_to_cart'  => __( 'After "add to cart" button', 'wc-wlfmc-wishlist' ),
												'shortcode'          => __( 'Use shortcode', 'wc-wlfmc-wishlist' ),
											),
											'dependencies' => array(
												'id'    => 'show_on_loop',
												'value' => '1',
											),
											'help'         => __( 'Select the button position to view in the lists. Preferably similar to the button position on the product page.', 'wc-wlfmc-wishlist' )
										),
										'loop_shortcode_button' => array(
											'label'        => __( 'Shortcode button', 'wc-wlfmc-wishlist' ),
											'type'         => 'copy-text',
											'default'      => '[wlfmc_add_to_wishlist]',
											'dependencies' => array(
												array(
													'id'    => 'show_on_loop',
													'value' => '1',
												),
												array(
													'id'    => 'loop_position',
													'value' => 'shortcode',
												),
											),
										),
										'show_on_gutenberg'     => array(
											'label'   => __( 'Show "add to Wishlist" in gutenberg listings', 'wc-wlfmc-wishlist' ),
											'desc'    => __( 'Enable the "add to Wishlist" feature in WooCommerce products\' gutenberg listings', 'wc-wlfmc-wishlist' ),
											'type'    => 'switch',
											'default' => '1',
											'help'    => __( 'By activating this option, the Add to wishlist button will be displayed in all gutenberg lists.', 'wc-wlfmc-wishlist' )
										),
										'gutenberg_position'    => array(
											'label'        => __( 'Button position in gutenberg listings', 'wc-wlfmc-wishlist' ),
											'desc'         => __( 'Choose where to show "Add to Wishlist" button or link in WooCommerce products\' gutenberg listings.', 'wc-wlfmc-wishlist' ),
											'default'      => 'image_top_right',
											'type'         => 'select',
											'class'        => 'select2-trigger',
											'options'      => array(
												'image_top_left'     => __( 'On image - top left', 'wc-wlfmc-wishlist' ),
												'image_top_right'    => __( 'On image - top right', 'wc-wlfmc-wishlist' ),
												'after_title'        => __( 'After title', 'wc-wlfmc-wishlist' ),
												'before_price'       => __( 'Before price', 'wc-wlfmc-wishlist' ),
												'after_price'        => __( 'After price', 'wc-wlfmc-wishlist' ),
												'before_add_to_cart' => __( 'Before "add to cart" button', 'wc-wlfmc-wishlist' ),
												'after_add_to_cart'  => __( 'After "add to cart" button', 'wc-wlfmc-wishlist' ),
											),
											'dependencies' => array(
												'id'    => 'show_on_gutenberg',
												'value' => '1',
											),
											'help'         => __( 'Select the button position to view in the gutenberg lists. Preferably similar to the button position on the product page.', 'wc-wlfmc-wishlist' )
										),
										'button_type_loop'      => array(
											'label'      => __( 'Button type', 'wc-wlfmc-wishlist' ),
											'type'       => 'radio',
											'options'    => array(
												'icon' => __( 'Icon only', 'wc-wlfmc-wishlist' ),
												'text' => __( 'Text only', 'wc-wlfmc-wishlist' ),
												'both' => __( 'Icon and text', 'wc-wlfmc-wishlist' ),
											),
											'default'    => 'icon',
											'help_image' => MC_WLFMC_URL . 'assets/admin/img/help/button_type.gif',
											'help'       => __( 'Select the button appearance. It is better to test different modes and choose the most compatible with the theme.', 'wc-wlfmc-wishlist' )

										),
										'button_theme_loop'     => array(
											'label'   => __( 'Default button style', 'wc-wlfmc-wishlist' ),
											'desc'    => __( 'Enable if use theme default styles for icon and text', 'wc-wlfmc-wishlist' ),
											'type'    => 'switch',
											'default' => '0',
										),
										'icon_name_loop'        => array(
											'label'        => __( 'Button icon', 'wc-wlfmc-wishlist' ),
											'type'         => 'select-icon',
											'class'        => 'select2-trigger',
											'options'      => array(
												'heart'  => array(
													'title' => __( 'Heart', 'wc-wlfmc-wishlist' ),
													'image' => '<span class="d-flex space-between f-center"><img src="' . MC_WLFMC_URL . 'assets/images/heart.svg" width="15" height="15" style="margin:0  5px"/><img src="' . MC_WLFMC_URL . 'assets/images/heart-o.svg" width="15" height="15" /></span>',
												),
												'tag'    => array(
													'title' => __( 'Save', 'wc-wlfmc-wishlist' ),
													'image' => '<span class="d-flex space-between f-center"><img src="' . MC_WLFMC_URL . 'assets/images/tag.svg" width="15" height="15" style="margin:0  5px"/><img src="' . MC_WLFMC_URL . 'assets/images/tag-o.svg" width="15" height="15" /></span>',
												),
												'plus'   => array(
													'title' => __( 'Plus', 'wc-wlfmc-wishlist' ),
													'image' => '<span class="d-flex space-between f-center"><img src="' . MC_WLFMC_URL . 'assets/images/plus.svg" width="15" height="15" style="margin:0  5px"/><img src="' . MC_WLFMC_URL . 'assets/images/plus-o.svg" width="15" height="15" /></span>',
												),
												'gift'   => array(
													'title' => __( 'Gift', 'wc-wlfmc-wishlist' ),
													'image' => '<span class="d-flex space-between f-center"><img src="' . MC_WLFMC_URL . 'assets/images/gift.svg" width="15" height="15" style="margin:0  5px"/><img src="' . MC_WLFMC_URL . 'assets/images/gift-o.svg" width="15" height="15" /></span>',
												),
												'star'   => array(
													'title' => __( 'Star', 'wc-wlfmc-wishlist' ),
													'image' => '<span class="d-flex space-between f-center"><img src="' . MC_WLFMC_URL . 'assets/images/star.svg" width="15" height="15" style="margin:0  5px"/><img src="' . MC_WLFMC_URL . 'assets/images/star-o.svg" width="15" height="15" /></span>',
												),
												'pin'    => array(
													'title' => __( 'Pin', 'wc-wlfmc-wishlist' ),
													'image' => '<span class="d-flex space-between f-center"><img src="' . MC_WLFMC_URL . 'assets/images/pin.svg" width="15" height="15" style="margin:0  5px"/><img src="' . MC_WLFMC_URL . 'assets/images/pin-o.svg" width="15" height="15" /></span>',
												),
												'custom' => __( 'Custom icon', 'wc-wlfmc-wishlist' ),
											),
											'default'      => 'heart',
											'dependencies' => array(
												array(
													'id'    => 'button_type_loop',
													'value' => 'icon,both',
												),
												array(
													'id'    => 'button_theme_loop',
													'value' => '0',
												),
											),
										),
										'icon_svg_loop'         => array(
											'label'             => __( 'Custom icon (svg)', 'wc-wlfmc-wishlist' ),
											'type'              => 'textarea',
											'custom_attributes' => array(
												'cols' => '120',
												'rows' => '3'
											),
											'dependencies'      => array(
												array(
													'id'    => 'button_type_loop',
													'value' => 'icon,both',
												),
												array(
													'id'    => 'button_theme_loop',
													'value' => '0',
												),
												array(
													'id'    => 'icon_name_loop',
													'value' => 'custom',
												)
											),
											'desc'              => __( 'Open your SVG file on a notepad and copy the code on this field.Please input the SVG code with your desired color.', 'wc-wlfmc-wishlist' ),
										),
										'icon_svg_added_loop'   => array(
											'label'             => __( '"product added" custom icon (svg)', 'wc-wlfmc-wishlist' ),
											'type'              => 'textarea',
											'custom_attributes' => array(
												'cols' => '120',
												'rows' => '3'
											),
											'dependencies'      => array(
												array(
													'id'    => 'button_type_loop',
													'value' => 'icon,both',
												),
												array(
													'id'    => 'button_theme_loop',
													'value' => '0',
												),
												array(
													'id'    => 'icon_name_loop',
													'value' => 'custom',
												)
											),
											'desc'              => __( 'Open your SVG file on a notepad and copy the code on this field.Please input the SVG code with your desired color.', 'wc-wlfmc-wishlist' ),
										),
										'button_icon_loop'      => array(
											'section'      => 'button-display',
											'label'        => __( 'Icon style', 'wc-wlfmc-wishlist' ),
											'type'         => 'group-fields',
											'fields'       => array(
												'icon_font_size_loop'   => array(
													'label'             => __( 'Font size', 'wc-wlfmc-wishlist' ),
													'type'              => 'text',
													'default'           => '15px',
													'custom_attributes' => array(
														'style' => 'width:80px'
													)
												),
												'icon_color_loop'       => array(
													'label'   => __( 'Color', 'wc-wlfmc-wishlist' ),
													'type'    => 'color',
													'default' => 'rgb(230,126,34)',
												),
												'icon_hover_color_loop' => array(
													'label'   => __( 'Hover color', 'wc-wlfmc-wishlist' ),
													'type'    => 'color',
													'default' => 'rgb(81,81,81)',
												),
											),
											'dependencies' => array(
												array(
													'id'    => 'button_theme_loop',
													'value' => '0',
												),
												array(
													'id'    => 'button_type_loop',
													'value' => 'icon,both',
												),
											),
											'desc'         => __( 'write like 10px, 15rem, 13em etc.', 'wc-wlfmc-wishlist' ),
										),
										'button_text_loop'      => array(
											'section'      => 'button-display',
											'label'        => __( 'Text style', 'wc-wlfmc-wishlist' ),
											'type'         => 'group-fields',
											'fields'       => array(

												'text_font_size_loop'   => array(
													'label'             => __( 'Font size', 'wc-wlfmc-wishlist' ),
													'type'              => 'text',
													'default'           => 'inherit',
													'custom_attributes' => array(
														'style' => 'width:80px'
													)
												),
												'text_color_loop'       => array(
													'label'   => __( 'Color', 'wc-wlfmc-wishlist' ),
													'type'    => 'color',
													'default' => 'rgb(230,126,34)',
												),
												'text_hover_color_loop' => array(
													'label'   => __( 'Hover color', 'wc-wlfmc-wishlist' ),
													'type'    => 'color',
													'default' => 'rgb(81,81,81)',
												),
											),
											'dependencies' => array(
												array(
													'id'    => 'button_theme_loop',
													'value' => '0',
												),
												array(
													'id'    => 'button_type_loop',
													'value' => 'text,both',
												),
											),
											'desc'         => __( 'write like 10px, 15rem, 13em etc.', 'wc-wlfmc-wishlist' ),

										),
										'button_colors_loop'    => array(
											'section'      => 'button-display',
											'label'        => __( 'Button color', 'wc-wlfmc-wishlist' ),
											'type'         => 'group-fields',
											'fields'       => array(
												'button_background_color_loop'       => array(
													'label'   => __( 'Background color', 'wc-wlfmc-wishlist' ),
													'type'    => 'color',
													'default' => 'transparent',
												),
												'button_background_hover_color_loop' => array(
													'label'   => __( 'Background hover color', 'wc-wlfmc-wishlist' ),
													'type'    => 'color',
													'default' => 'transparent',
												),
												'button_border_color_loop'           => array(
													'label'   => __( 'Border color', 'wc-wlfmc-wishlist' ),
													'type'    => 'color',
													'default' => 'transparent',
												),
												'button_border_hover_color_loop'     => array(
													'label'   => __( 'Border hover color', 'wc-wlfmc-wishlist' ),
													'type'    => 'color',
													'default' => 'transparent',
												),

											),
											'dependencies' => array(
												array(
													'id'    => 'button_theme_loop',
													'value' => '0',
												),
											),
										),
										'button_sizes_loop'     => array(
											'section'      => 'button-display',
											'label'        => __( 'Button sizes', 'wc-wlfmc-wishlist' ),
											'type'         => 'group-fields',
											'fields'       => array(
												'button_border_width_loop'  => array(
													'label'             => __( 'Border width', 'wc-wlfmc-wishlist' ),
													'type'              => 'text',
													'default'           => '1px',
													'custom_attributes' => array(
														'style' => 'width:80px'
													)
												),
												'button_width_loop'         => array(
													'label'             => __( 'Width', 'wc-wlfmc-wishlist' ),
													'type'              => 'text',
													'default'           => '45px',
													'custom_attributes' => array(
														'style' => 'width:80px'
													),
													'dependencies'      => array(
														array(
															'id'    => 'button_type_loop',
															'value' => 'icon',
														),
													),
												),
												'button_height_loop'        => array(
													'label'             => __( 'Height', 'wc-wlfmc-wishlist' ),
													'type'              => 'text',
													'default'           => '45px',
													'custom_attributes' => array(
														'style' => 'width:80px'
													)
												),
												'button_border_radius_loop' => array(
													'label'             => __( 'Border radius', 'wc-wlfmc-wishlist' ),
													'type'              => 'text',
													'default'           => '5px',
													'custom_attributes' => array(
														'style' => 'width:80px'
													),
													'help_image'        => MC_WLFMC_URL . 'assets/admin/img/help/border_radius.gif',
													'help'              => __( 'You can define the radius for all 4 corners of the button (look at the gif)', 'wc-wlfmc-wishlist' ),
												),
												'button_margin_loop'        => array(
													'label'             => __( 'Margin', 'wc-wlfmc-wishlist' ),
													'type'              => 'text',
													'default'           => '0px',
													'custom_attributes' => array(
														'style' => 'width:80px'
													),
													'help'              => __( 'You Can Define The Margin For All 4 Side Of The Button. To Move The Button Left, Put The Margin Like 0px 0px 0px -15px', 'wc-wlfmc-wishlist' ),
												),

											),
											'dependencies' => array(
												array(
													'id'    => 'button_theme_loop',
													'value' => '0',
												),
											),
											'desc'         => __( 'write like 10px, 15rem, 13em etc.', 'wc-wlfmc-wishlist' ),
										),
										'separator_loop'        => array(
											'section'      => 'button-display',
											'label'        => __( 'Separate icon and text', 'wc-wlfmc-wishlist' ),
											'type'         => 'group-fields',
											'fields'       => array(
												'separate_icon_and_text_loop' => array(
													'label'   => __( 'Activation', 'wc-wlfmc-wishlist' ),
													'type'    => 'switch',
													'default' => '0',
												),
												'separator_color_loop'        => array(
													'label'        => __( 'Separator color', 'wc-wlfmc-wishlist' ),
													'type'         => 'color',
													'dependencies' => array(
														array(
															'id'    => 'button_type_loop',
															'value' => 'both',
														),
														array(
															'id'    => 'separate_icon_and_text_loop',
															'value' => '1',
														),
													),

												),

											),
											'desc'         => __( 'Separate icon and text boxes with a vertical line', 'wc-wlfmc-wishlist' ),
											'dependencies' => array(
												'id'    => 'button_type_loop',
												'value' => 'both',
											),
										),
										'button_tooltip_loop'   => array(
											'section'      => 'button-display',
											'label'        => __( 'Button tooltip', 'wc-wlfmc-wishlist' ),
											'type'         => 'group-fields',
											'fields'       => array(
												'enable_tooltip_loop'           => array(
													'label'   => __( 'Activation', 'wc-wlfmc-wishlist' ),
													'type'    => 'switch',
													'default' => '0',
												),
												'tooltip_direction_loop'        => array(
													'label'        => __( 'direction', 'wc-wlfmc-wishlist' ),
													'type'         => 'select',
													'default'      => 'up',
													'options'      => array(
														'top'    => __( 'Top', 'wc-wlfmc-wishlist' ),
														'bottom' => __( 'Bottom', 'wc-wlfmc-wishlist' ),
														'right'  => __( 'Right', 'wc-wlfmc-wishlist' ),
														'left'   => __( 'Left', 'wc-wlfmc-wishlist' )
													),
													'dependencies' => array(
														array(
															'id'    => 'enable_tooltip_loop',
															'value' => '1',
														),
													),
												),
												'tooltip_color_loop'            => array(
													'label'        => __( 'color', 'wc-wlfmc-wishlist' ),
													'type'         => 'color',
													'default'      => '#fff',
													'dependencies' => array(
														array(
															'id'    => 'enable_tooltip_loop',
															'value' => '1',
														),
													),
												),
												'tooltip_background_color_loop' => array(
													'label'        => __( 'Background color', 'wc-wlfmc-wishlist' ),
													'type'         => 'color',
													'default'      => 'rgba(55, 64, 70, 0.9)',
													'dependencies' => array(
														array(
															'id'    => 'enable_tooltip_loop',
															'value' => '1',
														),
													),
												),
												'tooltip_border_radius_loop'    => array(
													'label'             => __( 'border radius', 'wc-wlfmc-wishlist' ),
													'type'              => 'text',
													'default'           => '6px',
													'custom_attributes' => array(
														'style' => 'width:80px'
													),
													'dependencies'      => array(
														array(
															'id'    => 'enable_tooltip_loop',
															'value' => '1',
														),
													),
												),

											),
											'dependencies' => array(
												array(
													'id'    => 'button_type_loop',
													'value' => 'icon',
												),
											),
											'help'         => __( 'Tooltip gets text from button text', 'wc-wlfmc-wishlist' ),
											'desc'         => __( 'write like 10px, 15rem, 13em etc for border radius.', 'wc-wlfmc-wishlist' ),
										),

										'end-article-loop' => array(
											'type' => 'end',
										),

										'start-article-labels-text' => array(
											'type'  => 'start',
											'title' => __( 'Button and tooltip custom text', 'wc-wlfmc-wishlist' ),
											'desc'  => __( 'It will show on the tooltip and button text.', 'wc-wlfmc-wishlist' )
										),
										'button_label_add'          => array(
											'label'   => __( '"Add To Wishlist" text', 'wc-wlfmc-wishlist' ),
											'type'    => 'text',
											'default' => __( 'Add To Wishlist', 'wc-wlfmc-wishlist' ),
										),
										'button_label_view'         => array(
											'label'   => __( '"View My Wishlist" text', 'wc-wlfmc-wishlist' ),
											'type'    => 'text',
											'default' => __( 'View My Wishlist', 'wc-wlfmc-wishlist' ),
										),
										'button_label_remove'       => array(
											'label'   => __( '"Remove From Wishlist" text', 'wc-wlfmc-wishlist' ),
											'type'    => 'text',
											'default' => __( 'Remove From Wishlist', 'wc-wlfmc-wishlist' ),
										),
										'end-article-labels-text'   => array(
											'type' => 'end',
										),

										'start-article-notification-text' => array(
											'type'  => 'start',
											'title' => __( 'Notification custom text', 'wc-wlfmc-wishlist' ),
											'desc'  => __( 'You can choose your desired text for the items below.', 'wc-wlfmc-wishlist' )
										),
										'product_added_text'              => array(
											'label'   => __( '"Product added" text', 'wc-wlfmc-wishlist' ),
											'desc'    => __( 'Enter the text of the message displayed when the user adds a product to the Wishlist. leave empty for disable message.', 'wc-wlfmc-wishlist' ),
											'default' => __( 'Product added!', 'wc-wlfmc-wishlist' ),
											'type'    => 'text',
											'help'    => __( 'After the user clicks on the Add to wishlist button, a notification bar will be displayed. You can display the default text or any other text on this notification bar.', 'wc-wlfmc-wishlist' )
										),
										'already_in_wishlist_text'        => array(
											'label'   => __( '"Product already in Wishlist" text', 'wc-wlfmc-wishlist' ),
											'desc'    => __( 'Enter the text for the message displayed when the user will try to add a product that is already in the Wishlist,leave empty for disable message', 'wc-wlfmc-wishlist' ),
											'default' => __( 'The product is already in your Wishlist!', 'wc-wlfmc-wishlist' ),
											'type'    => 'text',
											'help'    => __( 'If the product already exists in the user\'s wishlist and she/he clicks the Add to wishlist button again, this text will be displayed.', 'wc-wlfmc-wishlist' )
										),
										'product_removed_text'            => array(
											'label'   => __( '"Product removed" text', 'wc-wlfmc-wishlist' ),
											'desc'    => __( 'Enter the text of the message displayed when the user removed a product from the Wishlist,leave empty for disable message', 'wc-wlfmc-wishlist' ),
											'default' => __( 'Product Removed!', 'wc-wlfmc-wishlist' ),
											'type'    => 'text',
											'help'    => __( 'After the user clicks on the remove from wishlist button, a notification bar will be displayed. You can display the default text or any other text on this notification bar.', 'wc-wlfmc-wishlist' )
										),

										'login_need_text'            => array(
											'label'   => __( '"Force to login" text', 'wc-wlfmc-wishlist' ),
											'desc'    => __( 'You can use <code>{login_url}</code> or <code>{signup_url}</code> in the text.', 'wc-wlfmc-wishlist' ),
											'default' =>  __( 'to use your Wishlist: <br><a href="{login_url}">Login right now</a>', 'wc-wlfmc-wishlist' ),
											'type'    => 'textarea',
											'custom_attributes' => array(
												'cols' => '120',
												'rows' => '3'
											),
											'help'    => __( 'it will show when users have to log in to add to the wishlist', 'wc-wlfmc-wishlist' )
										),
										'end-article-notification-text'   => array(
											'type' => 'end',
										),

									),
									'page-settings' => array(
										'start-article-page-settings' => array(
											'type'  => 'start',
											'title' => __( 'Page Settings', 'wc-wlfmc-wishlist' ),
											'desc'  => __( 'Choose details of your wishlist page.', 'wc-wlfmc-wishlist' )
										),
										'wishlist_page'               => array(
											'label'   => __( 'Choose the Wishlist page', 'wc-wlfmc-wishlist' ),
											/* translators: 1: create a page link  2: shortcode*/
											'desc'    => sprintf( __( '%s or Add %s shortcode to a any page you want.', 'wc-wlfmc-wishlist' ), '<a class="wlfmc-built-wishlist-page" href="#">' . __( 'click to build a new page', 'wc-wlfmc-wishlist' ) . '</a>', '<code>[wlfmc_wishlist]</code>' ),
											'type'    => 'page-select',
											'exclude' => $this->get_all_wc_page_ids(),
											'class'   => 'select2-trigger',
											'default' => get_option( 'wlfmc_wishlist_page_id' ),
											'help'    => __( 'Wishlist page needs to be selected so the plugin knows where it is. You should choose it upon installation of the plugin or create it manually.', 'wc-wlfmc-wishlist' )
										),
										'wishlist_page_title'         => array(
											'label'   => __( 'Wishlist name', 'wc-wlfmc-wishlist' ),
											'help'    => __( 'Enter a name for the wishlist page. This is the wishlist that will be automatically generated for all users.', 'wc-wlfmc-wishlist' ),
											'default' => get_the_title( get_option( 'wlfmc_wishlist_page_id' ) ) ? get_the_title( get_option( 'wlfmc_wishlist_page_id' ) ) : __( 'My Wishlist', 'wc-wlfmc-wishlist' ),
											'type'    => 'text',
										),
										/*'remove_after_add_to_cart'    => array(
											'label'   => __( 'Remove if added to the cart', 'wc-wlfmc-wishlist' ),
											'type'    => 'switch',
											'default' => '1',
											'help'    => __( 'Remove the product from the wishlist after it has been added to the cart.', 'wc-wlfmc-wishlist' )
										),*/
										'remove_from_wishlist'        => array(
											'section' => 'button-display',
											'label'   => __( 'Remove from the wishlist if', 'wc-wlfmc-wishlist' ),
											'type'    => 'select',
											'class'   => 'select2-trigger',
											'options' => array(
												'none'          => __( 'Do not remove', 'wc-wlfmc-wishlist' ),
												'added-to-cart' => __( 'Added to the card', 'wc-wlfmc-wishlist' ),
												'completed'     => __( 'Purchase completed', 'wc-wlfmc-wishlist' ),
												'purchased'     => __( 'Purchase Processing', 'wc-wlfmc-wishlist' ),
											),
											'default' => 'none'
										),
										'redirect_after_add_to_cart'  => array(
											'label'   => __( 'Redirect to the cart', 'wc-wlfmc-wishlist' ),
											'type'    => 'switch',
											'default' => '1',
											'help'    => __( 'It works only for the "add all to cart" button and the "add to cart" option in the action button.', 'wc-wlfmc-wishlist' )
										),

										'enable_share'                 => array(
											'label'   => __( 'Share Wishlist', 'wc-wlfmc-wishlist' ),
											'desc'    => __( 'Enable this option to let users share their Wishlist on social media', 'wc-wlfmc-wishlist' ),
											'type'    => 'switch',
											'default' => '1'
										),
										'show_login_notice_for_guests' => array(
											'label'        => __( 'Login notice', 'wc-wlfmc-wishlist' ),
											'desc'         => __( 'Show login notice for guests on wishlist page', 'wc-wlfmc-wishlist' ),
											'type'         => 'switch',
											'dependencies' => array(
												'id'    => 'who_can_see_wishlist_options',
												'value' => 'all',
											),
											'default'      => '1',
											'help'         => __( 'It helps you to generate more leads.', 'wc-wlfmc-wishlist' ),
										),

										'end-article-page-settings' => array(
											'type' => 'end',
										),

										'start-article-table-settings' => array(
											'type'  => 'start',
											'title' => __( 'Table settings', 'wc-wlfmc-wishlist' ),
											'desc'  => __( 'Choose options of your wishlist table.', 'wc-wlfmc-wishlist' ),
										),
										'empty_wishlist_content'       => array(
											'label'             => __( 'Empty wishlist content', 'wc-wlfmc-wishlist' ),
											'type'              => 'wp-editor',
											'default'           => __( 'You have not added any products to your wishlist.', 'wc-wlfmc-wishlist' ),
											'custom_attributes' => array(
												'style' => 'max-width:100%;'
											),
											//'help'              => __( '', 'wc-wlfmc-wishlist' )
										),
										'wishlist_items_show'          => array(
											'label'   => __( 'Items show for wishlist', 'wc-wlfmc-wishlist' ),
											//'desc'         => __( '', 'wc-wlfmc-wishlist' ),
											'type'    => 'checkbox-group',
											'options' => array(
												'product-checkbox'     => __( 'Checkboxes', 'wc-wlfmc-wishlist' ),
												'product-name'         => __( 'Product name', 'wc-wlfmc-wishlist' ),
												'product-review'       => __( 'Product review', 'wc-wlfmc-wishlist' ),
												'product-thumbnail'    => __( 'Product image', 'wc-wlfmc-wishlist' ),
												'product-variation'    => __( 'Product variations selected by the user (example: size or color)', 'wc-wlfmc-wishlist' ),
												'product-price'        => __( 'Product price', 'wc-wlfmc-wishlist' ),
												'product-quantity'     => __( 'Quantity', 'wc-wlfmc-wishlist' ),
												'product-stock-status' => __( 'Product stock (show if the product is not available)', 'wc-wlfmc-wishlist' ),
												'product-date-added'   => __( 'Date on which the product was added to the wishlist', 'wc-wlfmc-wishlist' ),
												'product-add-to-cart'  => __( 'Add to cart option for each product', 'wc-wlfmc-wishlist' ),
												'product-remove'       => __( ' Button to remove the product from the wishlist - to the right of the product', 'wc-wlfmc-wishlist' ),
											),
											'default' => array(
												'product-checkbox',
												'product-name',
												'product-thumbnail',
												'product-price',
												'product-add-to-cart',
												'product-remove'
											),
											//'help'         => __( '', 'wc-wlfmc-wishlist' )
										),
										'wishlist_under_table'         => array(
											'label'   => __( 'Under wishlist table show', 'wc-wlfmc-wishlist' ),
											//'desc'         => __( '', 'wc-wlfmc-wishlist' ),
											'type'    => 'checkbox-group',
											'options' => array(
												'actions'         => __( 'All together Actions button', 'wc-wlfmc-wishlist' ),
												'add-all-to-cart' => __( '"Add All to Cart" button', 'wc-wlfmc-wishlist' ),
											),
											'default' => array(
												'actions',
												'add-all-to-cart',
											),
											//'help'         => __( '', 'wc-wlfmc-wishlist' )
										),
										'wishlist_view_mode'           => array(
											'label'   => __( 'Select view mode', 'wc-wlfmc-wishlist' ),
											'type'    => 'select',
											'default' => 'list',
											'options' => array(
												'list' => __( 'List', 'wc-wlfmc-wishlist' ),
												'grid' => __( 'Grid', 'wc-wlfmc-wishlist' ),
											),
										),
										'wishlist_custom_template'     => array(
											'label'   => __( 'Wishlist default template', 'wc-wlfmc-wishlist' ),
											//'desc'    => __( '', 'wc-wlfmc-wishlist' ),
											'type'    => 'switch',
											'default' => '0',
											//'help'    => __( '', 'wc-wlfmc-wishlist' )
										),

										'wishlist_button_text'              => array(
											'section'      => 'button-display',
											'label'        => __( 'Wishlist button text', 'wc-wlfmc-wishlist' ),
											'type'         => 'group-fields',
											'fields'       => array(
												'wishlist_button_color'       => array(
													'label'   => __( 'Color', 'wc-wlfmc-wishlist' ),
													'type'    => 'color',
													'default' => '#515151',
												),
												'wishlist_button_hover_color' => array(
													'label'   => __( 'Hover color', 'wc-wlfmc-wishlist' ),
													'type'    => 'color',
													'default' => '#fff',
												),
												'wishlist_button_font_size'   => array(
													'label'             => __( 'Font size', 'wc-wlfmc-wishlist' ),
													'type'              => 'text',
													'default'           => '14px',
													'custom_attributes' => array(
														'style' => 'width:80px'
													)
												),
											),
											'dependencies' => array(
												array(
													'id'    => 'wishlist_custom_template',
													'value' => '0',
												),
											),
											'desc'         => __( 'write like 10px, 15rem, 13em etc.', 'wc-wlfmc-wishlist' ),
										),
										'wishlist_button_colors'            => array(
											'section'      => 'button-display',
											'label'        => __( 'Wishlist button colors', 'wc-wlfmc-wishlist' ),
											'type'         => 'group-fields',
											'fields'       => array(
												'wishlist_button_background_color'       => array(
													'label'   => __( 'Background color', 'wc-wlfmc-wishlist' ),
													'type'    => 'color',
													'default' => '#ebebeb',
												),
												'wishlist_button_background_hover_color' => array(
													'label'   => __( 'Background hover color', 'wc-wlfmc-wishlist' ),
													'type'    => 'color',
													'default' => '#e67e22',
												),
												'wishlist_button_border_color'           => array(
													'label'   => __( 'Border color', 'wc-wlfmc-wishlist' ),
													'type'    => 'color',
													'default' => 'transparent',
												),
												'wishlist_button_border_hover_color'     => array(
													'label'   => __( 'Border hover color', 'wc-wlfmc-wishlist' ),
													'type'    => 'color',
													'default' => 'transparent',
												),

											),
											'dependencies' => array(
												array(
													'id'    => 'wishlist_custom_template',
													'value' => '0',
												),
											),
											'desc'         => __( 'write like 10px, 15rem, 13em etc.', 'wc-wlfmc-wishlist' ),
										),
										'wishlist_button_sizes'             => array(
											'section'      => 'button-display',
											'label'        => __( 'Wishlist button sizes', 'wc-wlfmc-wishlist' ),
											'type'         => 'group-fields',
											'fields'       => array(

												'wishlist_button_border_radius' => array(
													'label'             => __( 'Border radius', 'wc-wlfmc-wishlist' ),
													'type'              => 'text',
													'default'           => '5px',
													'custom_attributes' => array(
														'style' => 'width:80px'
													),
													'help_image'        => MC_WLFMC_URL . 'assets/admin/img/help/border_radius.gif',
													'help'              => __( 'You can define the radius for all 4 corners of the button (look at the gif)', 'wc-wlfmc-wishlist' ),

												),
												'wishlist_button_border_width'  => array(
													'label'             => __( 'Border width', 'wc-wlfmc-wishlist' ),
													'type'              => 'text',
													'default'           => '1px',
													'custom_attributes' => array(
														'style' => 'width:80px'
													)
												),
												'wishlist_button_height'        => array(
													'label'             => __( 'Height', 'wc-wlfmc-wishlist' ),
													'type'              => 'text',
													'default'           => '36px',
													'custom_attributes' => array(
														'style' => 'width:80px'
													)
												),

											),
											'dependencies' => array(
												array(
													'id'    => 'wishlist_custom_template',
													'value' => '0',
												),
											),
											'desc'         => __( 'write like 10px, 15rem, 13em etc.', 'wc-wlfmc-wishlist' ),
										),
										'wishlist_button_add_to_cart_style' => array(
											'label'        => __( 'Add to Cart Button style', 'wc-wlfmc-wishlist' ),
											'desc'         => __( 'Apply button style for add to cart button', 'wc-wlfmc-wishlist' ),
											'type'         => 'switch',
											'default'      => '1',
											'dependencies' => array(
												array(
													'id'    => 'wishlist_custom_template',
													'value' => '0',
												),
											),
										),
										'wishlist_qty_style'                => array(
											'label'        => __( 'Quantity field style', 'wc-wlfmc-wishlist' ),
											'desc'		=> __('Apply button style for qty field','wc-wlfmc-wishlist'),
											'type'         => 'switch',
											'default'      => '1',
											'dependencies' => array(
												'id'    => 'wishlist_custom_template',
												'value' => '0',
											),
										),
										'wishlist_pagination_style'         => array(
											'label'        => __( 'Pagination style', 'wc-wlfmc-wishlist' ),
											'desc'		=> __('Apply wishlist page style for pagination bar','wc-wlfmc-wishlist'),
											'type'         => 'switch',
											'default'      => '1',
											'dependencies' => array(
												'id'    => 'wishlist_custom_template',
												'value' => '0',
											),
											'help'         => __( 'Theme settings are used for pagination; by activating this section, coordinate it with the wishlist page style.', 'wc-wlfmc-wishlist' ),
										),
										'wishlist_table_style'              => array(
											'section'      => 'button-display',
											'label'        => __( 'Wishlist items style', 'wc-wlfmc-wishlist' ),
											'type'         => 'group-fields',
											'fields'       => array(
												'wishlist_table_thumbnail_background'  => array(
													'label'             => __( 'Thumbnail background color', 'wc-wlfmc-wishlist' ),
													'type'              => 'color',
													'default'           => '#f5f5f5',
													'custom_attributes' => array(
														'style' => 'width:80px'
													)
												),
												'wishlist_table_grid_border_color'     => array(
													'label'             => __( 'Grid border color', 'wc-wlfmc-wishlist' ),
													'type'              => 'color',
													'default'           => '#ebebeb',
													'custom_attributes' => array(
														'style' => 'width:80px'
													),
													'dependencies'      => array(
														array(
															'id'    => 'wishlist_view_mode',
															'value' => 'grid',
														),
													),
												),
												'wishlist_table_grid_border_radius'    => array(
													'label'             => __( 'Grid border radius', 'wc-wlfmc-wishlist' ),
													'type'              => 'text',
													'default'           => '6px',
													'custom_attributes' => array(
														'style' => 'width:80px'
													),
													'dependencies'      => array(
														array(
															'id'    => 'wishlist_view_mode',
															'value' => 'grid',
														),
													),
												),
												/*'wishlist_table_list_border_color'     => array(
													'label'             => __( 'List border color', 'wc-wlfmc-wishlist' ),
													'type'              => 'color',
													'default'           => '#f5f5f5',
													'custom_attributes' => array(
														'style' => 'width:80px'
													),
													'dependencies' => array(
														array(
															'id'    => 'wishlist_view_mode',
															'value' => 'list',
														),
													),
												),
												'wishlist_table_list_border_radius'    => array(
													'label'             => __( 'List border radius', 'wc-wlfmc-wishlist' ),
													'type'              => 'text',
													'default'           => '6px',
													'custom_attributes' => array(
														'style' => 'width:80px'
													),
													'dependencies' => array(
														array(
															'id'    => 'wishlist_view_mode',
															'value' => 'list',
														),
													),
												),*/
												'wishlist_table_item_background'       => array(
													'label'             => __( 'Item background color', 'wc-wlfmc-wishlist' ),
													'type'              => 'color',
													'default'           => 'transparent',
													'custom_attributes' => array(
														'style' => 'width:80px'
													)
												),
												'wishlist_table_item_hover_background' => array(
													'label'             => __( 'Item background hover color', 'wc-wlfmc-wishlist' ),
													'type'              => 'color',
													'default'           => 'transparent',
													'custom_attributes' => array(
														'style' => 'width:80px'
													)
												),
												'wishlist_table_separator_color'       => array(
													'label'             => __( 'Separator color', 'wc-wlfmc-wishlist' ),
													'type'              => 'color',
													'default'           => 'transparent',
													'custom_attributes' => array(
														'style' => 'width:80px'
													)
												),
											),
											'dependencies' => array(
												array(
													'id'    => 'wishlist_custom_template',
													'value' => '0',
												),
											),

										),
										'end-article-table-settings'        => array(
											'type' => 'end',
										),
										'start-article-login-notice'        => array(
											'type'         => 'start',
											'title'        => __( 'Login notice', 'wc-wlfmc-wishlist' ),
											'desc'         => __( 'Turn guest users into leads by inviting them to sign up on the wishlist page.', 'wc-wlfmc-wishlist' ),
											'dependencies' => array(
												array(
													'id'    => 'show_login_notice_for_guests',
													'value' => '1',
												),
												array(
													'id'    => 'who_can_see_wishlist_options',
													'value' => 'all',
												)

											),
										),
										'login_notice_content'              => array(
											'label'   => __( 'Content', 'wc-wlfmc-wishlist' ),
											'type'    => 'wp-editor',
											'help'    => __( 'Write a text for Notif that creates FOMO', 'wc-wlfmc-wishlist' ),
											'default' => '<p style="text-align: center;"><span style="color: #ff0000;"><strong>' . __( 'Warning! You Will Lose Your Wishlist', 'wc-wlfmc-wishlist' ) . '</strong></span></p><p style="text-align: center;">' . __( 'If you do not sign-up or log in to your account right now , you will probably lose your list after leaving the site.', 'wc-wlfmc-wishlist' ) . '</p>',
										),
										'login_notice_buttons'              => array(
											'label'   => __( 'Add button', 'wc-wlfmc-wishlist' ),
											'type'    => 'add-button',
											'help'    => __( 'Adjust the text of the notification buttons to have the most impact', 'wc-wlfmc-wishlist' ),
											'links'   => array(
												'login'       => __( 'login', 'wc-wlfmc-wishlist' ),
												'signup'      => __( 'Sign-up', 'wc-wlfmc-wishlist' ),
												'custom-link' => __( 'Custom url', 'wc-wlfmc-wishlist' ),
											),
											'default' => array(
												array(
													'label'             => __( 'Login', 'wc-wlfmc-wishlist' ),
													'background'        => '#555555',
													'background-hover'  => '#555555',
													'label-color'       => '#ffffff',
													'label-hover-color' => '#ffffff',
													'border-radius'     => '2px',
													'link'              => 'login',
													'custom-link'       => '',
												),
												array(
													'label'             => __( 'Sign-up', 'wc-wlfmc-wishlist' ),
													'background'        => 'rgba(0,0,0,0)',
													'background-hover'  => 'rgba(0,0,0,0)',
													'label-color'       => '#7e7e7e',
													'label-hover-color' => '#7e7e7e',
													'border-radius'     => '2px',
													'link'              => 'signup',
													'custom-link'       => '',
												),
											),
											'limit'   => 3,
										),
										'login_notice_background_color'     => array(
											'label'   => __( 'Background color', 'wc-wlfmc-wishlist' ),
											'type'    => 'color',
											'help'    => __( 'We suggest you choose red, orange and yellow.', 'wc-wlfmc-wishlist' ),
											'default' => '#f6f6f6',
										),
										'end-article-login-notice'          => array(
											'type' => 'end',
										),
										'start-article-share'               => array(
											'type'         => 'start',
											'title'        => __( 'Share Settings', 'wc-wlfmc-wishlist' ),
											'dependencies' => array(
												'id'    => 'enable_share',
												'value' => '1',
											),
											'desc'         => __( 'By activating this feature, your users can share their wishlist with their friends and acquaintances. This is a free branding for your website.', 'wc-wlfmc-wishlist' )
										),

										'share_items'       => array(
											'label'   => __( 'Active share buttons', 'wc-wlfmc-wishlist' ),
											'desc'    => __( 'Which social media icons show on the sharing bar?', 'wc-wlfmc-wishlist' ),
											'type'    => 'checkbox-group',
											'options' => array(
												'facebook'  => __( 'Facebook', 'wc-wlfmc-wishlist' ),
												'messenger' => __( 'Facebook messenger', 'wc-wlfmc-wishlist' ),
												'twitter'   => __( 'Twitter', 'wc-wlfmc-wishlist' ),
												'whatsapp'  => __( 'Whatsapp', 'wc-wlfmc-wishlist' ),
												'telegram'  => __( 'Telegram', 'wc-wlfmc-wishlist' ),
												'email'     => __( 'Email', 'wc-wlfmc-wishlist' ),
												'copy'      => __( 'Share link', 'wc-wlfmc-wishlist' ),
											),

											'default' => array(
												'facebook',
												'messenger',
												'twitter',
												'whatsapp',
												'telegram',
												'email',
												'copy'
											),
											'help'    => __( 'In what medias do you prefer your user to be able to share his / her wishlist?', 'wc-wlfmc-wishlist' )
										),
										'socials_title'     => array(
											'label'        => __( 'Sharing title', 'wc-wlfmc-wishlist' ),
											'desc'         => __( 'Wishlist title used for sharing', 'wc-wlfmc-wishlist' ),
											/* translators: %s: site name */
											'default'      => sprintf( __( 'My Wishlist on %s', 'wc-wlfmc-wishlist' ), get_bloginfo( 'name' ) ),
											'type'         => 'text',
											'dependencies' => array(
												array(
													'id'    => 'share_items',
													'value' => 'twitter,facebook,email',
												),
												array(
													'id'    => 'enable_share',
													'value' => '1',
												),
											),
											'help'         => __( 'Enter the title that you would like to display as your ad when your user is sharing it.', 'wc-wlfmc-wishlist' )
										),
										'socials_text'      => array(
											'label'        => __( 'Twitter text', 'wc-wlfmc-wishlist' ),
											'desc'         => __( 'Type the message you want to publish when you share your Wishlist on twitter', 'wc-wlfmc-wishlist' ),
											'type'         => 'textarea',
											'dependencies' => array(
												array(
													'id'    => 'share_items',
													'value' => 'twitter',
												),
												array(
													'id'    => 'enable_share',
													'value' => '1',
												),
											),
											'help'         => __( 'This text will be displayed on your user\'s Twitter when sharing.', 'wc-wlfmc-wishlist' )
										),
										'sharing_style'     => array(
											'section' => 'button-display',
											'label'   => __( 'Sharing style', 'wc-wlfmc-wishlist' ),
											'type'    => 'group-fields',
											'fields'  => array(
												'social_color'       => array(
													'label'   => __( 'Social color', 'wc-wlfmc-wishlist' ),
													'type'    => 'color',
													'default' => '#9c9c9c',
												),
												'social_hover_color' => array(
													'label'   => __( 'Social hover color', 'wc-wlfmc-wishlist' ),
													'type'    => 'color',
													'default' => '#515151',
												),
											),

										),
										'end-article-share' => array(
											'type' => 'end',

										),
									),
									'counter'       => array(
										'start-article-wishlist-counter-settings' => array(
											'type'       => 'start',
											'title'      => __( 'Wishlist product counter', 'wc-wlfmc-wishlist' ),
											'help'       => __( 'Wishlist product counter', 'wc-wlfmc-wishlist' ),
											'help_image' => MC_WLFMC_URL . 'assets/admin/img/help/counter.gif',
										),
										'counter_add_to_menu'                     => array(
											'label'   => __( 'Add counter to menu', 'wc-wlfmc-wishlist' ),
											'desc'    => __( 'Use shortcode to place it in the desired location <code>[wlfmc_wishlist_counter]</code>', 'wc-wlfmc-wishlist' ),
											'default' => '',
											'type'    => 'select',
											'class'   => 'select2-trigger',
											'options' => $this->get_wordpress_menus(),
											//'help'         => __( '', 'wc-wlfmc-wishlist' )
										),
										'counter_menu_position'                   => array(
											'label'        => __( 'Counter position (Menu item order)', 'wc-wlfmc-wishlist' ),
											//'desc'    => __( '', 'wc-wlfmc-wishlist' ),
											'type'         => 'number',
											'default'      => 100,
											'help'         => __( 'Allows you to add the wishlist counter as a menu item and apply its position.', 'wc-wlfmc-wishlist' ),
											'dependencies' => array(
												array(
													'id'    => 'counter_add_to_menu',
													'value' => count( $this->get_wordpress_menus() ) > 1 ? implode( ',', array_slice( array_keys( $this->get_wordpress_menus() ), 1 ) ) : 'disable',
												),
											),
										),
										'counter_icon'                            => array(
											'label'   => __( '"wishlist" counter icon', 'wc-wlfmc-wishlist' ),
											'type'    => 'select-icon',
											'class'   => 'select2-trigger',
											'options' => array(
												'heart'  => array(
													'title' => __( 'Heart', 'wc-wlfmc-wishlist' ),
													'image' => '<span class="d-flex space-between f-center"><img src="' . MC_WLFMC_URL . 'assets/images/heart.svg" width="15" height="15" style="margin:0  5px"/><img src="' . MC_WLFMC_URL . 'assets/images/heart-o.svg" width="15" height="15" /></span>',
												),
												'tag'    => array(
													'title' => __( 'Save', 'wc-wlfmc-wishlist' ),
													'image' => '<span class="d-flex space-between f-center"><img src="' . MC_WLFMC_URL . 'assets/images/tag.svg" width="15" height="15" style="margin:0  5px"/><img src="' . MC_WLFMC_URL . 'assets/images/tag-o.svg" width="15" height="15" /></span>',
												),
												'plus'   => array(
													'title' => __( 'Plus', 'wc-wlfmc-wishlist' ),
													'image' => '<span class="d-flex space-between f-center"><img src="' . MC_WLFMC_URL . 'assets/images/plus.svg" width="15" height="15" style="margin:0  5px"/><img src="' . MC_WLFMC_URL . 'assets/images/plus-o.svg" width="15" height="15" /></span>',
												),
												'gift'   => array(
													'title' => __( 'Gift', 'wc-wlfmc-wishlist' ),
													'image' => '<span class="d-flex space-between f-center"><img src="' . MC_WLFMC_URL . 'assets/images/gift.svg" width="15" height="15" style="margin:0  5px"/><img src="' . MC_WLFMC_URL . 'assets/images/gift-o.svg" width="15" height="15" /></span>',
												),
												'star'   => array(
													'title' => __( 'Star', 'wc-wlfmc-wishlist' ),
													'image' => '<span class="d-flex space-between f-center"><img src="' . MC_WLFMC_URL . 'assets/images/star.svg" width="15" height="15" style="margin:0  5px"/><img src="' . MC_WLFMC_URL . 'assets/images/star-o.svg" width="15" height="15" /></span>',
												),
												'pin'    => array(
													'title' => __( 'Pin', 'wc-wlfmc-wishlist' ),
													'image' => '<span class="d-flex space-between f-center"><img src="' . MC_WLFMC_URL . 'assets/images/pin.svg" width="15" height="15" style="margin:0  5px"/><img src="' . MC_WLFMC_URL . 'assets/images/pin-o.svg" width="15" height="15" /></span>',
												),
												'custom' => __( 'Custom icon', 'wc-wlfmc-wishlist' ),
											),
											'default' => 'heart',
										),
										'counter_icon_svg_zero'                   => array(
											'label'             => __( 'Custom zero icon svg', 'wc-wlfmc-wishlist' ),
											'type'              => 'textarea',
											'custom_attributes' => array(
												'cols' => '120',
												'rows' => '3'
											),
											'dependencies'      => array(
												array(
													'id'    => 'counter_icon',
													'value' => 'custom',
												)
											),
											'help'              => __( 'Define a custom icon for when no product is added to the wishlist', 'wc-wlfmc-wishlist' ),
											'desc'              => __( 'Open your SVG file on a notepad and copy the code on this field.Please input the SVG code with your desired color.', 'wc-wlfmc-wishlist' ),
										),
										'counter_icon_svg_added'                  => array(
											'label'             => __( 'Custom added icon svg', 'wc-wlfmc-wishlist' ),
											'type'              => 'textarea',
											'custom_attributes' => array(
												'cols' => '120',
												'rows' => '3'
											),
											'dependencies'      => array(
												array(
													'id'    => 'counter_icon',
													'value' => 'custom',
												)
											),
											'help'              => __( 'Define a custom icon for when at least one product is on the wishlist', 'wc-wlfmc-wishlist' ),
											'desc'              => __( 'Open your SVG file on a notepad and copy the code on this field.Please input the SVG code with your desired color.', 'wc-wlfmc-wishlist' ),
										),
										'counter_icon_width'                      => array(
											'label'             => __( 'Icon width', 'wc-wlfmc-wishlist' ),
											'type'              => 'text',
											'default'           => '24px',
											'dependencies'      => array(
												array(
													'id'    => 'counter_icon',
													'value' => 'custom',
												)
											),
											'custom_attributes' => array(
												'style' => 'width:80px'
											)
										),
										'enable_counter_text'                     => array(
											'label'   => __( 'Show "wishlist" counter text', 'wc-wlfmc-wishlist' ),
											//'desc'    => __( '', 'wc-wlfmc-wishlist' ),
											'type'    => 'switch',
											'default' => '0',
											//'help'    => __( '', 'wc-wlfmc-wishlist' )
										),
										'counter_text'                            => array(
											'label'        => __( '"wishlist" counter text', 'wc-wlfmc-wishlist' ),
											'type'         => 'text',
											'default'      => __( 'Wishlist - ', 'wc-wlfmc-wishlist' ),
											'dependencies' => array(
												array(
													'id'    => 'enable_counter_text',
													'value' => '1',
												),
											),
										),
										'enable_counter_products_number'          => array(
											'label'   => __( 'Show number of products in counter', 'wc-wlfmc-wishlist' ),
											//'desc'    => __( '', 'wc-wlfmc-wishlist' ),
											'type'    => 'switch',
											'default' => '1',
											//'help'    => __( '', 'wc-wlfmc-wishlist' )
										),
										'hide_counter_zero_products_number'       => array(
											'label'        => __( 'Hide zero value', 'wc-wlfmc-wishlist' ),
											//'desc'    => __( '', 'wc-wlfmc-wishlist' ),
											'type'         => 'switch',
											'default'      => '1',
											//'help'    => __( '', 'wc-wlfmc-wishlist' ),
											'dependencies' => array(
												array(
													'id'    => 'enable_counter_products_number',
													'value' => '1',
												),
											),
										),
										'counter_products_number_position'        => array(
											'label'        => __( 'Products number position', 'wc-wlfmc-wishlist' ),
											//'desc'         => __( '', 'wc-wlfmc-wishlist' ),
											'default'      => 'right',
											'type'         => 'select',
											'options'      => array(
												'right'     => __( 'Right side of the text', 'wc-wlfmc-wishlist' ),
												'left'      => __( 'Left side of the text', 'wc-wlfmc-wishlist' ),
												'top-right' => __( 'On icon - top right', 'wc-wlfmc-wishlist' ),
												'top-left'  => __( 'On icon - top left', 'wc-wlfmc-wishlist' ),
											),
											'dependencies' => array(
												array(
													'id'    => 'enable_counter_products_number',
													'value' => '1',
												),
											),
											//'help'         => __( '', 'wc-wlfmc-wishlist' )
										),


										'enable_counter_mini_wishlist_dropdown' => array(
											'label'   => __( 'Show dropdown with mini wishlist', 'wc-wlfmc-wishlist' ),
											//'desc'    => __( '', 'wc-wlfmc-wishlist' ),
											'type'    => 'switch',
											'default' => '1',
											//'help'    => __( '', 'wc-wlfmc-wishlist' )
										),
										'enable_counter_add_link_title'         => array(
											'label'        => __( 'Add Link For "Wishlist" Counter Title', 'wc-wlfmc-wishlist' ),
											//'desc'    => __( '', 'wc-wlfmc-wishlist' ),
											'type'         => 'switch',
											'default'      => '1',
											//'help'    => __( '', 'wc-wlfmc-wishlist' ),
											'dependencies' => array(
												array(
													'id'    => 'enable_counter_mini_wishlist_dropdown',
													'value' => '0',
												),
											),
										),
										'counter_per_page_products_count'       => array(
											'label'        => __( 'Maximum products in mini wishlist', 'wc-wlfmc-wishlist' ),
											//'desc'    => __( '', 'wc-wlfmc-wishlist' ),
											'type'         => 'number',
											'default'      => 4,
											//'help'    => __( '', 'wc-wlfmc-wishlist' ),
											'dependencies' => array(
												array(
													'id'    => 'enable_counter_mini_wishlist_dropdown',
													'value' => '1',
												),
											),
										),
										'counter_mini_wishlist_link_position'   => array(
											'label'        => __( 'Wishlist link position in mini wishlist', 'wc-wlfmc-wishlist' ),
											//'desc'         => __( '', 'wc-wlfmc-wishlist' ),
											'default'      => 'after',
											'type'         => 'select',
											'options'      => array(
												'after'  => __( 'After products', 'wc-wlfmc-wishlist' ),
												'before' => __( 'Before products', 'wc-wlfmc-wishlist' ),
											),
											'dependencies' => array(
												array(
													'id'    => 'enable_counter_mini_wishlist_dropdown',
													'value' => '1',
												),
											),
											//'help'         => __( '', 'wc-wlfmc-wishlist' )
										),

										'counter_style'                         => array(
											'section' => 'button-display',
											'label'   => __( 'Counter and mini wishlist style', 'wc-wlfmc-wishlist' ),
											'type'    => 'group-fields',
											'fields'  => array(
												'counter_color'            => array(
													'label'   => __( 'Icon color', 'wc-wlfmc-wishlist' ),
													'type'    => 'color',
													'default' => '#333',
												),
												'counter_text_color'       => array(
													'label'        => __( 'Text color', 'wc-wlfmc-wishlist' ),
													'type'         => 'color',
													'default'      => '#333',
													'dependencies' => array(
														array(
															'id'    => 'enable_counter_text',
															'value' => '1',
														),
													),
												),
												'counter_background_color' => array(
													'label'   => __( 'Background color', 'wc-wlfmc-wishlist' ),
													'type'    => 'color',
													'default' => '#fff',
												),
												'counter_border_color'     => array(
													'label'   => __( 'Border color', 'wc-wlfmc-wishlist' ),
													'type'    => 'color',
													'default' => '#f5f5f5',
												),
												'counter_border_radius'    => array(
													'label'             => __( 'Border radius', 'wc-wlfmc-wishlist' ),
													'type'              => 'text',
													'default'           => '5px',
													'custom_attributes' => array(
														'style' => 'width:80px'
													)
												),
											),
											'desc'    => __( 'write like 10px, 15rem, 13em etc.', 'wc-wlfmc-wishlist' ),
										),
										'counter_button_colors'                 => array(
											'label'   => __( 'Mini wishlist button colors', 'wc-wlfmc-wishlist' ),
											'type'    => 'color-style',
											'default' => array(
												'color'            => '#515151',
												'color-hover'      => '#fff',
												'background'       => '#ebebeb',
												'background-hover' => '#e67e22',
												'border'           => 'rgb(0,0,0,0)',
												'border-hover'     => 'rgb(0,0,0,0)',
											),
										),
										'counter_button_sizes'                  => array(
											'label'  => __( 'Mini wishlist button sizes', 'wc-wlfmc-wishlist' ),
											'type'   => 'group-fields',
											'fields' => array(
												'counter_button_font_size'    => array(
													'label'             => __( 'Font size', 'wc-wlfmc-wishlist' ),
													'type'              => 'text',
													'default'           => '15px',
													'custom_attributes' => array(
														'style' => 'width:80px'
													)
												),
												'counter_button_height'       => array(
													'label'             => __( 'Height', 'wc-wlfmc-wishlist' ),
													'type'              => 'text',
													'default'           => '38px',
													'custom_attributes' => array(
														'style' => 'width:80px'
													)
												),
												'counter_button_border_width' => array(
													'label'             => __( 'Border width', 'wc-wlfmc-wishlist' ),
													'type'              => 'text',
													'default'           => '1px',
													'custom_attributes' => array(
														'style' => 'width:80px'
													)
												),

												'counter_button_border_radius' => array(
													'label'             => __( 'border radius', 'wc-wlfmc-wishlist' ),
													'type'              => 'text',
													'default'           => '5px',
													'custom_attributes' => array(
														'style' => 'width:80px'
													),
													'help_image'        => MC_WLFMC_URL . 'assets/admin/img/help/border_radius.gif',
													'help'              => __( 'You can define the radius for all 4 corners of the button (look at the gif)', 'wc-wlfmc-wishlist' ),

												),
											),
											'desc'   => __( 'write like 10px, 15rem, 13em etc.', 'wc-wlfmc-wishlist' ),
										),
										'counter_button_text'                   => array(
											'label'   => __( 'Mini wishlist button text', 'wc-wlfmc-wishlist' ),
											'type'    => 'text',
											'default' => __( 'View My Wishlist', 'wc-wlfmc-wishlist' ),
										),
										'counter_total_text'                    => array(
											'label'   => __( '"Total product" text', 'wc-wlfmc-wishlist' ),
											'type'    => 'text',
											'default' => __( 'Total products', 'wc-wlfmc-wishlist' ),
										),
										'end-article-wishlist-counter-settings' => array(
											'type' => 'end',
										),
									),
									'advanced'      => array(
										'start-article-wishlist-advanced-settings' => array(
											'type'  => 'start',
											'title' => __( 'Advanced settings', 'wc-wlfmc-wishlist' ),
											'desc'  => __( 'These settings are not necessary and you can use them if you want.', 'wc-wlfmc-wishlist' ),
										),
										'login_url'                                => array(
											'label'   => __( 'Login URL', 'wc-wlfmc-wishlist' ),
											'default' => wp_login_url(),
											'desc'    => __( 'This link is used in places where the user will be invited to login.', 'wc-wlfmc-wishlist' ),
											'type'    => 'url',
											'help'    => __( 'if you use default wordpress login page, Leave the field.', 'wc-wlfmc-wishlist' ),
										),
										'signup_url'                               => array(
											'label'   => __( 'Sign-up URL', 'wc-wlfmc-wishlist' ),
											'default' => wp_registration_url(),
											'desc'    => __( 'This link is used in places where the user will be invited to Sign-up.', 'wc-wlfmc-wishlist' ),
											'type'    => 'url',
											'help'    => __( 'if you use default wordpress sign-up page, Leave the field.', 'wc-wlfmc-wishlist' ),
										),
										'email_per_hours'                          => array(
											'label'   => __( 'Email sent per hours', 'wc-wlfmc-wishlist' ),
											'default' => 20,
											'type'    => 'number',
											'help'    => __( ' By default, 20 emails from Wishlist email marketing options are sent to users every hour. If you want to change this number, ask your hosting support for the permissible Emails per Hour and consider emails sent from other plugins such as WooCommerce orders.', 'wc-wlfmc-wishlist' ),
										),
										'ajax_mode'                                => array(
											'label'   => __( 'Type of ajax operations', 'wc-wlfmc-wishlist' ),
											'type'    => 'select',
											'class'   => 'select2-trigger',
											'options' => array(
												'admin-ajax.php' => __( 'admin-ajax.php', 'wc-wlfmc-wishlist' ),
												'wp_loaded'      => __( 'wp loaded hook', 'wc-wlfmc-wishlist' ),
												'rest_api'       => __( 'Wp rest api', 'wc-wlfmc-wishlist' ),
											),
											'default' => 'admin-ajax.php',
										),
										'ajax_loading'                             => array(
											'label'   => __( 'Show loading Ajax operations', 'wc-wlfmc-wishlist' ),
											'type'    => 'switch',
											'default' => '1',
										),

										'live_chat'                              => array(
											'label'   => __( 'Live support chat', 'wc-wlfmc-wishlist' ),
											'type'    => 'switch',
											'default' => '0',
											'help'    => __( 'With this option enabled, you can ask us your questions from the chat box inside the plugin, and we will solve your problem quickly', 'wc-wlfmc-wishlist' )
										),
										'reset_sending_cycles'                   => array(
											'label'   => __( 'Reset Sending Cycles', 'wc-wlfmc-wishlist' ),
											'type'    => 'button',
											'class'   => 'wlfmc-reset-sending-cycles',
											'default' => __( 'Reset', 'wc-wlfmc-wishlist' ),
											'help'    => __( 'All previous cycle between complete automation and running a new automation will be cleared and all automation cycle rules will be cleared for all users.', 'wc-wlfmc-wishlist' )
										),
										'remove_all_data'                        => array(
											'label' => __( 'Remove all data', 'wc-wlfmc-wishlist' ),
											'desc'  => __( 'Uncheck , if you want to prevent data loss when deleting the plugin', 'wc-wlfmc-wishlist' ),
											'type'  => 'checkbox',
										),
										'end-article-wishlist-advanced-settings' => array(
											'type' => 'end',
										),
									)
								),
							),
						)
					),
					'title'          => __( 'MC Wishlist', 'wc-wlfmc-wishlist' ),
					'logo'           => '<img src="' . MC_WLFMC_URL . 'assets/images/logo.svg" width="45" height="40" />',
					'header_buttons' => array(
						array(
							'btn_label' => __( 'Easy to Use Guide', 'wc-wlfmc-wishlist' ),
							'btn_class' => ' ico-btn support-btn btn-primary',
							'btn_url'   => 'https://moreconvert.com/smart-wishlist-for-more-convert-documentation/',
						),
					),
					'type'           => 'setting-type',
					'id'             => 'wlfmc_options',
					'sidebar'        => array(
						$this->random_tips(),
						array(
							'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/diamond.svg" width="63" height="55" />',
							'title'   => __( 'Premium Wishlist', 'wc-wlfmc-wishlist' ),
							'content' => __( 'If you want to have a more advanced Wishlist and at the same time increase sales without more traffic, be sure to check out the Pro version.', 'wc-wlfmc-wishlist' ),
							'button'  => array(
								'btn_label' => __( 'Check now', 'wc-wlfmc-wishlist' ),
								'btn_url'   => 'https://moreconvert.com/product/wishlist/',
								'btn_class' => 'btn-primary min-width-btn ',
							)
						),
						array(
							'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/youtube.svg" width="80" height="55" />',
							'title'   => __( 'WordPress & Sales', 'wc-wlfmc-wishlist' ),
							'content' => __( 'Learn 3 new videos every week about troubleshooting WordPress and increasing revenue from your WooCommerce website.', 'wc-wlfmc-wishlist' ),
							'button'  => array(
								'btn_label' => __( 'Start Growing', 'wc-wlfmc-wishlist' ),
								'btn_url'   => 'https://moreconvert.com/youtube',
								'btn_class' => 'btn-primary min-width-btn red-btn',
							)
						),
					),
				);

				$this->steps_options = array(
					'steps' => apply_filters(
						'wlfmc_admin_steps',
						array(
							'welcome' => array(
								'steptitle' => __( 'Welcome', 'wc-wlfmc-wishlist' ),
								'title'     => __( 'Welcome To More Convert Challenge!', 'wc-wlfmc-wishlist' ),
								'subtitle'  => __( 'How to Sell More Without More Traffic?', 'wc-wlfmc-wishlist' ),
								'content'   => __( 'You made the best decision by choosing the MC Wishlist; our goal is you can sell more, not to entertain your user with some buttons and lists 😉 Ready to have some simple settings together?', 'wc-wlfmc-wishlist' ),
							),
							'step-1'  => array(
								'steptitle'   => __( 'Page Setup', 'wc-wlfmc-wishlist' ),
								'title'       => __( 'Page Setup Options', 'wc-wlfmc-wishlist' ),
								'top_desc'    => __( 'Select a Page to show the Wishlist page, where users\' Wishlist is displayed there to them.If you do not have a page, leave the field free to be created automatically.', 'wc-wlfmc-wishlist' ),
								'bottom_desc' => __( 'All settings of this step and the next steps can be changed through the WordPress dashboard.', 'wc-wlfmc-wishlist' ),
								'fields'      => array(

									'wishlist_page_title'          => array(
										'section' => 'button-display',
										'label'   => __( 'Wishlist page name', 'wc-wlfmc-wishlist' ),
										'default' => __( 'My Wishlist', 'wc-wlfmc-wishlist' ),
										'type'    => 'text',

									),
									'who_can_see_wishlist_options' => array(
										'section' => 'button-display',
										'label'   => __( 'Enable Wishlist for', 'wc-wlfmc-wishlist' ),
										'type'    => 'select',
										'class'   => 'select2-trigger',
										'options' => array(
											'all'   => __( 'All users', 'wc-wlfmc-wishlist' ),
											'users' => __( 'Logined users', 'wc-wlfmc-wishlist' ),
										),
										'default' => 'all',
									),
								)
							),
							'step-2'  => array(
								'steptitle'   => __( 'Button', 'wc-wlfmc-wishlist' ),
								'title'       => __( 'Button Options', 'wc-wlfmc-wishlist' ),
								'top_desc'    => __( 'Choose where the Add to Wishlist button is displayed on the product page and the listings (like the shop page).', 'wc-wlfmc-wishlist' ),
								'bottom_desc' => __( 'You can change the color and icon of the button later from MC Wishlist settings > Button tab', 'wc-wlfmc-wishlist' ),
								'fields'      => array(
									'wishlist_button_position' => array(
										'section' => 'button-display',
										'label'   => __( 'Button position on product page', 'wc-wlfmc-wishlist' ),
										'type'    => 'select',
										'class'   => 'select2-trigger',
										'options' => array(
											'before_add_to_cart' => __( 'Before "add to cart"', 'wc-wlfmc-wishlist' ),
											'after_add_to_cart'  => __( 'After "add to cart"', 'wc-wlfmc-wishlist' ),
											//'thumbnails'         => __( 'On top of the image', 'wc-wlfmc-wishlist' ),
											'image_top_left'     => __( 'On image - top left', 'wc-wlfmc-wishlist' ),
											'image_top_right'    => __( 'On image - top right', 'wc-wlfmc-wishlist' ),
											'image_bottom_left'  => __( 'On image - bottom left', 'wc-wlfmc-wishlist' ),
											'image_bottom_right' => __( 'On image - bottom right', 'wc-wlfmc-wishlist' ),
											'summary'            => __( 'After summary', 'wc-wlfmc-wishlist' ),
											'shortcode'          => __( 'Use shortcode', 'wc-wlfmc-wishlist' ),
										),
									),
									'loop_position'            => array(
										'section' => 'button-display',
										'label'   => __( 'Button position on listing', 'wc-wlfmc-wishlist' ),
										'default' => 'after_add_to_cart',
										'type'    => 'select',
										'class'   => 'select2-trigger',
										'options' => array(
											//'before_image'       => __( 'On top of the image', 'wc-wlfmc-wishlist' ),
											'image_top_left'     => __( 'On image - top left', 'wc-wlfmc-wishlist' ),
											'image_top_right'    => __( 'On image - top right', 'wc-wlfmc-wishlist' ),
											'before_add_to_cart' => __( 'Before "add to cart" button', 'wc-wlfmc-wishlist' ),
											'after_add_to_cart'  => __( 'After "add to cart" button', 'wc-wlfmc-wishlist' ),
											'shortcode'          => __( 'Use shortcode', 'wc-wlfmc-wishlist' ),
										),
									),
									'button_label_add'         => array(
										'section' => 'button-display',
										'label'   => __( '"Add To Wishlist" text', 'wc-wlfmc-wishlist' ),
										'type'    => 'text',
										'default' => __( 'Add To Wishlist', 'wc-wlfmc-wishlist' ),
									),
								)
							),
							'step-3'  => array(
								'steptitle'   => __( 'Processing', 'wc-wlfmc-wishlist' ),
								'title'       => __( 'Processing Options', 'wc-wlfmc-wishlist' ),
								'top_desc'    => __( 'Adjust the behavior of the Wishlist button after clicking on it and after clicking again.', 'wc-wlfmc-wishlist' ),
								'bottom_desc' => __( 'you can change the pop up details and other settings from MC Wishlist > setting > general', 'wc-wlfmc-wishlist' ),
								'fields'      => array(
									'click_wishlist_button_behavior' => array(
										'section' => 'button-display',
										'label'   => __( 'After clicking button', 'wc-wlfmc-wishlist' ),
										'type'    => 'select',
										'class'   => 'select2-trigger',
										'options' => array(
											'open-popup'   => __( 'Open the pop up', 'wc-wlfmc-wishlist' ),
											'just-add'     => __( 'Just add it to Wishlist', 'wc-wlfmc-wishlist' ),
											'add-redirect' => __( 'Add and redirect to Wishlist page', 'wc-wlfmc-wishlist' ),
										),
									),
									'remove_after_second_click'      => array(
										'section' => 'button-display',
										'label'   => __( 'Remove after second click', 'wc-wlfmc-wishlist' ),
										'help'    => __( 'Remove Product From Wishlist On Second Click', 'wc-wlfmc-wishlist' ),
										'type'    => 'switch',
									),
									/*'remove_after_add_to_cart' => array(
										'section' => 'button-display',
										'label'   => __( 'Automatic remove after adding to cart', 'wc-wlfmc-wishlist' ),
										'type'    => 'switch',
									),*/
									'remove_from_wishlist'           => array(
										'section' => 'button-display',
										'label'   => __( 'Remove from the wishlist if', 'wc-wlfmc-wishlist' ),
										'type'    => 'select',
										'class'   => 'select2-trigger',
										'options' => array(
											'none'          => __( 'Do not remove', 'wc-wlfmc-wishlist' ),
											'added-to-cart' => __( 'Added to the card', 'wc-wlfmc-wishlist' ),
											'completed'     => __( 'Purchase completed', 'wc-wlfmc-wishlist' ),
											'purchased'     => __( 'Purchase Processing', 'wc-wlfmc-wishlist' ),
										),
									),
								)
							),
							'step-4'  => array(
								'steptitle'   => __( 'Marketing', 'wc-wlfmc-wishlist' ),
								'title'       => __( 'Marketing Options', 'wc-wlfmc-wishlist' ),
								'bottom_desc' => __( 'you can change the marketing details  from MC Wishlist > Marketing', 'wc-wlfmc-wishlist' ),
								'fields'      => array(
									'enable_share' => array(
										'section' => 'button-display',
										'label'   => __( 'Users share their Wishlist on social media', 'wc-wlfmc-wishlist' ),
										'type'    => 'switch',
									),
								)
							),
							'last'    => array(
								'steptitle'   => __( 'Support', 'wc-wlfmc-wishlist' ),
								'title'       => __( 'Support Options', 'wc-wlfmc-wishlist' ),
								'bottom_desc' => __( 'Your satisfaction is very important to us, if you have an idea, problem or question, let us know, we will try to answer you very quickly.<br>Our goal and yours is to increase sales, I hope we succeed in this challenge.', 'wc-wlfmc-wishlist' ),
								'fields'      => array(
									'live_chat'    => array(
										'section' => 'button-display',
										'label'   => __( 'Enable support chat option to get fast and online support', 'wc-wlfmc-wishlist' ),
										'type'    => 'switch',
										'default' => '1'
									),
									'enable_track' => array(
										'section' => 'button-display',
										'label'   => __( 'I want to get more and better features of this plugin with data track permission (non-personal) to help improve it.', 'wc-wlfmc-wishlist' ),
										'type'    => 'switch',
										'default' => '1'
									),
								)
							),
							'ready'   => array(
								'steptitle' => __( 'Ready!', 'wc-wlfmc-wishlist' ),
								'title'     => __( 'Congratulations! Everything is set!', 'wc-wlfmc-wishlist' ),
								'content'   => __( 'You can have more and more detailed settings from the plugin settings.<br>This plugin is very powerful, and we are developing it tremendously to work on your sales in various ways.<br>To support us, be sure to keep the plugin active and let us know your ideas.', 'wc-wlfmc-wishlist' ),
								'buttons'   => array(

									array(
										'btn_label' => __( 'View Documention', 'wc-wlfmc-wishlist' ),
										'btn_class' => 'btn-primary',
										'btn_url'   => 'https://moreconvert.com/smart-wishlist-for-more-convert-documentation',
									),
									array(
										'btn_label' => __( 'Request Support', 'wc-wlfmc-wishlist' ),
										'btn_class' => 'btn-primary purplelight-btn ',
										'btn_url'   => 'https://moreconvert.com/support/',
									),
								),
							),
						)
					),
					'title' => __( 'MC Wishlist', 'wc-wlfmc-wishlist' ),
					'logo'  => '<img src="' . MC_WLFMC_URL . 'assets/images/logo.svg" width="45" height="40" />',
					'type'  => 'wizard-type',
					'id'    => 'wlfmc_options',
				);

				$this->tool_options = array(
					'tools'          => apply_filters(
						'wlfmc_marketing_toolkits',
						array(
							'email-automation' => array(
								'title' => __( 'Email Automation', 'wc-wlfmc-wishlist' ),
								'image' => '<svg class="icon"><use xlink:href="' . MC_WLFMC_URL . 'assets/admin/img/sprite.svg#email-automation"></use></svg>',
								'url'   => add_query_arg( 'tools', 'email-automation' ),
								'desc'  => __( 'Set up once to send emails to users based on your terms', 'wc-wlfmc-wishlist' ),
							),
							'email-campaign'   => array(
								'title'     => __( 'Email Campaign', 'wc-wlfmc-wishlist' ),
								'pro_label' => __( 'Pro', 'wc-wlfmc-wishlist' ),
								'image'     => '<svg class="icon"><use xlink:href="' . MC_WLFMC_URL . 'assets/admin/img/sprite.svg#email-campaign"></use></svg>',
								'popup'     => array(
									'image_url' => MC_WLFMC_URL . 'assets/admin/img/popup.svg',
									'title'     => __( 'More Options, More Income', 'wc-wlfmc-wishlist' ),
									'desc'      => __( 'Install the  premium version right now<br>to multiply your site revenue with<br>advanced and professional tools.', 'wc-wlfmc-wishlist' ),
									'buttons'   => array(
										array(
											'btn_label' => __( 'Get Now', 'wc-wlfmc-wishlist' ),
											'btn_url'   => 'https://moreconvert.com/youtube',
											'btn_class' => 'btn-primary orange-btn',
										),
										array(
											'btn_label' => __( 'Watch now', 'wc-wlfmc-wishlist' ),
											'btn_url'   => 'https://moreconvert.com/youtube',
											'btn_class' => 'orange-link',
										),
									)
								),
								'desc'      => __( 'Send emails to your selected subscribers', 'wc-wlfmc-wishlist' ),
							),
							/*'smart-sidebar'    => array(
								'title'     => __( 'Smart Sidebar', 'wc-wlfmc-wishlist' ),
								'image'     => '<svg class="icon"><use xlink:href="' . MC_WLFMC_URL . 'assets/admin/img/sprite.svg#smart-sidebar"></use></svg>',
								'pro_label' => __( 'Soon', 'wc-wlfmc-wishlist' ),


							),
							'smart-popup'      => array(
								'title'   => __( 'Smart Pop up', 'wc-wlfmc-wishlist' ),
								'image'   => '<svg class="icon"><use xlink:href="' . MC_WLFMC_URL . 'assets/admin/img/sprite.svg#smart-popup"></use></svg>',
								'pro_label' => __( 'Soon', 'wc-wlfmc-wishlist' ),

							),
							'smart-stickybar'  => array(
								'title'   => __( 'Smart Stickybar', 'wc-wlfmc-wishlist' ),
								'image'   => '<svg class="icon"><use xlink:href="' . MC_WLFMC_URL . 'assets/admin/img/sprite.svg#smart-stickybar"></use></svg>',
								'pro_label' => __( 'Soon', 'wc-wlfmc-wishlist' ),

							),
							'warm-call'        => array(
								'title'   => __( 'Warm Call', 'wc-wlfmc-wishlist' ),
								'image'   => '<svg class="icon"><use xlink:href="' . MC_WLFMC_URL . 'assets/admin/img/sprite.svg#warm-call"></use></svg>',
								'pro_label' => __( 'Soon', 'wc-wlfmc-wishlist' ),

							),
							'integration'      => array(
								'title'   => __( 'Integration', 'wc-wlfmc-wishlist' ),
								'image'   => '<svg class="icon"><use xlink:href="' . MC_WLFMC_URL . 'assets/admin/img/sprite.svg#integration"></use></svg>',
								'pro_label' => __( 'Soon', 'wc-wlfmc-wishlist' ),

							),*/

						)
					),
					'title'          => __( 'MC Wishlist', 'wc-wlfmc-wishlist' ),
					'subtitle'       => __( 'MC Marketing Toolkit', 'wc-wlfmc-wishlist' ),
					'desc'           => __( 'Select A Tool To Increase Your Sale', 'wc-wlfmc-wishlist' ),
					'logo'           => '<img src="' . MC_WLFMC_URL . 'assets/images/logo.svg" width="45" height="40" />',
					'type'           => 'tools-type',
					'header_buttons' => array(
						array(
							'btn_label' => __( 'Easy to Use Guide', 'wc-wlfmc-wishlist' ),
							'btn_class' => ' ico-btn support-btn btn-primary',
							'btn_url'   => 'https://moreconvert.com/smart-wishlist-for-more-convert-documentation/',
						),
					),

				);

				$this->main_panel = new MCT_Admin( $this->main_options );

				// load default value to options
				if ( empty( $this->main_panel->get_options() ) ) {
					$this->main_panel->set_default_options();
				}

			}

			add_action( 'admin_menu', array( $this, 'add_admin_menu' ) );
			add_action( 'admin_head', array( $this, 'remove_welcome_screen_menu' ) );
			add_action( 'admin_init', array( $this, 'welcome_screen_do_activation_redirect' ) );

			// add a post display state for special WC pages.
			add_filter( 'display_post_states', array( $this, 'add_display_post_states' ), 10, 2 );

			$plugin = plugin_basename( MC_WLFMC_MAIN_FILE );
			add_filter( "plugin_action_links_$plugin", array( $this, 'settings_link' ), 10, 1 );

			add_filter( 'plugin_row_meta', array( $this, 'plugin_row_meta' ), 10, 2 );


			add_action( 'mct_panel_after_wlfmc_options_update', array(
				$this,
				'update_remove_all_data_state'
			) );

			add_action( 'mct_panel_after_wlfmc_options_update', array(
				$this,
				'update_wishlist_page'
			) );

			add_action( 'wp_ajax_wlfmc_create_wishlist_page', array( $this, 'ajax_create_page_callback' ) );

			add_filter( 'mct_wizard_wlfmc_options_value', array( $this, 'save_wizard_options' ) );

		}

		/**
		 * Save wizard options
		 *
		 * @param $values
		 *
		 * @return array
		 *
		 * @since 1.3.0
		 */
		public function save_wizard_options( $values ) {

			$this->update_wishlist_page();


			if ( isset( $_POST['enable_track'] ) ) {

				$client = new Appsero\Client( '4fd3ce9d-2f72-4d4d-9344-ac3b11fb6a9c', 'MC Woocommerce Wishlist Plugin', __FILE__ );
				// optin insights
				$client->insights()->optin();
			}

			update_option( 'wlfmc_wizard', '1' );


			return $values;

		}

		/**
		 * Get all woocoommerce page ids.
		 *
		 * @return array
		 * @since 1.2.0
		 */
		public function get_all_wc_page_ids() {
			$ids   = array();
			$ids[] = get_option( 'woocommerce_shop_page_id' );
			$ids[] = get_option( 'woocommerce_cart_page_id' );
			$ids[] = get_option( 'woocommerce_checkout_page_id' );
			$ids[] = get_option( 'woocommerce_myaccount_page_id' );
			$ids[] = get_option( 'woocommerce_terms_page_id' );

			return $ids;
		}

		/**
		 * Add a post display state for special WC pages in the page list table.
		 *
		 * @param array $post_states An array of post display states.
		 * @param WP_Post $post The current post object.
		 *
		 * @return array
		 *
		 * @version 1.0.1
		 */
		public function add_display_post_states( $post_states, $post ) {

			if ( get_option( 'wlfmc_wishlist_page_id' ) == $post->ID ) {
				$post_states[] = __( 'Wishlist Page', 'wc-wlfmc-wishlist' );
			}

			return $post_states;
		}

		/**
		 * Update remove all data state after update plugin settigns.
		 *
		 * @since 1.0.1
		 */
		public function update_remove_all_data_state() {
			$state = isset( $_POST['remove_all_data'] ) ? wp_unslash( $_POST['remove_all_data'] ) : '';
			update_option( 'wlfmc_remove_all_data', $state );
		}

		/**
		 * Update wishlist page id after update plugin settigns.
		 *
		 * @since 1.3.0
		 */
		public function update_wishlist_page() {
			$id = isset( $_POST['wishlist_page'] ) ? intval( $_POST['wishlist_page'] ) : '';
			update_option( 'wlfmc_wishlist_page_id', $id );

			if ( isset( $_POST['wishlist_page_title'] ) && '' !== trim( $_POST['wishlist_page_title'] ) && isset( $_POST['wishlist_page'] ) && intval( $_POST['wishlist_page'] ) > 0 ) {
				$page_title = sanitize_text_field( $_POST['wishlist_page_title'] );
				$page_id    = get_option( 'wlfmc_wishlist_page_id' );
				wp_update_post( array(
					'ID'         => $page_id,
					'post_title' => $page_title,
				), false );

			}
		}

		/**
		 * Create wishlist page ajaxify.
		 *
		 * @since 1.0.1
		 */
		public function ajax_create_page_callback() {

			check_ajax_referer( 'ajax-nonce', 'key' );

			$id = wc_create_page(
				sanitize_title_with_dashes( _x( 'wishlist', 'page_slug', 'wc-wlfmc-wishlist' ) ),
				'wlfmc_wishlist_page_id',
				__( 'Wishlist', 'wc-wlfmc-wishlist' ),
				'<!-- wp:shortcode -->[wlfmc_wishlist]<!-- /wp:shortcode -->'
			);

			$options = new MCT_Options( 'wlfmc_options' );
			$options->update_option( 'wishlist_page', $id );

			echo wp_json_encode( array(
				'success' => true
			) );
			exit;
		}

		/**
		 * Get wordpress menus
		 *
		 * @return array
		 * @since 1.3.0
		 */
		public function get_wordpress_menus() {
			$menus     = array( '' => __( 'None', 'wc-wlfmc-wishlist' ) );
			$get_menus = get_terms( 'nav_menu', array( 'hide_empty' => true ) );
			foreach ( $get_menus as $menu ) {
				$menus[ $menu->term_id ] = $menu->name;
			}

			return $menus;
		}

		/**
		 * Random tips
		 *
		 * @return array
		 *
		 * @since 1.2.0
		 */
		public function random_tips() {

			$tips     = array(
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Calculate the average payment for each cart from WooCommerce reports, for 1.25 times the amount, offer free shipping for the cart to increase the average payment for each cart.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'For people who comment on your website, show a small photo of their face. This confirms social proof and proves that you did not create the comments yourself.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Add Twitter or Instagram usernames of your previous customers to let potential customers ensure the truth of the details of those you have mentioned as a buyer.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Place at least one trust signal at the bottom of your site. Local or international business certificates could be a wise choice.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Use the Google login system to simplify the payment process and allow users to buy from your website quickly without creating an account.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Most visitors will see the top left of the page at first glance. Place an opt-in offer at the top of the homepage, where people look before scrolling.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Remove all references to buy, price, and sell at the top of the page. Don\'t mention the purchase or expense before the reader becomes interested in the product.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Use bold and highlighted words in the product description to emphasize the best features. Subheadings and bullet lists also make the text easy to follow.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Put your products in limited categories or focus on a few brands. The fewer options you offer, the easier a user finds the product they are looking for.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Never make a testimonials page. They have low traffic since visitors don’t visit websites to read testimonials. Add them to the page of their related product.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Tell visitors how many customers you’ve helped. Specific numbers look more credible. It shows you know what you are doing.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Create a “best-selling” product category. Also, add information about popularity to the product descriptions of the bestsellers.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'A big price discount on the home page may put visitors in a price-sensitive mood. Make sure there is always at least one higher-priced product on your home page.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Use high-quality though small product images to make sure they load quickly. Neither Google nor visitors like waiting. Look for an image compressor site on Google.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'You can create YouTube videos beside the photo to show the product in action. Copy your YouTube video embed code and paste it onto your WordPress editor.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Design a simple pre-purchase registration form. Ask for customer’s name, email address, and phone number. If you sell physical products, you need location too.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Highlight your featured products on the homepage. You can do this by clicking the stars in the column hanging out in your list of products.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Do not hide your out-of-stock products. You can add a note saying the product becomes available soon and ask visitors’ email addresses to notify them instead.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Google likes fast-loading pages. Use tools like Google’s PageSpeed to analyze your WooCommerce page and follow the recommendations for speeding up your website.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Check customers’ activity. Send an email including your latest blog post or newest products for anyone whose last visit was more than a month ago.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'For your low-selling products, add a fixed product discount. Start with %25 for 2 weeks. If the sale remains low, increase the discount up to %40.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Look for the canceled purchases. If a product purchase is canceled more than 5 times, rewrite the product description with more features included.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Export the phone number of the last 7 days’ customers. Ask about their purchase and post-purchase experience on WhatsApp or via SMS.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Calculate the average payment for each cart from WooCommerce reports. For 1.25 times the amount, give free shipping to boost the average payment for each cart.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Study the hours your site receives the most traffic and the location of these sessions from Google Analytics. It\'s the best time to publish promotion blog posts.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Create an infographic for the best ways to use your product, including your logo in a visible location. Add it to the product page and share it on social media.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Send an email to a new customer who purchased a few days ago and suggest a related product, 15 days after their first purchase.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Write to a potential customer who has registered on your website, announcing a new product in your catalog with an exclusive 10% discount for the next 24 hours.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'If your online store also has offline customers at a physical location, provide your address and contact information to sign up to Google Places, free of charge.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Remove the navigation bar from the checkout process. This eliminates the opportunity to abandon the purchase and lowers the loss of sales.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'For customers with an average personal payment of more than AOV, set a %50 discount on your new inventory items. Then ask them to write their product reviews.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Look for the blog posts’ views, shares, and comments. On each post with an engagement rate more than average, add internal links to your newest products.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Use more than one photo for each product. Like for a clothing shop, upload an image of the clothing on a white background and a photo of a model wearing it.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Choose a warm color for the CTA button based on your website\'s dominant design color. Red, orange, or yellow can be good choices.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Find customers with incomplete orders using WooCommerce orders. Send them an email showing the star rating and reviews of the products in their abandoned cart.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Create landing pages optimized around profitable keywords, including your products or services. They target consumers who are far enough in the buyer’s journey.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Find your less popular items from inventory. Announce you only have a certain number of them in stock. This creates scarcity and puts pressure on visitors to buy.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'For limited-time coupons, try incorporating these words: Now, Hurry, Last chance, Before it’s gone, One time only, Limited time, Instant, Don’t miss out.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Include a bonus when customers buy within the next certain hours. This bonus can be a discount or one of your products.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Add free shipping with a deadline on your items. Define how much time they have to buy the product if they want to receive it the next day, for example.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Find your most abandoned items. Highlight the negative effects of not buying them in the item description. Talk about ease, affordability, and problem-solving.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Make a time-limited coupon to use in the emails you send to your members. You can add a navigating link in the email that activates the coupon when clicked.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Give a money-back guarantee in the checkout process to lower any barriers that prevent quick transactions during the sale.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Calculate the average value of your inventory items. For buying products with a price of more than that, add a “mystery item”, which is a lower-value product.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Break up the checkout into an expanding page including delivery, payment, and order summary to keep from overwhelming the customer with buyer information fields.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Keep the text concise in the checkout process. Use standard buttons and vocabulary, such as a “Buy” button and a shopping cart icon.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Address common challenges or ways to use your products in your blog. Writing about your products shows information, but mentioning functions creates FOMO.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Do not limit the payment methods. Include Apple Pay, Google Pay, giropay, Sofort, iDeal, SEPA, P24, and Bancontact using WooCommerce payments.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Offer additional products during the checkout process. But after placing the order, include coupons with an expiry date in the “Thank You” email instead of items.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'If you are a service provider, add a name for each plan in your tier. Calling a plan “Pro” or “Premium” inspires them to pay more for that service.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Set a flat-rate shipping fee for your store based on AOV and shipping costs. This gives your customers greater predictability around the delivery cost.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Offer customers a bonus for purchasing on their birthday. A 50% discount coupon or their favorite product for a free additional item seems inducing.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Make font sizes larger. Increasing the body font size to 13pt and improving the spacing between the characters and lines will lead to better engagement results.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Use Readability Test Tools to indicate homepage and product description copy. It should be understood by 10 to 11-year-olds.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Divide customers who browse but don’t buy, who abandon carts, and who buy more than 3 orders into groups. Send them personalized re-engagement newsletters.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Check your rival\'s product copies. Highlight some features that none of them have mentioned. You can add a comparison between your product and others too.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Set the prices based on how much customers are willing to pay, rather than the cost of the products. You can add premium value to your best-selling items.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Create product suggestion blocks at the foot of your pages or vertically at one side of the pages to let visitors check out more available options.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Develop some slides about how a consumer can use your items on the SlideShare website. Provide information to enable the user to know more about your good.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Do product reviews as blog posts to generate product-specific content for your small business vertical and get visitors familiar with your brand.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Transactional emails have a high open rate. Give a discount code with a good greeting in these emails, such as a purchase or forgotten password email.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Before sending and a few minutes after purchasing, contact users and offer them complementary products with a good discount.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Celebrate the anniversary of customers’ first purchase with a gift. It tells the customers that you care about them and raises the perceived value of your products.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Don’t presume visitors know why to use your store instead of a competitor. State your unique value proposition clearly on your homepage above the page fold.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'A/B test a radically new homepage with Google Optimize. Use a radically different style, layout, and improved focus on call-to-actions.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Improve your homepage headline with “AM Institute” free headline checker. The more magnetizing your headlines, the higher chance your visitors will purchase.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Try buying or signing up on your own website to check for issues. Put yourself in your visitors’ shoes and see what could be improved. Then get your mom to try too.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Use Olark’s free web chat tool to get visitors’ live feedback. Ask visitors their issues and what is lacking to come up with great ideas to improve your store.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Mention ‘100% Safe and Secure’ in your cart and checkout pages. Reducing visitors’ purchase worry on these pages is key for reducing cart abandonment.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Run a five-second test for free at UsabilityHub to find your visitor’s initial reactions to your site. If they don’t understand it, they won’t stick around.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Homepage sliders often have too many slides and slide too quickly. Replace it with a powerful static image and headline to create much better engagement.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Make sure your key pages don’t dead-end. Show visitors a good call-to-action at the end to check out your other content/products.', 'wc-wlfmc-wishlist' ),
				),
				array(
					'image'   => '<img src="' . MC_WLFMC_URL . 'assets/images/sell.svg" width="97" height="42" />',
					'title'   => __( 'More Convert Tips', 'wc-wlfmc-wishlist' ),
					'content' => __( 'Sidebars typically become very cluttered and visitors may miss key content in them. Declutter yours to only show the most important content relating to your goals.', 'wc-wlfmc-wishlist' ),
				),
			);
			$rand_key = array_rand( $tips, 1 );

			return $tips[ $rand_key ];
		}

		/**
		 * Add admin menu
		 *
		 * @return void
		 *
		 * @version 1.2.0
		 */
		public function add_admin_menu() {

			add_menu_page(
				__( 'MC Wishlist', 'wc-wlfmc-wishlist' ),
				__( 'MC Wishlist', 'wc-wlfmc-wishlist' ),
				'manage_options',
				'mc-wishlist-settings',
				array( $this, 'show_settings' ),
				'dashicons-heart',
				55
			);
			$settings  = add_submenu_page(
				'mc-wishlist-settings',
				__( 'Settings', 'wc-wlfmc-wishlist' ),
				__( 'Settings', 'wc-wlfmc-wishlist' ),
				'manage_options',
				'mc-wishlist-settings',
				array( $this, 'show_settings' )
			);
			$marketing = add_submenu_page(
				'mc-wishlist-settings',
				__( 'Marketing', 'wc-wlfmc-wishlist' ),
				__( 'Marketing', 'wc-wlfmc-wishlist' ),
				'manage_options',
				'mc-wishlist-marketing',
				array( $this, 'show_marketing' ) );

			$welcome = add_dashboard_page(
				__( 'MC Wishlist', 'wc-wlfmc-wishlist' ),
				__( 'MC Wishlist', 'wc-wlfmc-wishlist' ),
				'manage_options',
				'mc-wishlist-setup',
				array( $this, 'show_welcome_screen' )
			);
			add_action( 'load-' . $settings, array( $this, 'admin_enqueue_scripts' ) );
			add_action( 'load-' . $marketing, array( $this, 'admin_enqueue_scripts' ) );
			add_action( 'load-' . $welcome, array( $this, 'admin_enqueue_scripts' ) );

			add_action( 'load-' . $settings, array( $this->main_panel, 'init' ) );
			add_action( 'load-' . $marketing, array( $this->main_panel, 'init' ) );
			add_action( 'load-' . $welcome, array( $this->main_panel, 'wizard_init' ) );

			do_action( 'load-submenu-mc-wishlist', $settings, $marketing, $welcome );
		}

		/**
		 * Redirect to welcome page after activate plugin
		 *
		 * @return void
		 * @since 1.2.0
		 */
		public function welcome_screen_do_activation_redirect() {

			if ( ! get_transient( '_wlfmc_wishlist_activation_redirect' ) ) {
				return;
			}

			delete_transient( '_wlfmc_wishlist_activation_redirect' );

			if ( '1' == get_option( 'wlfmc_wizard' ) ) {
				return;
			}

			if ( is_network_admin() || isset( $_GET['activate-multi'] ) ) {
				return;
			}

			wp_safe_redirect( add_query_arg( array( 'page' => 'mc-wishlist-setup' ), admin_url( 'index.php' ) ) );

		}

		/**
		 *  Remove welcome screen menu
		 * @since 1.2.0
		 */
		public function remove_welcome_screen_menu() {
			remove_submenu_page( 'index.php', 'mc-wishlist-setup' );
		}

		/**
		 * Add Settings Button Beside Plugin Detail.
		 *
		 * @param array $links Array of links.
		 *
		 * @return array
		 * @since 1.0.1
		 */
		public function settings_link( $links ) {
			$settings_link = '<a href="admin.php?page=mc-wishlist-settings">'
							 . __( 'Settings', 'wc-wlfmc-wishlist' ) .
							 '</a>';
			array_unshift( $links, $settings_link );

			return $links;
		}

		/**
		 * Add Docs and Support Button Beside Plugin Detail.
		 *
		 * @param $links
		 * @param $file
		 *
		 * @return array
		 * @since 1.0.1
		 */
		public function plugin_row_meta( $links, $file ) {
			$plugin = plugin_basename( MC_WLFMC_MAIN_FILE );

			if ( $plugin == $file ) {
				$row_meta = array(
					'docs'    => '<a href="' . esc_url( 'https://moreconvert.com/smart-wishlist-for-more-convert-documentation/' ) . '" target="_blank" aria-label="' . esc_attr__( 'Documentation', 'wc-wlfmc-wishlist' ) . '" style="color:green;">' . esc_html__( 'Documentation', 'wc-wlfmc-wishlist' ) . '</a>',
					'support' => '<a href="' . esc_url( 'https://moreconvert.com/support/' ) . '" target="_blank" aria-label="' . esc_attr__( 'Support', 'wc-wlfmc-wishlist' ) . '" style="color:green;">' . esc_html__( 'Support', 'wc-wlfmc-wishlist' ) . '</a>',
					'pro'     => '<a href="' . esc_url( 'https://moreconvert.com/products/wishlist/' ) . '" target="_blank" aria-label="' . esc_attr__( 'Get Pro', 'wc-wlfmc-wishlist' ) . '" style="color:orange;font-weight:bold">' . esc_html__( 'Get Pro', 'wc-wlfmc-wishlist' ) . '</a>',
				);
				if ( is_plugin_active( 'smart-wishlist-for-more-convert-premium/smart-wishlist-for-more-convert-premium.php' ) ) {
					unset( $row_meta['pro'] );
				}

				return array_merge( $links, $row_meta );
			}

			return (array) $links;
		}

		/**
		 * Enqueue script and styles in admin side.
		 *
		 * @retrun void
		 *
		 * @version 1.2.2
		 */
		public function admin_enqueue_scripts() {
			$suffix = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';
			wp_register_script( 'wlfmc-admin', MC_WLFMC_URL . 'assets/admin/js/admin-panel' . $suffix . '.js', array( 'jquery' ), WLFMC_VERSION, true );

			$locale  = localeconv();
			$decimal = isset( $locale['decimal_point'] ) ? $locale['decimal_point'] : '.';

			$params = array(
				'ajax_url'                 => admin_url( "admin-ajax.php" ),
				'ajax_nonce'               => wp_create_nonce( "ajax-nonce" ),
				'i18n_making_page'         => __( 'Making a page ...', 'wc-wlfmc-wishlist' ),
				'i18n_sending'             => __( 'Sending ...', 'wc-wlfmc-wishlist' ),
				'i18n_resetting'           => __( 'Resetting ...', 'wc-wlfmc-wishlist' ),
				'i18n_resetting_confirm'   => __( 'All previous cycle between complete automation and running a new automation will be cleared and all automation cycle rules will be cleared for all users.  Do you agree to delete this information?', 'wc-wlfmc-wishlist' ),
				/* translators: %s: decimal */
				'i18n_decimal_error'       => sprintf( __( 'Please enter with one decimal point (%s) without thousand separators.', 'wc-wlfmc-wishlist' ), $decimal ),
				/* translators: %s: price decimal separator */
				'i18n_mon_decimal_error'   => sprintf( __( 'Please enter with one monetary decimal point (%s) without thousand separators and currency symbols.', 'wc-wlfmc-wishlist' ), wc_get_price_decimal_separator() ),
				'i18n_percent_description' => __( 'Value of the coupon(percent).', 'wc-wlfmc-wishlist' ),
				/* translators: %s: currency symbol */
				'i18n_amount_description'  => sprintf( __( 'Value of the coupon(%s).', 'wc-wlfmc-wishlist' ), get_woocommerce_currency_symbol() ),
				'decimal_point'            => $decimal,
				'mon_decimal_point'        => wc_get_price_decimal_separator(),
			);

			wp_localize_script( 'wlfmc-admin', 'wlfmc_wishlist_admin', $params );
			wp_enqueue_script( 'wlfmc-admin' );

			wp_enqueue_script( 'thickbox' );
			wp_enqueue_style( 'thickbox' );

			$options = new MCT_Options( 'wlfmc_options' );
			if ( '1' == $options->get_option( 'live_chat', '0' ) ) {
				wp_add_inline_script( 'wlfmc-admin', 'window.$crisp=[];window.CRISP_WEBSITE_ID="178de8d4-f389-4844-af87-fd40c311732c";(function(){d=document;s=d.createElement("script");s.src="https://client.crisp.chat/l.js";s.async=1;d.getElementsByTagName("head")[0].appendChild(s);})();' );
			}

		}

		/**
		 * Show admin option panel.
		 *
		 * @return void
		 *
		 * @version 1.0.1
		 */
		public function show_settings() {
			?>
			<div id="wlfmc_options">
				<?php
				if ( $this->installed ) {
					$fields = new MCT_Fields( $this->main_options );
					$fields->output();
				}
				?>
			</div>
			<div id="snackbar"></div>
			<!--script type="text/javascript">window.$crisp=[];window.CRISP_WEBSITE_ID="178de8d4-f389-4844-af87-fd40c311732c";(function(){d=document;s=d.createElement("script");s.src="https://client.crisp.chat/l.js";s.async=1;d.getElementsByTagName("head")[0].appendChild(s);})();</script-->

			<?php
		}

		/**
		 * Show admin option panel.
		 *
		 * @return void
		 *
		 * @version 1.2.1
		 */
		public function show_marketing() {
			?>
			<div id="wlfmc_options">
				<?php
				if ( $this->installed ) {

					// phpcs:disable WordPress.Security.NonceVerification.Recommended
					$active_tools = isset( $_GET['tools'] ) && '' !== $_GET['tools'] ? sanitize_text_field( wp_unslash( $_GET['tools'] ) ) : '';
					// phpcs:enable


					if ( '' === $active_tools ) {

						$fields = new MCT_Fields( $this->tool_options );
						$fields->output();

					} elseif ( has_action( 'wlfmc_' . $active_tools . '_admin_settings' ) ) {

						/**
						 * Show marketing toolkit settings.
						 *
						 */
						do_action( 'wlfmc_' . $active_tools . '_admin_settings', $this->main_options );

					}


				}
				?>
			</div>
			<div id="snackbar"></div>
			<?php
		}


		/**
		 * Show welcome screen.
		 *
		 * @since 1.2.0
		 */
		public function show_welcome_screen() {
			?>
			<div id="wlfmc_options">
				<?php
				if ( $this->installed ) {

					$fields = new MCT_Fields( $this->steps_options );
					$fields->output();
				}
				?>
			</div>
			<div id="snackbar"></div>
			<?php
		}

		/**
		 * Run the installation.
		 *
		 * @return void
		 *
		 * @version 1.0.1
		 */
		public function install() {
			if ( wp_doing_ajax() ) {
				return;
			}

			$stored_db_version = get_option( 'wlfmc_db_version' );
			$stored_version    = get_option( 'wlfmc_version' );

			if ( ! $stored_db_version || ! $this->installed ) {
				// fresh installation.
				WLFMC_Install()->init();
			} elseif ( version_compare( $stored_db_version, WLFMC_DB_VERSION, '<' ) || version_compare( $stored_version, WLFMC_VERSION, '<' ) ) {
				// update .
				WLFMC_Install()->update( $stored_version, $stored_db_version );
				do_action( 'wlfmc_updated' );
			}


			// Plugin installed.
			do_action( 'wlfmc_installed' );
		}


		/**
		 * Returns single instance of the class
		 *
		 * @return WLFMC_Admin
		 */
		public static function get_instance() {
			if ( is_null( self::$instance ) ) {
				self::$instance = new self();
			}

			return self::$instance;
		}
	}
}


/**
 * Unique access to instance of WLFMC_Admin class
 *
 * @return WLFMC_Admin
 */
function WLFMC_Admin() {
	return WLFMC_Admin::get_instance();
}
