<?php
/**
 * Smart Wishlist Install
 *
 * @author MoreConvert
 * @package Smart Wishlist For More Convert
 * @version 1.3.3
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


if ( ! class_exists( 'WLFMC_Install' ) ) {
	/**
	 * Install plugin table and create the wishlist page
	 *
	 */
	class WLFMC_Install {

		/**
		 * Single instance of the class
		 *
		 * @var WLFMC_Install
		 */
		protected static $instance;

		/**
		 * Items table name
		 *
		 * @var string
		 * @access private
		 */
		private $_table_items;

		/**
		 * Items table name
		 *
		 * @var string
		 * @access private
		 */
		private $_table_wishlists;

		/**
		 * Email table name
		 *
		 * @var string
		 * @access private
		 */
		private $_table_offers;

		/**
		 * Email automation table name
		 * @var string
		 */
		private $_table_automations;

		/**
		 * Returns single instance of the class
		 *
		 * @return WLFMC_Install
		 */
		public static function get_instance() {
			if ( is_null( self::$instance ) ) {
				self::$instance = new self();
			}

			return self::$instance;
		}

		/**
		 * Constructor.
		 *
		 * @version 1.3.3
		 */
		public function __construct() {
			global $wpdb;

			// define local private attribute.
			$this->_table_items       = $wpdb->prefix . 'wlfmc_wishlist_items';
			$this->_table_wishlists   = $wpdb->prefix . 'wlfmc_wishlists';
			$this->_table_automations = $wpdb->prefix . 'wlfmc_wishlist_automations';
			$this->_table_offers      = $wpdb->prefix . 'wlfmc_wishlist_offers';

			// add custom field to global $wpdb.
			$wpdb->wlfmc_items       = $this->_table_items;
			$wpdb->wlfmc_wishlists   = $this->_table_wishlists;
			$wpdb->wlfmc_automations = $this->_table_automations;
			$wpdb->wlfmc_offers      = $this->_table_offers;

		}

		/**
		 * Init db structure of the plugin
		 *
		 */
		public function init() {
			$this->_add_tables();
			$this->_add_pages();

			$this->register_current_version();
		}


		/**
		 * Register current version of plugin and database sctructure
		 */
		public function register_current_version() {
			delete_option( 'wlfmc_version' );
			update_option( 'wlfmc_version', WLFMC_VERSION );

			delete_option( 'wlfmc_db_version' );
			update_option( 'wlfmc_db_version', WLFMC_DB_VERSION );
		}

		/**
		 * Check if the table of the plugin already exists.
		 *
		 * @return bool
		 * @veriaon 1.3.3
		 */
		public function is_installed() {
			global $wpdb;
			$number_of_tables = $wpdb->query( $wpdb->prepare( 'SHOW TABLES LIKE %s', $wpdb->prefix . "wlfmc_wishlist%" ) );

			return 3 <= $number_of_tables;
		}

		/**
		 * Add tables for a fresh installation
		 *
		 * @return void
		 * @access private
		 *
		 * @version 1.0.1
		 */
		private function _add_tables() {
			if ( ! $this->is_installed() ) {
				$this->_add_wishlists_table();
				$this->_add_items_table();
				$this->_add_automations_table();
				$this->_add_offer_table();
			}
		}

		/**
		 * Add the wishlists table to the database.
		 *
		 * @return void
		 * @access private
		 */
		private function _add_wishlists_table() {


			$sql = "CREATE TABLE {$this->_table_wishlists} (
							ID BIGINT( 20 ) NOT NULL AUTO_INCREMENT,
							user_id BIGINT( 20 ) NULL DEFAULT NULL,
							session_id VARCHAR( 255 ) DEFAULT NULL,
							wishlist_slug VARCHAR( 200 ) NOT NULL,
							wishlist_name TEXT,
							wishlist_token VARCHAR( 64 ) NOT NULL UNIQUE,
							wishlist_privacy TINYINT( 1 ) NOT NULL DEFAULT 0,
							is_default TINYINT( 1 ) NOT NULL DEFAULT 0,
							dateadded timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
							expiration timestamp NULL DEFAULT NULL,
							PRIMARY KEY  ( ID ),
							KEY wishlist_slug ( wishlist_slug )
						) DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;";

			require_once ABSPATH . 'wp-admin/includes/upgrade.php';
			dbDelta( $sql );

			return;
		}

		/**
		 * Add the items' table to the database.
		 *
		 * @return void
		 * @access private
		 */
		private function _add_items_table() {


			$sql = "CREATE TABLE {$this->_table_items} (
							ID BIGINT( 20 ) NOT NULL AUTO_INCREMENT,
							prod_id BIGINT( 20 ) NOT NULL,
							quantity INT( 11 ) NOT NULL,
							user_id BIGINT( 20 ) NULL DEFAULT NULL,
							wishlist_id BIGINT( 20 ) NULL,
							position INT( 11 ) DEFAULT 0,
							note VARCHAR (250),
							importance TINYINT( 1 ) NOT NULL DEFAULT 0,
							original_price DECIMAL( 9,3 ) NULL DEFAULT NULL,
							original_currency CHAR( 3 ) NULL DEFAULT NULL,
							dateadded timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
							on_sale tinyint NOT NULL DEFAULT 0,
							PRIMARY KEY  ( ID ),
							KEY prod_id ( prod_id )
						) DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;";

			require_once ABSPATH . 'wp-admin/includes/upgrade.php';
			dbDelta( $sql );

			return;
		}


		/**
		 * Add the email automations table to the database.
		 *
		 * @return void
		 * @access private
		 *
		 *
		 * @version 1.3.3
		 */
		private function _add_automations_table() {


			$sql = "CREATE TABLE {$this->_table_automations} (
							ID BIGINT( 20 ) NOT NULL AUTO_INCREMENT,
							automation_name TEXT,
							list_type  VARCHAR(100) NOT NULL DEFAULT 'default',
							options LONGTEXT,
							created_at timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
							is_active TINYINT( 1 ) NOT NULL DEFAULT 0,
							PRIMARY KEY  ( ID )
						) DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;";

			require_once ABSPATH . 'wp-admin/includes/upgrade.php';
			dbDelta( $sql );


			return;
		}

		/**
		 * Add the email table to the database.
		 *
		 * @return void
		 * @access private
		 *
		 *
		 * @version 1.0.1
		 */
		private function _add_offer_table() {

			$sql = "CREATE TABLE {$this->_table_offers} (
							ID BIGINT( 20 ) NOT NULL AUTO_INCREMENT,
							automation_id BIGINT( 20 ) NULL,
							user_id BIGINT( 20 ) NULL DEFAULT NULL,
							wishlist_id BIGINT( 20 ) NULL,
							has_coupon  TINYINT( 1 ) NOT NULL DEFAULT 0,
							coupon_id BIGINT( 20 ) NULL,
							product_id BIGINT( 20 ) NULL,
							email_options LONGTEXT,
							email_key INT(1),
							track_code varchar(50) NULL,
							days SMALLINT( 3 ) NULL DEFAULT 0,
							net DOUBLE,
							dateadded timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
							datesend timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
							datesent timestamp,
							status varchar( 200 ) NOT NULL DEFAULT 'sending' comment 'sending ,not-send , sent ,  opened ,  clicked, coupon-used',
							PRIMARY KEY  ( ID )
						) DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;";

			require_once ABSPATH . 'wp-admin/includes/upgrade.php';
			dbDelta( $sql );


			return;
		}

		/**
		 * Update db structure and options of the plugin
		 *
		 * @param string $current_version Version from which we're updating.
		 * @param string $current_db_version Version from which we're updating.
		 *
		 * @since 1.0.1
		 * @version 1.2.0
		 */
		public function update( $current_version, $current_db_version ) {

			if ( version_compare( $current_db_version, '1.0.1', '<' ) ) {
				$this->_update_1_0_1();
			}
			if ( version_compare( $current_version, '1.2.0', '<' ) ) {

				$this->_update_1_2_0();
			}

			if ( version_compare( $current_version, '1.3.0', '<' ) ) {

				$this->_update_1_3_0();
			}
			if ( version_compare( $current_version, '1.3.1', '<' ) ) {

				$this->_update_1_3_1();
			}
			if ( version_compare( $current_version, '1.3.2', '<' ) ) {

				$this->_update_1_3_2();
			}

			if ( version_compare( $current_db_version, '1.1.0', '<' ) ) {

				$this->_add_automations_table();

			}

			if ( version_compare( $current_version, '1.3.3', '<' ) ) {

				$this->_update_1_3_3();
			}

			$this->register_current_version();
		}

		/**
		 * Update from 1.0.0 to 1.0.1
		 *
		 * @since 1.0.1
		 */
		private function _update_1_0_1() {
			global $wpdb;

			if ( $wpdb->get_var( "SHOW TABLES LIKE '{$wpdb->wlfmc_offers}';" ) ) {
				if ( ! $wpdb->get_var( "SHOW COLUMNS FROM `{$wpdb->wlfmc_offers}` LIKE 'days';" ) ) {
					$wpdb->query( "ALTER TABLE {$wpdb->wlfmc_offers} ADD `days` SMALLINT( 3 ) NULL DEFAULT 0;" );
				}
				if ( ! $wpdb->get_var( "SHOW COLUMNS FROM `{$wpdb->wlfmc_offers}` LIKE 'product_id';" ) ) {
					$wpdb->query( "ALTER TABLE {$wpdb->wlfmc_offers} ADD `product_id` BIGINT( 20 ) NULL;" );
				}
			}
		}

		/**
		 * Update to 1.2.0
		 *
		 * @since 1.2.0
		 */
		public function _update_1_2_0() {

			set_transient( '_wlfmc_wishlist_activation_redirect', true, 30 );

			update_option( 'smart-wishlist-for-more-convert_tracking_notice', 'hide' );

			update_option( 'wlfmc-skip-wizard-notice', true );

			update_option( 'wlfmc-finish-wizard-notice', true );

			// If our option doesn't exist already, we'll create it with today's timestamp.
			if ( ! get_option( 'wlfmc_wishlist_activation_date' ) ) {
				update_option( 'wlfmc_wishlist_activation_date', date( 'Y-m-d' ) );
			}
		}

		/**
		 * Update to 1.3.0
		 *
		 * @since 1.3.0
		 */
		public function _update_1_3_0() {

			$options = new MCT_Options( 'wlfmc_options' );
			if ( 'before_image' === $options->get_option( 'loop_position' ) ) {
				$options->update_option( 'loop_position', 'image_top_left' );
			}
			if ( 'thumbnails' === $options->get_option( 'wishlist_button_position' ) ) {
				$options->update_option( 'wishlist_button_position', 'image_top_left' );
			}
			if ( 'before_image' === $options->get_option( 'gutenberg_position' ) ) {
				$options->update_option( 'gutenberg_position', 'image_top_left' );
			}

			$options->update_option( 'enable_for_outofstock_product', '1' );
		}

		/**
		 * Update to 1.3.1
		 *
		 * @since 1.3.1
		 */
		public function _update_1_3_1() {

			$options = new MCT_Options( 'wlfmc_options' );
			$options->update_option( 'show_login_notice_for_guests', $options->get_option( 'show_login_notice_for_quests' ) );
		}

		/**
		 * Update to 1.3.2
		 *
		 * @since 1.3.2
		 */
		public function _update_1_3_2() {

			$options               = new MCT_Options( 'wlfmc_options' );
			$wishlist_button_style = $options->get_option( 'wishlist_button_style' );

			if ( isset( $wishlist_button_style['color'] ) ) {
				$options->update_option( 'wishlist_button_color', $wishlist_button_style['color'] );
			}
			if ( isset( $wishlist_button_style['color-hover'] ) ) {
				$options->update_option( 'wishlist_button_hover_color', $wishlist_button_style['color-hover'] );
			}
			if ( isset( $wishlist_button_style['background'] ) ) {
				$options->update_option( 'wishlist_button_background_color', $wishlist_button_style['background'] );
			}
			if ( isset( $wishlist_button_style['background-hover'] ) ) {
				$options->update_option( 'wishlist_button_background_hover_color', $wishlist_button_style['background-hover'] );
			}
			if ( isset( $wishlist_button_style['border'] ) ) {
				$options->update_option( 'wishlist_button_border_color', $wishlist_button_style['border'] );
			}
			if ( isset( $wishlist_button_style['border-hover'] ) ) {
				$options->update_option( 'wishlist_button_border_hover_color', $wishlist_button_style['border-hover'] );
			}

			$icon_style_single  = $options->get_option( 'icon_style_single' );
			$text_style_single  = $options->get_option( 'text_style_single' );
			$button_type_single = $options->get_option( 'button_type_single' );
			if ( isset( $icon_style_single['color'] ) ) {
				$options->update_option( 'icon_color_single', $icon_style_single['color'] );
			}
			if ( isset( $icon_style_single['color-hover'] ) ) {
				$options->update_option( 'icon_hover_color_single', $icon_style_single['color-hover'] );
			}
			if ( isset( $text_style_single['color'] ) ) {
				$options->update_option( 'text_color_single', $text_style_single['color'] );
			}
			if ( isset( $text_style_single['color-hover'] ) ) {
				$options->update_option( 'text_hover_color_single', $text_style_single['color-hover'] );
			}
			if ( 'icon' === $button_type_single ) {
				if ( isset( $icon_style_single['background'] ) ) {
					$options->update_option( 'button_background_color_single', $icon_style_single['background'] );
				}
				if ( isset( $icon_style_single['background-hover'] ) ) {
					$options->update_option( 'button_background_hover_color_single', $icon_style_single['background-hover'] );
				}
				if ( isset( $icon_style_single['border'] ) ) {
					$options->update_option( 'button_border_color_single', $icon_style_single['border'] );
				}
				if ( isset( $icon_style_single['border-hover'] ) ) {
					$options->update_option( 'button_border_hover_color_single', $icon_style_single['border-hover'] );
				}
			} else {
				if ( isset( $text_style_single['background'] ) ) {
					$options->update_option( 'button_background_color_single', $text_style_single['background'] );
				}
				if ( isset( $text_style_single['background-hover'] ) ) {
					$options->update_option( 'button_background_hover_color_single', $text_style_single['background-hover'] );
				}
				if ( isset( $text_style_single['border'] ) ) {
					$options->update_option( 'button_border_color_single', $text_style_single['border'] );
				}
				if ( isset( $text_style_single['border-hover'] ) ) {
					$options->update_option( 'button_border_hover_color_single', $text_style_single['border-hover'] );
				}
			}


			$icon_style_loop  = $options->get_option( 'icon_style_loop' );
			$text_style_loop  = $options->get_option( 'text_style_loop' );
			$button_type_loop = $options->get_option( 'button_type_loop' );
			if ( isset( $icon_style_loop['color'] ) ) {
				$options->update_option( 'icon_color_loop', $icon_style_loop['color'] );
			}
			if ( isset( $icon_style_loop['color-hover'] ) ) {
				$options->update_option( 'icon_hover_color_loop', $icon_style_loop['color-hover'] );
			}
			if ( isset( $text_style_loop['color'] ) ) {
				$options->update_option( 'text_color_loop', $text_style_loop['color'] );
			}
			if ( isset( $text_style_loop['color-hover'] ) ) {
				$options->update_option( 'text_hover_color_loop', $text_style_loop['color-hover'] );
			}
			if ( 'icon' === $button_type_loop ) {
				if ( isset( $icon_style_loop['background'] ) ) {
					$options->update_option( 'button_background_color_loop', $icon_style_loop['background'] );
				}
				if ( isset( $icon_style_loop['background-hover'] ) ) {
					$options->update_option( 'button_background_hover_color_loop', $icon_style_loop['background-hover'] );
				}
				if ( isset( $icon_style_loop['border'] ) ) {
					$options->update_option( 'button_border_color_loop', $icon_style_loop['border'] );
				}
				if ( isset( $icon_style_loop['border-hover'] ) ) {
					$options->update_option( 'button_border_hover_color_loop', $icon_style_loop['border-hover'] );
				}
			} else {
				if ( isset( $text_style_loop['background'] ) ) {
					$options->update_option( 'button_background_color_loop', $text_style_loop['background'] );
				}
				if ( isset( $text_style_loop['background-hover'] ) ) {
					$options->update_option( 'button_background_hover_color_loop', $text_style_loop['background-hover'] );
				}
				if ( isset( $text_style_loop['border'] ) ) {
					$options->update_option( 'button_border_color_loop', $text_style_loop['border'] );
				}
				if ( isset( $text_style_loop['border-hover'] ) ) {
					$options->update_option( 'button_border_hover_color_loop', $text_style_loop['border-hover'] );
				}
			}
		}

		/**
		 * Update to 1.3.3
		 *
		 * @since 1.3.3
		 */
		public function _update_1_3_3() {
			global $wpdb;

			wp_clear_scheduled_hook( 'wlfmc_send_offer_emails' );

			$options                  = new MCT_Options( 'wlfmc_options' );
			$single_position          = $options->get_option( 'wishlist_button_position', 'after_add_to_cart' );
			$loop_position            = $options->get_option( 'loop_position', 'after_add_to_cart' );
			$remove_after_add_to_cart = $options->get_option( 'remove_after_add_to_cart', true );
			$button_label_add         = $options->get_option( 'button_label_add_single', __( 'Add To Wishlist', 'wc-wlfmc-wishlist' ) );
			$button_label_view        = $options->get_option( 'button_label_view_single', __( 'View My Wishlist', 'wc-wlfmc-wishlist' ) );
			$button_label_remove      = $options->get_option( 'button_label_remove_single', __( 'Remove From Wishlist', 'wc-wlfmc-wishlist' ) );

			$options->update_option( 'button_label_add', $button_label_add );
			$options->update_option( 'button_label_view', $button_label_view );
			$options->update_option( 'button_label_remove', $button_label_remove );

			if ( true == $remove_after_add_to_cart ) {
				$options->update_option( 'remove_from_wishlist', 'added-to-cart' );
			}
			if ( in_array( $single_position, array(
				'image_top_left',
				'image_top_right',
				'image_bottom_left',
				'image_bottom_right'
			) ) ) {
				$options->update_option( 'button_type_single', 'icon' );
			}
			if ( in_array( $loop_position, array(
				'image_top_left',
				'image_top_right',
			) ) ) {
				$options->update_option( 'button_type_loop', 'icon' );
			}


			if ( $wpdb->get_var( "SHOW TABLES LIKE '{$wpdb->wlfmc_offers}';" ) ) {
				if ( ! $wpdb->get_var( "SHOW COLUMNS FROM `{$wpdb->wlfmc_offers}` LIKE 'automation_id';" ) ) {
					$wpdb->query( "ALTER TABLE {$wpdb->wlfmc_offers} ADD `automation_id` BIGINT( 20 ) NULL;" );
				}
				if ( ! $wpdb->get_var( "SHOW COLUMNS FROM `{$wpdb->wlfmc_offers}` LIKE 'net';" ) ) {
					$wpdb->query( "ALTER TABLE {$wpdb->wlfmc_offers} ADD `net` DOUBLE ;" );
				}
				if ( ! $wpdb->get_var( "SHOW COLUMNS FROM `{$wpdb->wlfmc_offers}` LIKE 'track_code';" ) ) {
					$wpdb->query( "ALTER TABLE {$wpdb->wlfmc_offers} ADD `track_code` VARCHAR(50) NULL;" );
				}
				if ( ! $wpdb->get_var( "SHOW COLUMNS FROM `{$wpdb->wlfmc_offers}` LIKE 'email_key';" ) ) {
					$wpdb->query( "ALTER TABLE {$wpdb->wlfmc_offers} ADD `email_key` INT(1) ;" );
				}

				if ( ! $wpdb->get_var( "SHOW COLUMNS FROM `{$wpdb->wlfmc_offers}` LIKE 'status';" ) ) {
					$wpdb->query( "ALTER TABLE {$wpdb->wlfmc_offers} ADD `status`  varchar( 200 ) NOT NULL DEFAULT 'sending' comment 'sending ,not-send , sent ,  opened ,  clicked, coupon-used' ;" );
				}
				if ( $wpdb->get_var( "SHOW COLUMNS FROM `{$wpdb->wlfmc_offers}` LIKE 'datesent';" ) ) {
					$wpdb->query( "ALTER TABLE {$wpdb->wlfmc_offers} MODIFY `datesent` timestamp ;" );
				}

			}
			$min_total          = $options->get_option( 'minimum-wishlist-total', 1 );
			$min_count          = $options->get_option( 'minimum-wishlist-count', 1 );
			$include_products   = maybe_unserialize( $options->get_option( 'include-product' ) );
			$period_days        = (int) $options->get_option( 'period-days' );
			$automation_options = array(
				'minimum-wishlist-total'       => $min_total,
				'minimum-wishlist-count'       => $min_count,
				'include-product'              => $include_products,
				'period-days'                  => $period_days,
				'discount-type'                => $options->get_option( 'discount-type', 'fixed_cart' ),
				'coupon-amount'                => $options->get_option( 'coupon-amount' ),
				'individual-use'               => $options->get_option( 'individual-use', '0' ),
				'exclude-sale-items'           => $options->get_option( 'exclude-sale-items', '0' ),
				'free-shipping'                => $options->get_option( 'free-shipping', '0' ),
				'expiry-date'                  => $options->get_option( 'expiry-date' ),
				'user-restriction'             => $options->get_option( 'user-restriction', '0' ),
				'delete-after-expired'         => $options->get_option( 'delete-after-expired', '0' ),
				'email-from-name'              => $options->get_option( 'email-from-name' ),
				'email-from-address'           => $options->get_option( 'email-from-address' ),
				'mail-type'                    => $options->get_option( 'mail-type', 'html' ),
				'email-template-logo'          => $options->get_option( 'email-template-logo' ),
				'email-template-avatar'        => $options->get_option( 'email-template-avatar' ),
				'email-template-customer-name' => $options->get_option( 'email-template-customer-name' ),
				'email-template-customer-job'  => $options->get_option( 'email-template-customer-job' ),
				'email-template-facebook'      => $options->get_option( 'email-template-facebook' ),
				'email-template-linkedin'      => $options->get_option( 'email-template-linkedin' ),
				'email-template-instagram'     => $options->get_option( 'email-template-instagram' ),
				'offer_emails'                 => $options->get_option( 'offer_emails' )
			);
			$insert             = $wpdb->insert( $this->_table_automations,
				array(
					'automation_name' => __( 'Default', 'wc-wlfmc-wishlist' ),
					'options'         => serialize( $automation_options ),
				),
				array(
					'%s',
					'%s'
				)
			);
			if ( is_wp_error( $insert ) ) {
				return new WP_Error( 'Create_Automation_table_error', $insert->get_error_message() );
			} else {
				$wpdb->query(  "TRUNCATE TABLE {$wpdb->wlfmc_offers}"  );

			}

		}

		/**
		 * Add a page "Wishlist".
		 *
		 * @return void
		 */
		private function _add_pages() {
			wc_create_page(
				sanitize_title_with_dashes( _x( 'wishlist', 'page_slug', 'wc-wlfmc-wishlist' ) ),
				'wlfmc_wishlist_page_id',
				__( 'Wishlist', 'wc-wlfmc-wishlist' ),
				'<!-- wp:shortcode -->[wlfmc_wishlist]<!-- /wp:shortcode -->'
			);
		}
	}
}

/**
 * Unique access to instance of WLFMC_Install class
 *
 * @return WLFMC_Install
 */
function WLFMC_Install() {
	return WLFMC_Install::get_instance();
}
