<?php
/**
 * Shortcodes Class
 *
 * @author MoreConvert
 * @package Smart Wishlist For More Convert
 * @version 1.3.3
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}// Exit if accessed directly

if ( ! class_exists( 'WLFMC_Shortcode' ) ) {
	/**
	 * Woocommerce Smart Wishlist Shortcodes
	 *
	 */
	class WLFMC_Shortcode {

		/**
		 * Init shortcodes available for the plugin
		 *
		 * @return void
		 *
		 * @version 1.3.0
		 */
		public static function init() {
			// register shortcodes.
			add_shortcode( 'wlfmc_wishlist', array( 'WLFMC_Shortcode', 'wishlist' ) );
			add_shortcode( 'wlfmc_add_to_wishlist', array( 'WLFMC_Shortcode', 'add_to_wishlist' ) );
			add_shortcode( 'wlfmc_wishlist_counter', array( 'WLFMC_Shortcode', 'wishlist_counter' ) );

		}


		/**
		 * Print the wishlist HTML.
		 *
		 * @param array $atts Array of attributes for the shortcode.
		 * @param string $content Shortcode content (none expected).
		 *
		 * @return string Rendered shortcode
		 *
		 * @version 1.3.2
		 */
		public static function wishlist( $atts, $content = null ) {
			global $wlfmc_is_wishlist, $wlfmc_wishlist_token;

			$atts = shortcode_atts(
				array(
					'container_class' => '',
					'per_page'        => get_option( 'posts_per_page', 9 ),
					'current_page'    => 1,
					'pagination'      => 'yes',
					'wishlist_id'     => get_query_var( 'wishlist_id', false ),
					'action_params'   => get_query_var( WLFMC()->wishlist_param, false ),
					'no_interactions' => 'no',

				),
				$atts
			);

			/**
			 * @var $per_page int
			 * @var $current_page int
			 * @var $pagination string
			 * @var $wishlist_id int
			 * @var $action_params array
			 * @var $no_interactions string
			 */
			extract( $atts ); // phpcs:ignore

			$options    = new MCT_Options( 'wlfmc_options' );
			$items_show = $options->get_option( 'wishlist_items_show', array(
				'product-checkbox',
				'product-remove',
				'product-thumbnail',
				'product-name',
				'product-price',
				'product-add-to-cart',
			) );

			// retrieve options from query string.
			$action_params = explode( '/', apply_filters( 'wlfmc_current_wishlist_view_params', $action_params ) );
			$action        = ( isset( $action_params[0] ) ) ? $action_params[0] : 'view';


			// init params needed to load correct template.
			$template_part          = 'view';
			$no_interactions        = 'yes' == $no_interactions;
			$empty_wishlist_content = $options->get_option( 'empty_wishlist_content', __( 'You have not added any products to your wishlist.', 'wc-wlfmc-wishlist' ) );

			$wishlist_under_table = $options->get_option( 'wishlist_under_table', array(
				'actions',
				'add-all-to-cart'
			) );

			$additional_params = array(


				// wishlist data.
				'wishlist'               => false,
				'wishlist_token'         => '',
				'wishlist_id'            => false,
				'is_private'             => false,

				// wishlist items.
				'count'                  => 0,
				'wishlist_items'         => array(),

				// page data.
				'current_page'           => $current_page,
				'page_links'             => false,

				// user data.
				'is_user_logged_in'      => is_user_logged_in(),
				'is_user_owner'          => true,

				// view data.
				'no_interactions'        => $no_interactions,
				'view_mode'              => $options->get_option( 'wishlist_view_mode', 'list' ),
				'items_show'             => $items_show,
				'empty_wishlist_content' => $empty_wishlist_content,
				'enable_actions'         => in_array( 'actions', (array) $wishlist_under_table ),
				'enable_all_add_to_cart' => in_array( 'add-all-to-cart', (array) $wishlist_under_table ),

				'wishlist_class'            => $options->get_option( 'wishlist_custom_template', true ) ? '' : 'wishlist-custom-style',
				'wishlist_pagination_class' => 'woocommerce-pagination',
				// share data.
				'share_enabled'             => false,

				// template data.
				'template_part'             => $template_part,
				'additional_info'           => false,
				'available_multi_wishlist'  => false,
				'users_wishlists'           => array(),
				'form_action'               => esc_url( WLFMC()->get_wishlist_url( 'view' ) ),
			);

			if ( true == $options->get_option( 'wishlist_button_add_to_cart_style', true ) ) {
				$additional_params['wishlist_class'] .= ' add-to-card-same-button';
			}
			if ( true == $options->get_option( 'wishlist_qty_style', true ) ) {
				$additional_params['wishlist_class'] .= ' qty-same-button';
			}
			if ( true == $options->get_option( 'wishlist_pagination_style', true ) ) {
				$additional_params['wishlist_pagination_class'] = 'wishlist-pagination';
			}
			$wishlist = WLFMC_Wishlist_Factory::get_current_wishlist( $atts );

			if ( $wishlist && $wishlist->current_user_can( 'view' ) ) {


				// set global wishlist token.
				$wlfmc_wishlist_token = $wishlist->get_token();

				// retrieve wishlist params.
				$is_user_owner = $wishlist->is_current_user_owner();
				$count         = $wishlist->count_items();
				$offset        = 0;

				// sets current page, number of pages and element offset.
				$wishlist_url = is_user_logged_in() ? apply_filters( 'wlfmc_user_logged_in_wishlist_url', wc_get_account_endpoint_url( get_option( 'woocommerce_myaccount_wlfmc_wishlist_endpoint', 'wlfmc-wishlist' ) ) ) : $wishlist->get_url();
				$has_param    = parse_url( $wishlist_url );
				$has_param    = isset( $has_param['query'] ) && ! empty( $has_param['query'] );

				$queried_page = is_user_logged_in() && ! $has_param ? get_query_var( get_option( 'woocommerce_myaccount_wlfmc_wishlist_endpoint', 'wlfmc-wishlist' ) ) : get_query_var( 'paged' );
				$current_page = max( 1, $queried_page ? $queried_page : $current_page );

				// sets variables for pagination, if shortcode atts is set to yes.
				if ( 'yes' == $pagination && ! $no_interactions && $count > 1 ) {
					$pages = ceil( $count / $per_page );

					if ( $current_page > $pages ) {
						$current_page = $pages;
					}

					$offset = ( $current_page - 1 ) * $per_page;

					if ( $pages > 1 ) {
						$big        = 999999999;
						$base       = is_user_logged_in() ? esc_url( $wishlist->get_url() . '%#%' ) : esc_url( add_query_arg( array( 'paged' => '%#%' ), $wishlist->get_url() ) );
						$page_links = paginate_links(
							array(
								'base'      => $has_param ? str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ) : $base,
								'format'    => '%#%',
								'current'   => $current_page,
								'total'     => $pages,
								'show_all'  => true,
								'prev_text' => is_rtl() ? '&rarr;' : '&larr;',
								'next_text' => is_rtl() ? '&larr;' : '&rarr;',
								'type'      => 'list',
								'end_size'  => 3,
								'mid_size'  => 3,
							)
						);
					}
				} else {
					$per_page = 0;
				}

				// retrieve items to print.
				$wishlist_items = $wishlist->get_items( $per_page, $offset );

				$additional_params = wp_parse_args(
					array(
						// wishlist items.
						'count'          => $count,
						'wishlist_items' => $wishlist_items,

						// wishlist data.
						'wishlist'       => $wishlist,
						'is_default'     => $wishlist->get_is_default(),
						'wishlist_token' => $wishlist->get_token(),
						'wishlist_id'    => $wishlist->get_id(),
						'is_private'     => $wishlist->has_privacy( 'private' ),

						// page data.Wishlist
						'current_page'   => $current_page,
						'page_links'     => isset( $page_links ) && ! $no_interactions ? $page_links : false,

						// user data.
						'is_user_owner'  => $is_user_owner,


						// template data.
						'form_action'    => $wishlist->get_url(),
					),
					$additional_params
				);
				// share options.
				$enable_share = $options->get_option( 'enable_share' ) == true && ! $wishlist->has_privacy( 'private' );
				$share_items  = $options->get_option( 'share_items' );

				if ( ! $no_interactions && $enable_share && is_array( $share_items ) && ! empty( $share_items ) ) {
					$share_link_url = apply_filters( 'wlfmc_shortcode_share_link_url', $wishlist->get_share_url(), $wishlist );
					$socials_title  = apply_filters( 'wlfmc_socials_title', urlencode( $options->get_option( 'socials_title' ) ) );
					$socials_text   = apply_filters( 'wlfmc_socials_text', urlencode( $options->get_option( 'socials_text' ) ) );
					$share_atts     = array(
						'share_socials_title' => $socials_title,
						'share_socials_text'  => $socials_text,
						'share_link_url'      => $share_link_url,
					);

					foreach ( $share_items as $item ) {
						$share_atts[ 'share_' . $item . '_icon' ] = apply_filters( 'wlfmc_socials_share_' . $item . '_icon', '<i class="wlfmc-icon-' . $item . '"></i>' );
					}
					if ( wp_is_mobile() ) {
						$share_whatsapp_url = 'whatsapp://send?text=' . $socials_title . ' – ' . urlencode( $share_link_url );
						$share_telegram_url = 'tg://msg_url?url=' . urlencode( $share_link_url ) . '&text=' . $socials_text;
					} else {
						$share_whatsapp_url = 'https://web.whatsapp.com/send?text=' . $socials_title . ' – ' . urlencode( $share_link_url );
						$share_telegram_url = 'https://t.me/share/url?url=' . urlencode( $share_link_url ) . '&text=' . $socials_text;
					}

					$share_atts['share_whatsapp_url'] = $share_whatsapp_url;
					$share_atts['share_telegram_url'] = $share_telegram_url;

					$additional_params['share_enabled'] = true;
					$additional_params['share_items']   = $share_items;
					$additional_params['share_atts']    = $share_atts;
				}

				$who_can_see_wishlist_options      = $options->get_option( 'who_can_see_wishlist_options', 'all' );
				$notice_guests                     = $options->get_option( 'show_login_notice_for_guests', '0' );
				$additional_params['login_notice'] = false;

				if ( 'all' === $who_can_see_wishlist_options && '1' == $notice_guests && $is_user_owner && ! is_user_logged_in() ) {

					$additional_params['login_notice']         = true;
					$additional_params['login_notice_content'] = $options->get_option( 'login_notice_content', '' );
					$additional_params['login_notice_buttons'] = $options->get_option( 'login_notice_buttons', '' );
					$additional_params['login_url']            = $options->get_option( 'login_url', wp_login_url() );
					$additional_params['signup_url']           = $options->get_option( 'signup_url', wp_registration_url() );

				}
			}

			// filter params.
			$additional_params = apply_filters( 'wlfmc_wishlist_params', $additional_params, $action, $action_params, $pagination, $per_page, $atts );

			$atts = array_merge(
				$atts,
				$additional_params
			);

			$atts['fragment_options'] = WLFMC_Frontend()->format_fragment_options( $atts, 'wishlist' );

			// apply filters for add to cart buttons.
			WLFMC_Frontend()->alter_add_to_cart_button();

			// sets that we're in the wishlist template.
			$wlfmc_is_wishlist = true;

			$template = wlfmc_get_template( 'wishlist.php', $atts, true );

			// we're not in wishlist template anymore.
			$wlfmc_is_wishlist    = false;
			$wlfmc_wishlist_token = null;

			// remove filters for add to cart buttons.
			WLFMC_Frontend()->restore_add_to_cart_button();

			// enqueue scripts.
			WLFMC_Frontend()->enqueue_scripts();

			return apply_filters( 'wlfmc_wishlist_html', $template, $atts );
		}

		/**
		 * Return "Add to Wishlist" button.
		 *
		 * @param array $atts Array of parameters for the shortcode
		 * @param string $content Shortcode content (usually empty)
		 *
		 * @return string
		 *
		 * @version 1.3.5
		 */
		public static function add_to_wishlist( $atts, $content = null ) {
			global $product;

			// product object.
			$current_product = ( isset( $atts['product_id'] ) ) ? wc_get_product( $atts['product_id'] ) : false;
			$current_product = $current_product ? $current_product : $product;

			if ( ! $current_product || ! $current_product instanceof WC_Product ) {
				return '';
			}

			$current_product_id = $current_product->get_id();

			// product parent.
			$current_product_parent = $current_product->get_parent_id();

			// labels & icons settings.

			$options = new MCT_Options( 'wlfmc_options' );
			if ( ! $options->get_option( 'enable_for_outofstock_product' ) && ! $current_product->is_in_stock() ) {
				return '';
			}
			$disable_wishlist               = false;
			$who_can_see_wishlist_options   = $options->get_option( 'who_can_see_wishlist_options', 'all' );
			$force_user_to_login            = $options->get_option( 'force_user_to_login', false );
			$click_wishlist_button_behavior = $options->get_option( 'click_wishlist_button_behavior', 'just-add' );
			$remove_after_second_click      = $options->get_option( 'remove_after_second_click', '0' ); // browse or remove can be set
			$already_in_wishlist            = $options->get_option( 'already_in_wishlist_text' );
			$product_added                  = $options->get_option( 'product_added_text' );
			$loop_position                  = $options->get_option( 'loop_position', 'after_add_to_cart' );
			$single_position                = $options->get_option( 'wishlist_button_position', 'after_add_to_cart' );
			$is_single                      = isset( $atts['is_single'] ) ? $atts['is_single'] : wlfmc_is_single();
			$is_gutenberg                   = isset( $atts['is_gutenberg'] ) ? $atts['is_gutenberg'] : false;
			$gutenberg_position             = $options->get_option( 'gutenberg_position', 'after_add_to_cart' );
			$button_label_add               = $options->get_option( 'button_label_add', __( 'Add to wishlist', 'wc-wlfmc-wishlist' ) );
			$button_label_view              = $options->get_option( 'button_label_view', __( 'View My Wishlist', 'wc-wlfmc-wishlist' ) );
			$button_label_remove            = $options->get_option( 'button_label_remove', __( 'Remove from wishlist', 'wc-wlfmc-wishlist' ) );

			if ( $is_single ) {
				// button icon.
				$icon        = $options->get_option( 'icon_name_single', 'heart' );
				$added_icon  = $icon . '-o';
				$is_svg_icon = false;
				if ( 'custom' === $icon ) {
					$is_svg_icon = true;
					$icon        = $options->get_option( 'icon_svg_single' );
					$added_icon  = $options->get_option( 'icon_svg_added_single' );
				}
				$separate_icon_and_text = $options->get_option( 'separate_icon_and_text_single', false );
				$button_type            = $options->get_option( 'button_type_single', 'icon' );
				$button_theme           = $options->get_option( 'button_theme_single', true );
				$position_class         = ' wlfmc_position_' . $single_position;
				$tooltip                = $options->get_option( 'enable_tooltip_single', true );
				$tooltip_direction      = $options->get_option( 'tooltip_direction_single', 'up' );
				$tooltip_type           = 'single';
			} else {
				// button icon.
				$icon        = $options->get_option( 'icon_name_loop', 'heart' );
				$added_icon  = $icon . '-o';
				$is_svg_icon = false;
				if ( 'custom' === $icon ) {
					$is_svg_icon = true;
					$icon        = $options->get_option( 'icon_svg_loop' );
					$added_icon  = $options->get_option( 'icon_svg_added_loop' );
				}
				$separate_icon_and_text = $options->get_option( 'separate_icon_and_text_loop', false );
				$button_type            = $options->get_option( 'button_type_loop', 'icon' );
				$button_theme           = $options->get_option( 'button_theme_loop', true );
				$position_class         = ' wlfmc_position_' . $loop_position;
				$tooltip                = $options->get_option( 'enable_tooltip_loop', true );
				$tooltip_direction      = $options->get_option( 'tooltip_direction_loop', 'up' );
				$tooltip_type           = 'loop';
			}

			$tooltip_class = ( true == $tooltip && 'icon' === $button_type ) ? ' wlfmc-tooltip wlfmc-tooltip-' . $tooltip_direction : '';

			// button label.
			$label = apply_filters( 'wlfmc_button_add_label', $button_label_add, $is_single );

			// button class.

			$classes = apply_filters( 'wlfmc_add_to_wishlist_button_classes', 'wlfmc_add_to_wishlist single_add_to_wishlist button alt ' );

			if( 'add-redirect' === $click_wishlist_button_behavior) {
				$classes = str_replace('wlfmc_add_to_wishlist','' ,$classes);
			}

			if ( ( 'all' === $who_can_see_wishlist_options && true == $force_user_to_login && ! is_user_logged_in() ) ) {
				$disable_wishlist = true;
				$classes          .= ' wlfmc-btn-login-need';
			}

			if ( true == $separate_icon_and_text && 'both' == $button_type ) {
				$classes .= ' have-sep';
			}

			// check if product is already in wishlist.
			$exists            = WLFMC()->is_product_in_wishlist( $current_product_id );
			$container_classes = $exists ? 'exists' : '';
			$found_in_list     = $exists ? wlfmc_get_wishlist( false ) : false;
			$found_item        = $found_in_list ? $found_in_list->get_product( $current_product_id ) : false;

			$container_classes .= $is_single ? ' wlfmc-single-btn' : ' wlfmc-loop-btn';
			$container_classes .= $position_class;
			$container_classes .= ' wlfmc-btn-type-' . $button_type;

			if ( ( in_array( $gutenberg_position, array(
						'image_top_left',
						'image_top_right'
					) ) && 'true' == $is_gutenberg ) ||
			     ( in_array( $loop_position, array( 'image_top_left', 'image_top_right' ) ) && ! $is_single ) ||
			     ( in_array( $single_position, array(
					     'image_top_left',
					     'image_top_right',
					     'image_bottom_left',
					     'image_bottom_right'
				     ) ) && $is_single ) ) {
				$container_classes .= ' wlfmc-top-of-image ';
				if ( $is_single ) {
					$container_classes .= $single_position;
				} elseif ( $is_gutenberg ) {
					$container_classes .= $gutenberg_position;
				} else {
					$container_classes .= $loop_position;
				}

				//$button_type = 'icon';
				//$classes     = str_replace( 'button', '', $classes );
			}

			if ( '1' == $remove_after_second_click ) {
				$template_part_after_add = 'remove';
				$container_classes       .= ' show-remove-after-add';
			} else {
				$template_part_after_add = 'browse';
				$container_classes       .= ' show-browse-after-add';
			}


			if ( true != $button_theme ) {
				$classes = str_replace( 'button', 'wlfmc-custom-btn', $classes );
			}

			$template_part = $exists ? $template_part_after_add : 'button';

			//$template_part = isset( $atts['added_to_wishlist'] ) && $atts['added_to_wishlist'] && 'button' == $template_part_after_add  ?  'added' : $template_part;


			$classes_add    = $classes;
			$classes_exists = str_replace( array( 'single_add_to_wishlist', 'add_to_wishlist' ), '', $classes );

			if ( 'remove' == $template_part ) {
				$label   = apply_filters( 'wlfmc_button_remove_label', $button_label_remove );
				$classes = str_replace( array( 'single_add_to_wishlist', 'add_to_wishlist' ), '', $classes );
			}
			if ( 'browse' == $template_part ) {
				$label   = apply_filters( 'wlfmc_button_view_label', $button_label_view );
				$classes = str_replace( array( 'single_add_to_wishlist', 'add_to_wishlist' ), '', $classes );
			}

			$tooltip_label = $label;

			if ( 'icon' == $button_type ) {
				$label = '';

			}
			if ( 'text' == $button_type ) {
				$icon       = '';
				$added_icon = '';
			}

			// get wishlist url.
			$wishlist_url = is_user_logged_in() ? apply_filters( 'wlfmc_user_logged_in_wishlist_url', wc_get_account_endpoint_url( get_option( 'woocommerce_myaccount_wlfmc_wishlist_endpoint', 'wlfmc-wishlist' ) ) ) : WLFMC()->get_wishlist_url();

			// get product type.
			$product_type = $current_product->get_type();

			$exists_in_wishlists = array();

			if ( 'variable' === $product_type && $is_single ) {
				$wishlists = WLFMC()->get_current_user_wishlists();

				$variations = $current_product->get_children();
				if ( ! empty( $variations ) ) {
					foreach ( $wishlists as $wishlist ) {

						$items = $wishlist->get_items();
						if ( ! empty( $items ) ) {
							foreach ( $variations as $variation ) {
								$product_id = wlfmc_object_id( $variation, 'product', true, 'default' );
								$item       = $items[ $product_id ] ?? '';
								if ( $item ) {
									$exists_in_wishlists[] = array(
										'wishlist_id' => $wishlist->get_id(),
										'item_id'     => $item->get_id(),
										'product_id'  => $variation
									);
								}
							}
						}


					}
				}
				if ( $exists ) {
					$exists_in_wishlists[] = array(
						'wishlist_id' => $found_in_list->get_id(),
						'item_id'     => $found_item->get_id(),
						'product_id'  => $current_product_id
					);
				}

			}

			$additional_params = array(
				'base_url'                      => wlfmc_get_current_url(),
				'wishlist_url'                  => $wishlist_url,
				'in_default_wishlist'           => $exists,
				'exists'                        => $exists,
				'container_classes'             => $container_classes,
				'is_single'                     => $is_single,
				'found_in_list'                 => $found_in_list,
				'found_item'                    => $found_item,
				'product_id'                    => $current_product_id,
				'parent_product_id'             => $current_product_parent ? $current_product_parent : $current_product_id,
				'product_type'                  => $product_type,
				'label'                         => $label,
				'already_in_wishlist_text'      => apply_filters( 'wlfmc_product_already_in_wishlist_text_button', $already_in_wishlist ),
				'product_added_text'            => apply_filters( 'wlfmc_product_added_to_wishlist_message_button', $product_added ),
				'icon'                          => $icon,
				'link_classes'                  => $classes,
				'available_multi_wishlist'      => false,
				'is_svg_icon'                   => $is_svg_icon,
				'disable_wishlist'              => $disable_wishlist,
				'loop_position'                 => $loop_position,
				'is_gutenberg'                  => $is_gutenberg,
				'gutenberg_position'            => $gutenberg_position,
				'template_part'                 => $template_part,
				'tooltip_class'                 => $tooltip_class,
				'tooltip_label'                 => $tooltip_label,
				'tooltip_type'                  => $tooltip_type,
				'enabled_popup'                 => false,
				'exists_in_wishlists'           => $exists_in_wishlists,
				'enable_for_outofstock_product' => $options->get_option( 'enable_for_outofstock_product' )
			);

			// popup
			if ( 'open-popup' === $click_wishlist_button_behavior ) {


				$popup_title        = $options->get_option( 'popup_title' );
				$popup_content      = $options->get_option( 'popup_content' );
				$popup_position     = $options->get_option( 'popup_position', 'center-center' );
				$popup_size         = $options->get_option( 'popup_size', 'small' );
				$popup_image        = $options->get_option( 'popup_image' );
				$popup_image_size   = $options->get_option( 'popup_image_size', 'medium' );
				$popup_image_width  = $options->get_option( 'popup_image_width' );
				$popup_image_height = $options->get_option( 'popup_image_height' );
				$buttons            = $options->get_option( 'popup_buttons' );
				$use_featured_image = $options->get_option( 'use_featured_image' );
				$popup_image_size   = ( 'manual' === $popup_image_size && '' != $popup_image_width && '' != $popup_image_height ) ? array(
					$popup_image_width,
					$popup_image_height
				) : $popup_image_size;
				$image_attributes   = wp_get_attachment_image_src( $popup_image, $popup_image_size );
				$image_attributes   = ( true == $use_featured_image ) ? wp_get_attachment_image_src( $current_product->get_image_id(), $popup_image_size ) : $image_attributes;
				$popup_image_src    = $image_attributes ? $image_attributes[0] : '';
				$popup_position     = explode( '-', $popup_position );
				$popup_vertical     = $popup_position[0];
				$popup_horizontal   = $popup_position[1];


				$placeholders  = array(
					'{product_name}'  => $current_product->get_title(),
					'{product_price}' => $current_product->get_price_html(),
				);
				$popup_title   = str_replace( array_keys( $placeholders ), array_values( $placeholders ), $popup_title );
				$popup_content = str_replace( array_keys( $placeholders ), array_values( $placeholders ), $popup_content );


				$additional_params = array_merge(
					$additional_params,
					array(
						'enabled_popup'      => true,
						'template_part'      => $template_part,
						'popup_vertical'     => $popup_vertical,
						'popup_horizontal'   => $popup_horizontal,
						'popup_size'         => $popup_size,
						'popup_image'        => $popup_image_src,
						'popup_title'        => $popup_title,
						'popup_content'      => $popup_content,
						'product_title'      => $current_product->get_title(),
						'product_price'      => $current_product->get_price_html(),
						'use_featured_image' => $use_featured_image,
						'popup_image_size'   => $popup_image_size,
						'login_url'          => $options->get_option( 'login_url', wp_login_url() ),
						'signup_url'         => $options->get_option( 'signup_url', wp_registration_url() ),
						'buttons'            => $buttons,

					)
				);
			}

			$additional_params = apply_filters( 'wlfmc_add_to_wishlist_params', $additional_params, $atts );


			$atts = shortcode_atts(
				$additional_params,
				$atts
			);


			// add new params for new template

			$button_label_add    = apply_filters( 'wlfmc_button_add_label', $button_label_add, $is_single );
			$button_label_remove = apply_filters( 'wlfmc_button_remove_label', $button_label_remove );
			$button_label_view   = apply_filters( 'wlfmc_button_view_label', $button_label_view );

			$tooltip_label_add    = apply_filters( 'wlfmc_tooltip_add_label', $button_label_add );
			$tooltip_label_remove = apply_filters( 'wlfmc_tooltip_remove_label', $button_label_remove );
			$tooltip_label_view   = apply_filters( 'wlfmc_tooltip_view_label', $button_label_view );

			if ( 'icon' == $button_type ) {
				$button_label_add    = '';
				$button_label_remove = '';
				$button_label_view   = '';
			}
			$data_remove_url = add_query_arg( 'remove_from_wishlist', '#product_id', wlfmc_get_current_url() );
			$data_add_url    = add_query_arg( 'add_to_wishlist', '#product_id', wlfmc_get_current_url() );


			$before_add_icon_html  = '';
			$after_added_icon_html = '';
			if ( in_array( $button_type, array( 'icon', 'both' ) ) ) {
				$before_add_icon_html  = ( false === $is_svg_icon ) ? '<i class="wlfmc-icon-' . $icon . '"></i>' : $icon;
				$after_added_icon_html = ( false === $is_svg_icon ) ? '<i class="wlfmc-icon-' . $added_icon . '"></i>' : $added_icon;
			}

			$atts['before_add_icon']  = apply_filters( 'wlfmc_before_add_icon_html', $before_add_icon_html, $atts );
			$atts['after_added_icon'] = apply_filters( 'wlfmc_after_added_icon_html', $after_added_icon_html, $atts );

			$atts['classes_exists']       = $classes_exists;
			$atts['classes_add']          = $classes_add;
			$atts['button_label_add']     = $button_label_add;
			$atts['button_label_remove']  = $button_label_remove;
			$atts['button_label_view']    = $button_label_view;
			$atts['tooltip_label_add']    = $tooltip_label_add;
			$atts['tooltip_label_remove'] = $tooltip_label_remove;
			$atts['tooltip_label_view']   = $tooltip_label_view;
			$atts['data_remove_url']      = $data_remove_url;
			$atts['data_add_url']         = $data_add_url;


			// change icon when item exists in wishlist.
			if ( $atts['exists'] ) {
				$atts['icon'] = $added_icon;
			}

			if ( in_array( $button_type, array( 'icon', 'both' ) ) ) {
				$icon_html = ( false === $is_svg_icon ) ? '<i class="wlfmc-icon-' . $atts['icon'] . '"></i>' : $atts['icon'];
			} else {
				$icon_html = '';
			}

			$atts['icon'] = apply_filters( 'wlfmc_add_to_wishlist_icon_html', $icon_html, $atts );

			$template = wlfmc_get_template( 'add-to-wishlist.php', $atts, true );

			// enqueue scripts.
			WLFMC_Frontend()->enqueue_scripts();

			return apply_filters( 'wlfmc_add_to_wishlist_button_html', $template, $wishlist_url, $product_type, $exists, $atts );
		}


		/**
		 * Return "wishlist" product counter.
		 *
		 * @param array $atts Array of parameters for the shortcode
		 * @param string $content Shortcode content (usually empty)
		 *
		 * @return string
		 *
		 * @since 1.3.3
		 */
		public static function wishlist_counter( $atts, $content = null ) {


			$wishlist = WLFMC_Wishlist_Factory::get_current_wishlist();


			if ( ! $wishlist || ! $wishlist->current_user_can( 'view' ) ) {
				/**
				 * Create a wishlist for guests who have no products on the wishlist
				 *
				 * $wishlist = WLFMC_Wishlist_Factory::get_wishlist( 0, 'edit' );
				 * if ( $wishlist ) {
				 * $wishlist->save();
				 * } else {
				 * return '';
				 * }
				 */
				$options     = new MCT_Options( 'wlfmc_options' );
				$empty_icon  = $options->get_option( 'counter_icon', 'heart' );
				$is_svg_icon = false;
				if ( 'custom' === $empty_icon ) {
					$is_svg_icon = true;
					$empty_icon  = $options->get_option( 'counter_icon_svg_zero' );
				}

				$atts = array(
					'show_icon'                => 'yes',
					'show_empty_content'       => 'yes',
					'dropdown_products'        => 'yes',
					'show_button'              => 'yes',
					'show_totals'              => 'yes',
					'container_class'          => '',
					'show_text'                => '1' == $options->get_option( 'enable_counter_text', '1' ) ? 'yes' : 'no',
					'counter_text'             => $options->get_option( 'counter_text', '' ),
					'button_text'              => $options->get_option( 'counter_button_text', __( 'View My Wishlist', 'wc-wlfmc-wishlist' ) ),
					'total_text'               => $options->get_option( 'counter_total_text', __( 'Total products', 'wc-wlfmc-wishlist' ) ),
					'icon'                     => $empty_icon,
					'is_svg_icon'              => $is_svg_icon,
					'products_number_position' => $options->get_option( 'counter_products_number_position', 'right' ),
					'add_link_title'           => '1' == $options->get_option( 'enable_counter_add_link_title', '1' ),
					'wishlist_link_position'   => $options->get_option( 'counter_mini_wishlist_link_position', 'after' ),
					'empty_wishlist_content'   => $options->get_option( 'empty_wishlist_content', __( 'You have not added any products to your wishlist.', 'wc-wlfmc-wishlist' ) ),
				);

				$icon_html                = ( false === $is_svg_icon ) ? '<i class="wlfmc-icon-' . $atts['icon'] . '"></i>' : $atts['icon'];
				$atts['icon']             = apply_filters( 'wlfmc_wishlist_counter_icon_html', $icon_html, $atts );
				$atts['fragment_options'] = WLFMC_Frontend()->format_fragment_options( $atts, 'wishlist_counter' );

				$template = wlfmc_get_template( 'wishlist-counter-empty-guests.php', apply_filters( 'wlfmc_wishlist_counter_empty_guests_params', $atts ), true );

				// enqueue scripts.
				WLFMC_Frontend()->enqueue_scripts();

				return apply_filters( 'wlfmc_wishlist_counter_empty_guests_html', $template, $atts );
			}

			$options = new MCT_Options( 'wlfmc_options' );

			$empty_icon    = $options->get_option( 'counter_icon', 'heart' );
			$has_item_icon = $empty_icon . '-o';
			$is_svg_icon   = false;
			if ( 'custom' === $empty_icon ) {
				$is_svg_icon   = true;
				$empty_icon    = $options->get_option( 'counter_icon_svg_zero' );
				$has_item_icon = $options->get_option( 'counter_icon_svg_added' );
			}

			$additional_params = array(
				'show_icon'                 => 'yes',
				'show_button'               => 'yes',
				'show_totals'               => 'yes',
				'container_class'           => '',
				'show_text'                 => '1' == $options->get_option( 'enable_counter_text', '1' ) ? 'yes' : 'no',
				'show_counter'              => '1' == $options->get_option( 'enable_counter_products_number', '1' ) ? 'yes' : 'no',
				'show_products'             => '1' == $options->get_option( 'enable_counter_mini_wishlist_dropdown', '1' ) ? 'yes' : 'no',
				'dropdown_products'         => 'yes',
				'counter_text'              => $options->get_option( 'counter_text', '' ),
				'button_text'               => $options->get_option( 'counter_button_text', __( 'View my Wishlist', 'wc-wlfmc-wishlist' ) ),
				'total_text'                => $options->get_option( 'counter_total_text', __( 'Total products', 'wc-wlfmc-wishlist' ) ),
				'per_page'                  => $options->get_option( 'counter_per_page_products_count', '4' ),
				'empty_icon'                => $empty_icon,
				'has_item_icon'             => $has_item_icon,
				'is_svg_icon'               => $is_svg_icon,
				'hide_zero_products_number' => '1' == $options->get_option( 'hide_counter_zero_products_number', '1' ),
				'products_number_position'  => $options->get_option( 'counter_products_number_position', 'right' ),
				'add_link_title'            => '1' == $options->get_option( 'enable_counter_add_link_title', '1' ),
				'wishlist_link_position'    => $options->get_option( 'counter_mini_wishlist_link_position', 'after' ),
				'wishlist'                  => $wishlist,
				'is_default'                => $wishlist->get_is_default(),
				'wishlist_token'            => $wishlist->get_token(),
				'wishlist_id'               => $wishlist->get_id(),
				'is_private'                => $wishlist->has_privacy( 'private' ),
				'wishlist_url'              => $wishlist->get_url(),
				'wishlist_items'            => $wishlist->get_items( $options->get_option( 'counter_per_page_products_count', '4' ), 0 ),
				'empty_wishlist_content'    => $options->get_option( 'empty_wishlist_content', __( 'You have not added any products to your wishlist.', 'wc-wlfmc-wishlist' ) ),
			);

			$additional_params = apply_filters( 'wlfmc_wishlist_counter_params', $additional_params, $atts );

			$atts = shortcode_atts(
				$additional_params,
				$atts
			);

			// change icon when item exists in wishlist.
			if ( 0 < $wishlist->count_items() ) {
				$atts['icon'] = $additional_params['has_item_icon'];
			} else {
				$atts['icon'] = $additional_params['empty_icon'];
			}

			$icon_html = ( false === $is_svg_icon ) ? '<i class="wlfmc-icon-' . $atts['icon'] . '"></i>' : $atts['icon'];

			// set fragment options.
			$atts['fragment_options'] = WLFMC_Frontend()->format_fragment_options( $atts, 'wishlist_counter' );
			$atts['icon']             = apply_filters( 'wlfmc_wishlist_counter_icon_html', $icon_html, $atts );

			$template = wlfmc_get_template( 'wishlist-counter.php', $atts, true );

			// enqueue scripts.
			WLFMC_Frontend()->enqueue_scripts();

			return apply_filters( 'wlfmc_wishlist_counter_html', $template, $atts );


		}


	}
}

WLFMC_Shortcode::init();
