<?php

/**
 * Wishlist Counter Widget.
 *
 * @author MoreConvert
 * @package Smart Wishlist For More Convert
 * @version 1.0.1
 */

// Don't load directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Elementor\Controls_Manager;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Widget_Base;

class WLFMC_WidgetWishlistCounter extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve WishList widget name.
	 *
	 * @return string Widget Name.
	 * @access public
	 *
	 */
	public function get_name() {
		return 'wlfmc-wishlist-counter';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve WishList widget title.
	 *
	 * @return string Widget Title.
	 * @access public
	 *
	 */
	public function get_title() {
		return esc_html__( 'Wishlist Counter', 'wc-wlfmc-wishlist' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve WishList widget icon.
	 *
	 * @return string Widget Icon.
	 * @access public
	 *
	 */
	public function get_icon() {
		return 'eicon-table';
	}


	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the WishList widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @access public
	 *
	 * @return array Widget Categories.
	 */
	public function get_categories() {
		return [ 'WLFMC_WishList' ];
	}

	/**
	 * Register WishList Widget Controls
	 *
	 * @return void.
	 * @access protected
	 *
	 */
	protected function register_controls() {

	}

	/**
	 * Render WishList widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @access protected
	 */
	protected function render() {

		$this->add_render_attribute( 'wrapper', 'class', 'mc-wishlist-wrapper' );
		?>
		<div <?php echo $this->get_render_attribute_string( 'wrapper' ); ?>>
			<?php echo do_shortcode( '[wlfmc_wishlist_counter container_class="'.$this->get_id().'"]' ); ?>
		</div>
		<?php
	}
}
