<?php
/**
 * Automation list Class
 *
 * @author MoreConvert
 * @package Smart Wishlist For More Convert
 * @version 1.3.3
 */


if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'WP_List_Table' ) ) {
	require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}

class WLFMC_Automation_Table extends WP_List_Table {


	function __construct() {


		parent::__construct( [
			'singular' => 'automation',     // Singular name of the listed records.
			'plural'   => 'automations',    // Plural name of the listed records.
			'ajax'     => false //should this table support ajax?
		] );


	}

	function column_default( $item, $column_name ) {
		switch ( $column_name ) {
			case 'status':
				$status = $item['is_active'] ? __( 'Active', 'wc-wlfmc-wishlist' ) : __( 'Paused', 'wc-wlfmc-wishlist' );
				$class  = $item['is_active'] ? 'active' : 'pause';

				return '<span class="status-' . $class . '">' . $status . '</span>';
			case 'net_total':
				return wc_price( $item[ $column_name ] );
			case 'open_rate':
				//$value = absint( $item['sent'] ) > 0 ? absint( $item['opened'] ) / absint( $item['sent'] ) * 100 : 0;

				return floatval( $item[ $column_name ] ) . '%';
			case 'click_rate':
				//$value = absint( $item['sent'] ) > 0 ? absint( $item['clicked'] ) / absint( $item['sent'] ) * 100 : 0;

				return floatval( $item[ $column_name ] ) . '%';
			case 'sent':
			case 'recipients':
			case 'automation_name':
				return $item[ $column_name ];
			case 'created_at':
				return $item[ $column_name ] != '' ? date( 'Y-m-d', strtotime( $item[ $column_name ] ) ) : '-';
			default:
				return print_r( $item, true ); //Show the whole array for troubleshooting purposes
		}
	}


	function get_columns() {
		return [
			//'cb'         => '<input type="checkbox" />',
			'created_at'      => __( 'Date', 'wc-wlfmc-wishlist' ),
			'automation_name' => __( 'Name', 'wc-wlfmc-wishlist' ),
			'recipients'      => __( 'Recipients', 'wc-wlfmc-wishlist' ),
			//'sent'       => __( 'Sent', 'wc-wlfmc-wishlist' ),
			'open_rate'       => __( 'Open Rate', 'wc-wlfmc-wishlist' ),
			'click_rate'      => __( 'Click Rate', 'wc-wlfmc-wishlist' ),
			'status'          => __( 'Status', 'wc-wlfmc-wishlist' ),
			'net_total'       => __( 'NET', 'wc-wlfmc-wishlist' ),
			'action'          => '&nbsp;',//__( 'Action', 'wc-wlfmc-wishlist' ),

		];
	}

	function column_cb( $item ) {
		return sprintf(
			'<input type="checkbox" name="items[]" value="%s" />', $item['ID']
		);
	}

	function column_action( $item ) {


		return
			'<div class="margin-bet">' .
			sprintf( '<a href="?page=%s&tools=email-automation&tools-action=edit&automation_id=%s" class="center-align btn-secondary ico-btn gear-btn min-width-btn small-btn" >' . __( 'Manage', 'wc-wlfmc-wishlist' ) . '</a>', esc_attr( $_REQUEST['page'] ), absint( $item['ID'] ) ) .
			sprintf( '<a href="?page=%s&tools=email-automation&tools-action=view&automation_id=%s" class="center-align btn-secondary ico-btn report-btn min-width-btn small-btn" >' . __( 'Reports', 'wc-wlfmc-wishlist' ) . '</a>', esc_attr( $_REQUEST['page'] ), absint( $item['ID'] ) ) .
			'</div>';


	}

	function column_recipients( $item ) {
		global $wpdb;
		// create a nonce
		$delete_nonce = wp_create_nonce( 'delete-recipients' );

		$actions = [
			'delete-recipients' => sprintf( '<a href="?page=%s&tools=email-automation&action=delete-recipients&item=%s&_wpnonce=%s" onclick="return confirm(\'%s\')">' . __( 'Delete scheduled emails', 'wc-wlfmc-wishlist' ) . '</a>', esc_attr( $_REQUEST['page'] ), absint( $item['ID'] ), $delete_nonce, __( 'Are you sure you want to delete scheduled emails?', 'wc-wlfmc-wishlist' ) ),
		];


		return $item['recipients'] . $this->row_actions( $actions );
	}

	function column_created_at( $item ) {
		// create a nonce
		$delete_nonce = wp_create_nonce( 'delete-automation' );

		$actions = [
			'delete' => sprintf( '<a href="?page=%s&tools=email-automation&action=delete&item=%s&_wpnonce=%s" onclick="return confirm(\'%s\')">' . __( 'Delete', 'wc-wlfmc-wishlist' ) . '</a>', esc_attr( $_REQUEST['page'] ), absint( $item['ID'] ), $delete_nonce, __( 'Are you sure you want to delete?', 'wc-wlfmc-wishlist' ) ),
		];


		return date( 'Y-m-d', strtotime( $item['created_at'] ) ) . $this->row_actions( $actions );
	}

	function get_sortable_columns() {
		return [
			'created_at'      => [ 'created_at', true ],
			'recipients'      => [ 'recipients', false ],
			'automation_name' => [ 'automation_name', false ],
			'open_rate'       => [ 'open_rate', false ],
			'click_rate'      => [ 'click_rate', false ],
			'net_total'       => [ 'net_total', false ],
		];
	}

	function prepare_items() {


		$this->_column_headers = $this->get_column_info();

		/** Process bulk action */
		$this->process_bulk_action();

		$per_page     = $this->get_items_per_page( 'automation_per_page' );
		$current_page = $this->get_pagenum();
		$total_items  = self::record_count();

		$this->items = self::get_orders( $per_page, $current_page );

		$this->set_pagination_args( [
			'total_items' => $total_items,
			'per_page'    => $per_page,
			'total_pages' => ceil( $total_items / $per_page ),
		] );


	}

	public function process_bulk_action() {

		//Detect when a bulk action is being triggered...
		if ( 'delete' === $this->current_action() ) {

			// In our file that handles the request, verify the nonce.
			$nonce = esc_attr( $_REQUEST['_wpnonce'] );

			if ( ! wp_verify_nonce( $nonce, 'delete-automation' ) ) {

				die( 'Go get a life script kiddies' );

			} else if ( isset( $_REQUEST['item'] ) ) {
				self::delete_automation( absint( $_REQUEST['item'] ) );

			}

		}

		if ( 'delete-recipients' === $this->current_action() ) {

			// In our file that handles the request, verify the nonce.
			$nonce = esc_attr( $_REQUEST['_wpnonce'] );

			if ( ! wp_verify_nonce( $nonce, 'delete-recipients' ) ) {

				die( 'Go get a life script kiddies' );

			} else if ( isset( $_REQUEST['item'] ) ) {
				self::delete_recipients( absint( $_REQUEST['item'] ) );

			}

		}


	}

	/**
	 * Delete a automation record.
	 *
	 * @param int $id automation ID
	 */
	public static function delete_automation( $id ) {

		$automation = new WLFMC_Automation( $id );
		$deleted    = $automation->delete();
		if ( $deleted ) {
			wp_safe_redirect( add_query_arg( array(
				'deleted' => 1,
				'page'    => 'mc-wishlist-marketing',
				'tools'   => 'email-automation'
			), admin_url( 'admin.php' ) ) );
		} else {
			wp_safe_redirect( add_query_arg( array(
				'cant-delete' => 1,
				'page'        => 'mc-wishlist-marketing',
				'tools'       => 'email-automation'
			), admin_url( 'admin.php' ) ) );
		}

		exit;
	}

	public function delete_recipients( $id ) {
		$automation = new WLFMC_Automation( $id );
		$deleted    = $automation->delete_email_queue();

		if ( $deleted ) {
			wp_safe_redirect( add_query_arg( array(
				'recipients-deleted' => 1,
				'page'               => 'mc-wishlist-marketing',
				'tools'              => 'email-automation'
			), admin_url( 'admin.php' ) ) );
		} else {
			wp_safe_redirect( add_query_arg( array(
				'cant-delete-recipients' => 1,
				'page'                   => 'mc-wishlist-marketing',
				'tools'                  => 'email-automation'
			), admin_url( 'admin.php' ) ) );
		}

		exit;
	}


	/**
	 * Record count.
	 *
	 * @return string|null
	 */
	public static function record_count() {
		global $wpdb;

		$sql = "SELECT COUNT(ID) FROM {$wpdb->wlfmc_automations} ";
		if ( ! empty( $_REQUEST['status'] ) && in_array( $_REQUEST['status'], [
				'1',
				'0',
			] ) ) {
			$sql .= ' WHERE  is_active="' . esc_sql( $_REQUEST['status'] ) . '"';
		}

		return $wpdb->get_var( $sql );
	}

	/**
	 * @param $per_page
	 * @param int $page_number
	 *
	 * @return array|object|null
	 */
	public static function get_orders( $per_page, $page_number = 1 ) {
		//  sum(case when items.status IN ('opened','clicked' ,'coupon-used')  then 1 else 0 end) opened,
		//            sum(case when items.status IN ('clicked' ,'coupon-used') then 1 else 0 end) clicked, sum(case when items.status = 'coupon-used' then 1 else 0 end) coupon_used,
		//
		global $wpdb;
		$sql = "SELECT automation.* ,
			sum(case when items.status IN ('sent', 'opened','clicked' ,'coupon-used')  then 1 else 0 end) sent,
            sum(case when items.status IN ('sending' , 'not-send') then 1 else 0 end) send_queue,
            (sum(case when items.status IN ('opened','clicked' ,'coupon-used')  then 1 else 0 END) / sum(case when items.status IN ('sent', 'opened','clicked' ,'coupon-used')  then 1 else 0 END) * 100 ) AS open_rate,
            (sum(case when items.status IN ('clicked' ,'coupon-used')  then 1 else 0 END) / sum(case when items.status IN ('sent', 'opened','clicked' ,'coupon-used')  then 1 else 0 END) * 100 ) AS click_rate,
            sum(case when items.net > 0 then items.net else 0 end) net_total,
            COUNT(DISTINCT(items.user_id)) as recipients
 			FROM {$wpdb->wlfmc_automations} as automation
 			LEFT JOIN {$wpdb->wlfmc_offers} as items ON automation.ID = items.automation_id WHERE 1=1";

		if ( ! empty( $_REQUEST['status'] ) && in_array( $_REQUEST['status'], [
				'1',
				'0',
			] ) ) {
			$sql .= ' AND  automation.is_active="' . esc_sql( $_REQUEST['status'] ) . '"';
		}
		if ( ! empty( $_REQUEST['s'] ) ) {
			$sql .= ' AND  automation.automation_name LIKE "%' . $wpdb->esc_like( $_REQUEST['s'] ) . '%"';
		}
		$sql .= ' GROUP BY automation.ID';

		if ( ! empty( $_REQUEST['orderby'] ) ) {
			$sql .= ' ORDER BY ' . esc_sql( $_REQUEST['orderby'] );
			$sql .= ! empty( $_REQUEST['order'] ) ? ' ' . esc_sql( $_REQUEST['order'] ) : ' ASC';
		}


		$sql .= " LIMIT $per_page";

		$sql .= ' OFFSET ' . ( $page_number - 1 ) * $per_page;

		return $wpdb->get_results( $sql, 'ARRAY_A' );
	}

	/**
	 * Displays the search box.
	 *
	 *
	 * @param string $text The 'submit' button label.
	 * @param string $input_id ID attribute value for the search input field.
	 */
	public function search_box( $text, $input_id ) {
		if ( empty( $_REQUEST['s'] ) && ! $this->has_items() ) {
			return;
		}

		$input_id = $input_id . '-search-input';

		if ( ! empty( $_REQUEST['orderby'] ) ) {
			echo '<input type="hidden" name="orderby" value="' . esc_attr( $_REQUEST['orderby'] ) . '" />';
		}
		if ( ! empty( $_REQUEST['order'] ) ) {
			echo '<input type="hidden" name="order" value="' . esc_attr( $_REQUEST['order'] ) . '" />';
		}
		?>
		<p class="search-box">
			<label class="screen-reader-text" for="<?php echo esc_attr( $input_id ); ?>"><?php echo $text; ?>:</label>
			<input type="search" placeholder="<?php esc_attr_e( 'Search by name', 'wc-wlfmc-wishlist' ); ?>"
				   id="<?php echo esc_attr( $input_id ); ?>" name="s" value="<?php _admin_search_query(); ?>"/>
			<?php submit_button( $text, '', '', false, array( 'id' => 'search-submit' ) ); ?>
		</p>
		<?php
	}

	/**
	 * Display the views.
	 *
	 * @return array
	 */
	function get_views() {
		global $wpdb;
		$count   = $wpdb->get_row( "SELECT  count(*) all_status,
 				sum(case when is_active = '1' then 1 else 0 end) is_active,
				sum(case when is_active = '0' then 1 else 0 end) paused

			    from {$wpdb->wlfmc_automations}", ARRAY_A );
		$views   = [];
		$current = ( ! empty( $_REQUEST['status'] ) ? $_REQUEST['status'] : 'all' );

		$removable_query_args = wp_removable_query_args();
		$current_url          = remove_query_arg( $removable_query_args );


		if ( $count['all_status'] > 0 ) {
			$class        = ( $current == 'all' ? ' class="current"' : '' );
			$url          = esc_url( remove_query_arg( 'status', $current_url ) );
			$views['all'] = "<a href='{$url }' {$class} >" . __( 'All', 'wc-wlfmc-wishlist' ) . " (" . $count['all_status'] . ")</a>";

		}
		if ( $count['is_active'] > 0 ) {
			$url                = esc_url( add_query_arg( 'status', '1', $current_url ) );
			$label              = __( 'Active', 'wc-wlfmc-wishlist' );
			$class              = ( $current == '1' ? ' class="current"' : '' );
			$views['is_active'] = "<a href='{$url}' {$class} >" . $label . " (" . $count['is_active'] . ")</a>";

		}
		if ( $count['paused'] > 0 ) {
			$label           = __( 'Paused', 'wc-wlfmc-wishlist' );
			$url             = esc_url( add_query_arg( 'status', '0', $current_url ) );
			$class           = ( $current == '0' ? ' class="current"' : '' );
			$views['paused'] = "<a href='{$url}' {$class} >" . $label . " (" . $count['paused'] . ")</a>";

		}


		return $views;
	}

	/**
	 * Message
	 * define an array of message and show the content od message if
	 * is find in the query string
	 */
	public function message() {
		// phpcs:disable WordPress.Security.NonceVerification.Recommended
		$message = apply_filters(
			'wlfmc_automation_table_messages',
			array(
				'deleted'                => $this->get_message( '<strong>' . __( 'Automation Removed.', 'wc-wlfmc-wishlist' ) . '</strong>', 'updated', false ),
				'cant-delete'            => $this->get_message( '<strong>' . __( 'You can\'t remove a sending automation.', 'wc-wlfmc-wishlist' ) . '</strong>', 'error', false ),
				'recipients-deleted'     => $this->get_message( '<strong>' . __( 'All scheduled emails Removed.', 'wc-wlfmc-wishlist' ) . '</strong>', 'updated', false ),
				'cant-delete-recipients' => $this->get_message( '<strong>' . __( 'Can\'t find any scheduled emails.', 'wc-wlfmc-wishlist' ) . '</strong>', 'error', false ),
			)
		);

		foreach ( $message as $key => $value ) {
			if ( isset( $_GET[ $key ] ) ) {
				echo wp_kses_post( $value );
			}
		}
		// phpcs:enable
	}

	/**
	 * Get Message
	 * return html code of message
	 *
	 * @param string $message The message.
	 * @param string $type The type of message (can be 'error' or 'updated').
	 * @param bool $echo Set to true if you want to print the message.
	 *
	 * @return string
	 */
	public function get_message( $message, $type = 'error', $echo = true ) {
		$message = '<div id="message" class="' . esc_attr( $type ) . ' fade"><p>' . wp_kses_post( $message ) . '</p></div>';
		if ( $echo ) {
			echo wp_kses_post( $message );
		}

		return $message;
	}


}
